@@ -25,7 +25,7 @@ BFont_Info *CurrentFont;
 void
 InitFont (BFont_Info * Font)
 {
-  int x = 0, i = 0;
+  unsigned int x = 0, i = 0;
   Uint32 sentry;
   SDL_Surface* tmp_char1;
 
@@ -43,24 +43,28 @@ InitFont (BFont_Info * Font)
   if (SDL_MUSTLOCK (Font->Surface))
     SDL_LockSurface (Font->Surface);
   x = 0;
-  while (x < (Font->Surface->w - 1))
+  while (x < (Font->Surface->w - 1) && i < MAX_CHARS_IN_FONT)
     {
       if (FdGetPixel (Font->Surface, x, 0) != sentry)
 	{
 	  Font->Chars[i].x = x;
 	  Font->Chars[i].y = 1;
 	  Font->Chars[i].h = Font->Surface->h;
-	  for (;
-	       FdGetPixel (Font->Surface, x, 0) != sentry
-	       && x < (Font->Surface->w); ++x);
+          while( x < (Font->Surface->w)){
+               if(FdGetPixel (Font->Surface, x, 0) == sentry)
+                   break;
+               x++;
+          }
 	  Font->Chars[i].w = (x - Font->Chars[i].x);
 
 	  //--------------------
 	  // Now we make a copy for later reference when we do OpenGL based
 	  // output of this character.
 	  //
+	  Font->number_of_chars = i + 1;
 	  tmp_char1 = SDL_CreateRGBSurface( 0 , CharWidth ( Font , i ) , FontHeight (Font) -1 , 32, 
-					    0x0FF000000 , 0x000FF0000  , 0x00000FF00 , 0x000FF );
+					    //0xFF000000 , 0x00FF0000  , 0x0000FF00 , 0x000000FF );
+					    0x000000FF , 0x0000FF00  , 0x00FF0000 , 0xFF000000 );
 
 	  SDL_SetAlpha( Font->Surface , 0 , 255 );
 	  SDL_SetColorKey( Font->Surface , 0 , 0 );
@@ -88,7 +92,12 @@ InitFont (BFont_Info * Font)
   Font->Chars[' '].y = 0;
   Font->Chars[' '].h = Font->Surface->h;
   Font->Chars[' '].w = Font->Chars['!'].w;
+  Font->number_of_chars = i;
 
+#ifdef HAVE_LIBGL
+if ( use_open_gl ) 
+  Font->list_base = glGenLists(i);
+#endif
   if (SDL_MUSTLOCK (Font->Surface))
     SDL_UnlockSurface (Font->Surface);
 
@@ -108,7 +117,7 @@ LoadFont (const char *filename)
 
   if (filename != NULL)
     {
-      Font = (BFont_Info *) malloc (sizeof (BFont_Info));
+      Font = (BFont_Info *) MyMalloc (sizeof (BFont_Info));
       if (Font != NULL)
 	{
 	  //--------------------
@@ -138,12 +147,6 @@ LoadFont (const char *filename)
 	      /* Set the font as the current font */
 	      SetCurrentFont (Font);
 	      
-	      /*
-	      if ( use_open_gl )
-		{
-		  flip_image_horizontally ( Font -> Surface ) ;
-		}
-	      */
 	    }
 	  else
 	    {
@@ -297,19 +300,18 @@ SetFontHeight (BFont_Info * Font, int height)
 
 /* Return the width of the "c" character */
 int
-CharWidth (BFont_Info * Font, int c)
+CharWidth (BFont_Info * Font, unsigned char c)
 {
-if(c > 128)
-	c = 'a';
 
-return Font->Chars[c].w;
+  if ( c < ' ' || c > Font->number_of_chars-1 ) c = '.';
+  return Font->Chars[c].w;
 }
 
 /* ----------------------------------------------------------------------
  * Puts a single char on the surface 
  * ---------------------------------------------------------------------- */
 int
-PutChar (SDL_Surface * Surface, int x, int y, int c)
+PutChar (SDL_Surface * Surface, int x, int y, unsigned char c)
 {
   return PutCharFont (Surface, CurrentFont, x, y, c);
 }; // int PutChar (SDL_Surface * Surface, int x, int y, int c)
@@ -318,7 +320,7 @@ PutChar (SDL_Surface * Surface, int x, int y, int c)
  * Puts a single char on the surface with the specified font 
  * ---------------------------------------------------------------------- */
 int
-PutCharFont (SDL_Surface * Surface, BFont_Info * Font, int x, int y, int c)
+PutCharFont (SDL_Surface * Surface, BFont_Info * Font, int x, int y, unsigned char c)
 {
   SDL_Rect dest;
   SDL_Rect clipping_rect;
@@ -327,6 +329,7 @@ PutCharFont (SDL_Surface * Surface, BFont_Info * Font, int x, int y, int c)
   dest.x = x;
   dest.y = y;
 
+  if ( c<' ' || c>Font->number_of_chars-1 ) c = '.';
   if ( ( c != ' ' ) && ( c != '\n' ) )
     {
       //--------------------
@@ -336,26 +339,26 @@ PutCharFont (SDL_Surface * Surface, BFont_Info * Font, int x, int y, int c)
       //
       if ( use_open_gl )
 	{
-	  //--------------------
-	  // Printing the character should only be done, if the character would also
-	  // be blitted with SDL output, i.e. if the character lies within the so called
-	  // SDL clipping rectangle.  We make sure this is the case, or otherwise just 
-	  // leave this character unblitted.
-	  //
-	  SDL_GetClipRect ( Surface , & clipping_rect );
+	//--------------------
+	// We need to simulate the clipping is would be done by SDL.
+	// We simply do "all or none" clipping for left and right, but for the top/bottom of the screen,
+	// we use GL to do proper clipping in order not to see a whole line disappear at once.
 
-	  if ( ( dest . x < clipping_rect . x + clipping_rect . w ) &&
-	       ( dest . y < clipping_rect . y + clipping_rect . h ) &&
-	       ( dest . y >= clipping_rect . y ) &&
-	       ( dest . x >= clipping_rect . x ) )
-	    {
-	      //--------------------
-	      // Blitting the characters of the font with plain pixel operations in OpenGL is
-	      // known to fail on some systems.  So why not just use the faster textured quads
-	      // anyway?  Yes, why not.  But to safe some texture memory, we won't create *every*
-	      // texture for every font loaded at starting time but we'll create the surfaces
-	      // on the fly and ONLY FOR THOSE CHARACTERS NEEDED.  That should save us some time...
-	      //
+	// glClipPlane simply does a little math.
+
+        SDL_GetClipRect ( Surface , & clipping_rect );
+
+	#ifdef HAVE_LIBGL
+	GLdouble eqntop[4] = { 0.0, 1.0, 0.0, - clipping_rect . y };
+	GLdouble eqnbottom[4] = { 0.0, -1.0, 0.0, clipping_rect . y + clipping_rect . h};
+        glClipPlane(GL_CLIP_PLANE0, eqntop);
+        glEnable(GL_CLIP_PLANE0);
+        glClipPlane(GL_CLIP_PLANE1, eqnbottom);
+        glEnable(GL_CLIP_PLANE1);
+	#endif
+	if ( ( dest . x < clipping_rect . x + clipping_rect . w ) &&
+              ( dest . x >= clipping_rect . x ) )
+	      {
 	      if ( ! Font -> char_iso_image [ c ] . texture_has_been_created )
 		{
 		  if ( Font -> char_iso_image [ c ] . surface == NULL )
@@ -364,10 +367,47 @@ PutCharFont (SDL_Surface * Surface, BFont_Info * Font, int x, int y, int c)
 						 PLEASE_INFORM, IS_FATAL );
 		    }
 		  make_texture_out_of_surface ( & ( Font -> char_iso_image [ c ] ) ) ;
+		  #ifdef HAVE_LIBGL
+		  glNewList(Font->list_base + c, GL_COMPILE);
+
+	          glEnable( GL_TEXTURE_2D );
+		  glBindTexture(GL_TEXTURE_2D, *(Font->char_iso_image[c] . texture));
+	          glTexEnvi ( GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE );
+        	  glEnable ( GL_BLEND );
+        	  glDisable ( GL_ALPHA_TEST );
+ 
+	          glBlendFunc( GL_SRC_ALPHA , GL_ONE_MINUS_SRC_ALPHA );
+
+		  glBegin(GL_QUADS);
+
+		  glTexCoord2f( 0, 1.0 );
+		  glVertex2i( 0 , 0 );
+		  glTexCoord2f( 0.0, 0 );
+		  glVertex2i( 0 , Font->char_iso_image[c] . texture_height );
+		  glTexCoord2f( 1.0, 0 );
+		  glVertex2i( Font->char_iso_image[c] . texture_width , Font->char_iso_image[c] . texture_height );
+		  glTexCoord2f( 1.0, 1 );
+		  glVertex2i(  Font->char_iso_image[c] . texture_width , 0 );
+		
+		  glEnd( );
+	          glDisable( GL_TEXTURE_2D );
+		  glEndList();
+
+		  #endif
 		}
 	      
-	      blit_open_gl_texture_to_screen_position ( Font -> char_iso_image [ c ] , dest . x , dest . y , TRUE ) ;
-	    }
+	      //blit_open_gl_texture_to_screen_position ( & (Font -> char_iso_image [ c ]) , dest . x , dest . y , TRUE ) ;
+	      #ifdef HAVE_LIBGL
+	      glPushMatrix();
+	      glMatrixMode(GL_MODELVIEW);
+	      glTranslated(dest.x, dest.y, 0);
+	      glCallList(Font->list_base + c );
+	      glPopMatrix();
+              glDisable(GL_CLIP_PLANE0);
+	      glDisable(GL_CLIP_PLANE1);
+	      #endif
+
+              }
 	}
       else
 	{
@@ -405,6 +445,8 @@ PutStringFont (SDL_Surface * Surface, BFont_Info * Font, int x, int y, char *tex
   int kerning = 0;
   if (Font==Menu_BFont) kerning = -4;
 
+  if (Font==FPS_Display_BFont || Font==Blue_BFont || Font==Red_BFont) kerning = -2;
+
   while (text[i] != '\0')
     {
       //--------------------
@@ -413,10 +455,14 @@ PutStringFont (SDL_Surface * Surface, BFont_Info * Font, int x, int y, char *tex
       // switch the font even multiple times in one big text.
       //                                          jp, 27.7.2002
       //
-      if ( text[i] == 1 ) Font = Red_BFont;
-      else if ( text[i] == 2 ) Font = Blue_BFont;
-      else if ( text[i] == 3 ) Font = FPS_Display_BFont;
-      else x += PutCharFont (Surface, Font, x, y, text[i]) + kerning;
+      switch ( text [ i ] )
+	{
+	case 1: Font = Red_BFont; kerning = -2; break;
+	case 2: Font = Blue_BFont; kerning = -2; break;
+	case 3: Font = FPS_Display_BFont; kerning = -2; break;
+	default:
+	      x += PutCharFont (Surface, Font, x, y, text[i]) + kerning;
+	}
       i++;
     }
 }; // void PutStringFont (SDL_Surface * Surface, BFont_Info * Font, int x, int y, char *text)
@@ -449,10 +495,17 @@ TextWidthFont (BFont_Info * Font, char *text)
   // I extend this to give new text width results...
   //
   int kerning = 0;
-  if ( CurrentFont == Menu_BFont ) kerning = -4;
+  if ( Font == Menu_BFont ) kerning = -4;
+  if ( Font==FPS_Display_BFont || Font==Blue_BFont || Font==Red_BFont) kerning = -2;
 
   while (text[i] != '\0')
     {
+      switch ( text [ i ] )
+	{
+	case 1: Font = Red_BFont; kerning = -2; break;
+	case 2: Font = Blue_BFont; kerning = -2; break;
+	case 3: Font = FPS_Display_BFont; kerning = -2; break;
+	}
       x += CharWidth (Font, text[i]) + kerning ;
       i++;
     }
@@ -597,7 +650,7 @@ LeftPutStringFont (SDL_Surface * Surface, BFont_Info * Font, int y,
 /******/
 
 void
-PrintString (SDL_Surface * Surface, int x, int y, char *fmt, ...)
+PrintString (SDL_Surface * Surface, int x, int y, const char *fmt, ...)
 {
   va_list args;
   char *temp;
@@ -616,7 +669,7 @@ PrintString (SDL_Surface * Surface, int x, int y, char *fmt, ...)
 
 void
 PrintStringFont (SDL_Surface * Surface, BFont_Info * Font, int x, int y,
-		 char *fmt, ...)
+		 const char *fmt, ...)
 {
   va_list args;
   char *temp;
@@ -632,7 +685,7 @@ PrintStringFont (SDL_Surface * Surface, BFont_Info * Font, int x, int y,
 }
 
 void
-CenteredPrintString (SDL_Surface * Surface, int y, char *fmt, ...)
+CenteredPrintString (SDL_Surface * Surface, int y, const char *fmt, ...)
 {
   va_list args;
   char *temp;
@@ -649,7 +702,7 @@ CenteredPrintString (SDL_Surface * Surface, int y, char *fmt, ...)
 
 void
 CenteredPrintStringFont (SDL_Surface * Surface, BFont_Info * Font, int y,
-			 char *fmt, ...)
+			 const char *fmt, ...)
 {
   va_list args;
   char *temp;
@@ -666,7 +719,7 @@ CenteredPrintStringFont (SDL_Surface * Surface, BFont_Info * Font, int y,
 }
 
 void
-RightPrintString (SDL_Surface * Surface, int y, char *fmt, ...)
+RightPrintString (SDL_Surface * Surface, int y, const char *fmt, ...)
 {
   va_list args;
   char *temp;
@@ -683,7 +736,7 @@ RightPrintString (SDL_Surface * Surface, int y, char *fmt, ...)
 
 void
 RightPrintStringFont (SDL_Surface * Surface, BFont_Info * Font, int y,
-		      char *fmt, ...)
+		      const char *fmt, ...)
 {
   va_list args;
   char *temp;
@@ -699,7 +752,7 @@ RightPrintStringFont (SDL_Surface * Surface, BFont_Info * Font, int y,
 }
 
 void
-LeftPrintString (SDL_Surface * Surface, int y, char *fmt, ...)
+LeftPrintString (SDL_Surface * Surface, int y, const char *fmt, ...)
 {
   va_list args;
   char *temp;
@@ -716,7 +769,7 @@ LeftPrintString (SDL_Surface * Surface, int y, char *fmt, ...)
 
 void
 LeftPrintStringFont (SDL_Surface * Surface, BFont_Info * Font, int y,
-		     char *fmt, ...)
+		     const char *fmt, ...)
 {
   va_list args;
   char *temp;
@@ -732,7 +785,7 @@ LeftPrintStringFont (SDL_Surface * Surface, BFont_Info * Font, int y,
 }
 
 void
-JustifiedPrintString (SDL_Surface * Surface, int y, char *fmt, ...)
+JustifiedPrintString (SDL_Surface * Surface, int y, const char *fmt, ...)
 {
   va_list args;
   char *temp;
@@ -749,7 +802,7 @@ JustifiedPrintString (SDL_Surface * Surface, int y, char *fmt, ...)
 
 void
 JustifiedPrintStringFont (SDL_Surface * Surface, BFont_Info * Font, int y,
-			  char *fmt, ...)
+			  const char *fmt, ...)
 {
   va_list args;
   char *temp;
