@@ -28,7 +28,7 @@ extern void DebugPrintf (int db_level, const char *fmt, ...);
 extern dialogue_option ChatRoster[MAX_DIALOGUE_OPTIONS_IN_ROSTER];
 extern int debug_level ;
 extern void Terminate ( int exit_status ) ;
-char authors_notes[100000]="\nYou can use this text field to make some notes on anything.  These otes will get saved with the dialog.\nThis is intended purely for the author's reference when using the dialog editor, while the engine of the game itself will ignore this entry.\n";
+char authors_notes[100000]="\nYou can use this text field to make some notes on anything.  These notes will get saved with the dialog.\nThis is intended purely for the author's reference when using the dialog editor, while the engine of the game itself will ignore this entry.\n";
 
 #endif
 
