@@ -38,6 +38,27 @@
 #include "colodefs.h"
 #include "SDL_rotozoom.h"
 
+//--------------------
+// This controls the zoom factor for the automap.  Since this uses
+// a different update policy than the level editor, even strong zoom
+// will not be a problem here...
+//
+// However some other considerations must be taken into account:  OPENGL
+// DOES IN GENERAL NOT WORK WELL ANY MORE WITH TEXTURES LARGER THAN 1024
+// AND SOMETIMES EVEN NOT WELL WITH ANYTHING > 256 (old vodoo cards!!!)
+// EVEN GEFORCE II HAS PROBLEMS WITH 2048 TEXTURE SIZE.
+//
+// Therefore some sanity-factor is introduced here:  it will scale down
+// the internal automap texture but scale it up again when the acutal
+// part-transparent blit is being done.  Using 0.25 for the sanity factor
+// should be the safest bet.  However quality is poor:  you get lots of
+// rectangular blocks where a wall/door/tree would be.
+// So we're using larger textures, assuming that most people will have
+// decen graphics adapters. Vodoo users can recompile the game for their needs...
+//
+#define AUTOMAP_ZOOM_OUT_FACT 8.0
+int AUTOMAP_TEXTURE_WIDTH=2048;
+int AUTOMAP_TEXTURE_HEIGHT=1024;
 
 
 /* ----------------------------------------------------------------------
@@ -93,6 +114,20 @@ set_up_texture_for_automap ( void )
     // We create an SDL surface, so that we can make the texture for the
     // automap from it...
     //
+    int max_size;
+    glGetIntegerv(GL_MAX_TEXTURE_SIZE, &max_size);
+
+    if ( AUTOMAP_TEXTURE_WIDTH > max_size )
+	{
+	AUTOMAP_TEXTURE_HEIGHT *= (float)(max_size / (float)AUTOMAP_TEXTURE_WIDTH);
+	AUTOMAP_TEXTURE_WIDTH = max_size;
+	}
+    if ( AUTOMAP_TEXTURE_HEIGHT > max_size )
+	{
+	AUTOMAP_TEXTURE_WIDTH *= (float)(max_size / (float)AUTOMAP_TEXTURE_HEIGHT);
+	AUTOMAP_TEXTURE_HEIGHT = max_size;
+	}
+
     pure_surface = SDL_CreateRGBSurface( 0 , AUTOMAP_TEXTURE_WIDTH , AUTOMAP_TEXTURE_HEIGHT , 32, 0x0FF000000 , 0x000FF0000  , 0x00000FF00 , 0x000FF );
 
     //--------------------
@@ -304,30 +339,6 @@ show_automap_data_sdl ( void )
 	}
     }
 
-  //--------------------
-  // Now that the pure map data has been drawn, we add yellow dots for 
-  // the items, that have been detected on this level.
-  //
-  for ( i = 0 ; i < MAX_ITEMS_PER_LEVEL ; i ++ )
-    {
-      //--------------------
-      // This would be the most accurate information, but this is not granted
-      // without casting a spell and then only a copy is made and only updated
-      // once, so the player must really get on with much less information.
-      //
-      // if ( automap_level -> ItemList [ i ] . type == (-1) ) continue;
-      if ( Me [ 0 ] . DetectedItemList [ i ] . x == 0 ) continue;
-
-      for ( x = 0 ; x < AUTOMAP_SQUARE_SIZE ; x ++ )
-	{
-	  for ( y = 0 ; y < AUTOMAP_SQUARE_SIZE ; y ++ )
-	    {
-	      PutPixel ( Screen , AUTOMAP_SQUARE_SIZE * automap_level -> ItemList [ i ].pos.x + x , 
-			 AUTOMAP_SQUARE_SIZE * automap_level -> ItemList [ i ].pos.y + y , ItemColor );
-	    }
-	}
-    }
-
   //--------------------
   // Now that the pure map data has been drawn, we add red dots for 
   // the ememys around.
@@ -436,8 +447,8 @@ automap_update_texture_for_square ( int x , int y )
 	    glEnable ( GL_TEXTURE_2D );
 	    glBindTexture ( GL_TEXTURE_2D , *automap_texture );
 	    glTexSubImage2D ( GL_TEXTURE_2D , 0 , 
-			      ( AUTOMAP_TEXTURE_WIDTH / 2 ) + ( x - y ) * ( iso_floor_tile_width * AUTOMAP_SANITY_FACTOR / ( 2.0 * AUTOMAP_ZOOM_OUT_FACT ) ) ,
-			      AUTOMAP_TEXTURE_HEIGHT - ( 50 + ( x + y ) * ( iso_floor_tile_height * AUTOMAP_SANITY_FACTOR / ( 2.0 * AUTOMAP_ZOOM_OUT_FACT ) ) ) ,
+			      ( AUTOMAP_TEXTURE_WIDTH / 2 ) + ( our_obstacle -> pos . x - our_obstacle -> pos . y ) * ( iso_floor_tile_width / ( 2.0 * AUTOMAP_ZOOM_OUT_FACT ) ) ,
+			      AUTOMAP_TEXTURE_HEIGHT - ( 50 + ( our_obstacle -> pos . x + our_obstacle -> pos.  y ) * ( iso_floor_tile_height / ( 2.0 * AUTOMAP_ZOOM_OUT_FACT ) ) ) ,
 			      obstacle_map [ our_obstacle -> type ] . automap_version -> w ,
 			      obstacle_map [ our_obstacle -> type ] . automap_version -> h ,
 			      GL_BGRA, 
@@ -596,7 +607,7 @@ show_automap_data_ogl ( float scale_factor )
 
     iso_image local_iso_image;
     static iso_image tux_on_the_map_iso_image = UNLOADED_ISO_IMAGE ;
-    char *fpath;
+    char fpath[4096];
 
     //--------------------
     // Also if there is no map-maker present in inventory, then we need not
@@ -631,18 +642,18 @@ show_automap_data_ogl ( float scale_factor )
     local_iso_image . original_image_height = AUTOMAP_TEXTURE_HEIGHT ;
 
     blit_semitransparent_open_gl_texture_to_screen_position ( 
-	local_iso_image , 
+	&local_iso_image , 
 	- ( AUTOMAP_TEXTURE_WIDTH * scale_factor / 2 ) 
 	+ GameConfig . screen_width / 2 
 	- GameConfig . automap_manual_shift_x 
 	- ( Me [ 0 ] . pos . x - Me [ 0 ] . pos . y ) * 
-	  ( iso_floor_tile_width * scale_factor * AUTOMAP_SANITY_FACTOR / ( 2.0 * AUTOMAP_ZOOM_OUT_FACT ) ) , 
+	  ( iso_floor_tile_width * scale_factor / ( 2.0 * AUTOMAP_ZOOM_OUT_FACT ) ) , 
 
 	// + ( AUTOMAP_TEXTURE_HEIGHT / 2 ) 
 	+ GameConfig . screen_height / 2 
 	- GameConfig . automap_manual_shift_y 
 	- ( Me [ 0 ] . pos . x + Me [ 0 ] . pos . y ) * 
-          ( iso_floor_tile_height * scale_factor * AUTOMAP_SANITY_FACTOR / ( 2.0 * AUTOMAP_ZOOM_OUT_FACT ) ) , 
+          ( iso_floor_tile_height * scale_factor / ( 2.0 * AUTOMAP_ZOOM_OUT_FACT ) ) , 
 	scale_factor );
 
 
@@ -656,7 +667,7 @@ show_automap_data_ogl ( float scale_factor )
     if ( ! tux_on_the_map_iso_image . texture_has_been_created )
     {
 	DebugPrintf ( 1 , "\nLoading icon for Tux on the automap." );
-	fpath = find_file ( "tux_icon_on_automap.png" , GRAPHICS_DIR , FALSE );
+	find_file ( "tux_icon_on_automap.png" , GRAPHICS_DIR , fpath, 0 );
 	get_iso_image_from_file_and_path ( fpath , & tux_on_the_map_iso_image , TRUE ) ;
 	make_texture_out_of_surface ( & ( tux_on_the_map_iso_image ) ) ;
     }
@@ -664,7 +675,7 @@ show_automap_data_ogl ( float scale_factor )
     // Now we can blit the icon on the automap too
     //
     blit_semitransparent_open_gl_texture_to_screen_position ( 
-	tux_on_the_map_iso_image , 
+	&tux_on_the_map_iso_image , 
 	// - ( tux_on_the_map_iso_image . original_image_width / 2 ) 
 	+ ( GameConfig . screen_width / 2 ) 
 	- GameConfig . automap_manual_shift_x ,
