@@ -250,10 +250,6 @@ DeleteBullet ( int Bulletnumber , int ShallWeStartABlast )
       CurBullet -> Surfaces_were_generated = FALSE;
     }
 
-  //--------------------
-  // Now that the memory has been freed again, we can finally delete this bullet entry.
-  // Hope, that this does not give us a SEGFAULT, but it should not do so.
-  //
   CurBullet->type = INFOUT;
   CurBullet->time_in_seconds = 0;
   CurBullet->time_in_frames = 0;
@@ -420,39 +416,18 @@ MoveActiveSpells (void)
 	//--------------------
 	// We can ignore all unused entries...
 	//
-	if ( AllActiveSpells [ i ] . type == (-1) ) continue;
+	if ( AllActiveSpells [ i ] . img_type == (-1) ) continue;
 	
 	//--------------------
 	// All spells should count their lifetime...
 	//
 	AllActiveSpells [ i ] . spell_age += PassedTime;
 
-/*
-    for ( i = 0 ; i < NumberOfPicturesToUse ; i++ )
-    {
-	Angle = 360.0 * (float)i / (float)NumberOfPicturesToUse ;
-	
-	Displacement . x = 0 ; Displacement . y = - Radius ;
-	
-	RotateVectorByAngle ( &Displacement , Angle );
-	
-	PrerotationIndex = rintf ( ( Angle  ) * (float)FIXED_NUMBER_OF_SPARK_ANGLES / 360.0 ); 
-	if ( PrerotationIndex >= FIXED_NUMBER_OF_SPARK_ANGLES ) PrerotationIndex = 0 ;
-	
-	if ( ! active_direction [ PrerotationIndex ] ) continue ;
 
-*/
-	
-	//--------------------
-	// Now we handle the emp waves...
-	//
-	if ( ( AllActiveSpells [ i ] . type == SPELL_RADIAL_EMP_WAVE ) ||
-	     ( AllActiveSpells [ i ] . type == SPELL_RADIAL_VMX_WAVE ) ||
-	     ( AllActiveSpells [ i ] . type == SPELL_RADIAL_FIRE_WAVE ) )
-	{
-	    AllActiveSpells [ i ] . spell_radius += 5.0 * PassedTime;
+	// We hardcode a speed here
+        AllActiveSpells [ i ] . spell_radius += 5.0 * PassedTime;
 	    
-	    //--------------------
+            //--------------------
 	    // We do some collision checking with the obstacles in each
 	    // 'active_direcion' of the spell and deactivate those directions,
 	    // where some collision with solid material has happend.
@@ -510,38 +485,14 @@ MoveActiveSpells (void)
 			//--------------------
 			// We do some damage to the enemy in question
 			//
-			switch ( AllActiveSpells [ i ] . type )
-			{
-			    case SPELL_RADIAL_EMP_WAVE:
-				AllEnemys [ j ] . energy -= 80.0 * Frame_Time();
-				if ( AllEnemys [ j ] . energy < 0 )
-				{
-				    sprintf ( game_message_text , "%s was destroyed by radial emp wave." ,
-					      Druidmap [ AllEnemys[j].type ] . druidname );
-				    append_new_game_message ( game_message_text );
-				}
-				break;
-			    case SPELL_RADIAL_VMX_WAVE:
-				AllEnemys [ j ] . energy -= 180.0 * Frame_Time();
-				if ( AllEnemys [ j ] . energy < 0 )
-				{
-				    sprintf ( game_message_text , "%s was destroyed by radial vmx wave." ,
-					      Druidmap [ AllEnemys[j].type ] . druidname );
-				    append_new_game_message ( game_message_text );
-				}
-				break;
-			    case SPELL_RADIAL_FIRE_WAVE:
-				AllEnemys [ j ] . energy -= 300.0 * Frame_Time();
-				if ( AllEnemys [ j ] . energy < 0 )
-				{
-				    sprintf ( game_message_text , "%s was destroyed by radial plasma wave." ,
-					      Druidmap [ AllEnemys[j].type ] . druidname );
-				    append_new_game_message ( game_message_text );
-				}
-				break;
-			    default:
-				break;
-			}
+			if ( AllActiveSpells [ i ] . mine ) 
+				robot_group_turn_hostile(j);
+			AllEnemys [ j ] . energy -= AllActiveSpells [ i ] . damage * Frame_Time();
+			AllEnemys [ j ] . poison_duration_left += AllActiveSpells [ i ] . poison_duration;
+			AllEnemys [ j ] . poison_damage_per_sec = AllActiveSpells [ i ] . damage;
+			AllEnemys [ j ] . frozen += AllActiveSpells [ i ] . freeze_duration;
+			AllEnemys [ j ] . paralysation_duration_left += AllActiveSpells [ i ] . paralyze_duration;
+
 			if ( AllEnemys [ j ] . energy < 0 )  
                                 {
 				int reward = Druidmap [ AllEnemys[j].type ] . experience_reward;
@@ -553,10 +504,6 @@ MoveActiveSpells (void)
 			if(AllEnemys [ j ] . firewait < Druidmap [ AllEnemys [ j ] . type ] . recover_time_after_getting_hit)
 				AllEnemys [ j ] . firewait = Druidmap [ AllEnemys [ j ] . type ] . recover_time_after_getting_hit ;
 		    }
-		    else
-		    {
-			DebugPrintf ( 1 , "\n%s(): Bot is NOT affected.  Doing damage... " , __FUNCTION__ );
-		    }
 		}
 	    }
 	    
@@ -564,7 +511,6 @@ MoveActiveSpells (void)
 	    // Such a spell can not live for longer than 1.0 seconds, say
 	    //
 	    if ( AllActiveSpells [ i ] . spell_age >= 1.0 ) DeleteSpell ( i ) ;
-	}
 	
     }
     
@@ -576,7 +522,7 @@ MoveActiveSpells (void)
 void
 DeleteSpell (int SpellNum)
 {
-  AllActiveSpells [ SpellNum ] . type = ( -1 );
+  AllActiveSpells [ SpellNum ] . img_type = ( -1 );
   AllActiveSpells [ SpellNum ] . spell_age = 0 ;
 }; // void DeleteSpell( int SpellNum )
 
@@ -613,7 +559,7 @@ enemy_spray_blood ( Enemy CurEnemy )
 {
   moderately_finepoint target_pos = { 1.0 , 0 } ;
 
-  DebugPrintf ( 1 , "\nBlood has been sprayed...%s", CurEnemy -> type );
+  DebugPrintf ( 1 , "\nBlood has been sprayed...%d", CurEnemy -> type );
 
   RotateVectorByAngle ( & target_pos , MyRandom ( 360 ) );
 
@@ -701,7 +647,7 @@ handle_flash_effects ( bullet* CurBullet )
 	    enemy_spray_blood ( & ( AllEnemys [ i ] ) ) ;
 	    if ( AllEnemys [ i ] . energy < 0 )
 	    {
-		sprintf ( game_message_text , "%s was destroyed by disruptor blast." ,
+		sprintf ( game_message_text , _("%s was destroyed by disruptor blast."),
 			  Druidmap [ AllEnemys[i].type ] . druidname );
 		append_new_game_message ( game_message_text );
 	    }
@@ -714,7 +660,7 @@ handle_flash_effects ( bullet* CurBullet )
     //
     my_damage = CurBullet -> damage * ( 100 - Me [ 0 ] . resist_disruptor ) / 100 ;
     Me [ 0 ] . energy -= my_damage;
-    sprintf ( game_message_text , "Disruptor blast has hit you for %d damage." ,
+    sprintf ( game_message_text , _("Disruptor blast has hit you for %d damage."),
 	      ((int)my_damage) );
     append_new_game_message ( game_message_text );
     
@@ -767,7 +713,7 @@ apply_bullet_damage_to_player ( int player_num , int damage, int owner )
     if ( MyRandom(100) / monster_level >= Me [ player_num ] . lv_1_bot_will_hit_percentage )
     {
 	Me [ player_num ] . TextVisibleTime = 0 ;
-	Me [ player_num ] . TextToBeDisplayed = "That one went into the armour." ;
+	Me [ player_num ] . TextToBeDisplayed = _("That one went into the armour.");
 	DamageAllEquipment ( player_num ) ;
 	BulletReflectedSound ( ) ;
     }
@@ -917,7 +863,7 @@ check_bullet_enemy_collisions ( bullet* CurBullet , int num )
 			    reward = Druidmap [ ThisRobot -> type ] . experience_reward;
 			    Me [ 0 ] . Experience += reward;
 			    sprintf ( game_message_text , 
-				      "%s was destroyed by your bullet.  For defeating your enemy, you receive %d experience." ,
+				      _("%s was destroyed by your bullet.  For defeating your enemy, you receive %d experience."),
 				      Druidmap [ ThisRobot -> type ] . druidname , 
 				      reward );
 			    append_new_game_message ( game_message_text );
@@ -925,9 +871,9 @@ check_bullet_enemy_collisions ( bullet* CurBullet , int num )
 		  }
 		  else
 		  {
-		      if ( ThisRobot -> energy < 0 )
+		      if ( ThisRobot -> energy < 0 && CurBullet -> owner > 0)
 		      {
-			  sprintf ( game_message_text , "%s was destroyed by bullet from %s." ,
+			  sprintf ( game_message_text , _("%s was destroyed by bullet from %s."),
 				    Druidmap [ ThisRobot -> type ] . druidname ,
 				    Druidmap [ CurBullet -> owner ] . druidname );
 			  append_new_game_message ( game_message_text );
@@ -979,7 +925,7 @@ check_bullet_enemy_collisions ( bullet* CurBullet , int num )
 		{
 		  CurBullet -> total_miss_hit[ i ] = MISS;
 		  ThisRobot -> TextVisibleTime = 0;
-		  ThisRobot -> TextToBeDisplayed = "Haha, you missed me!";
+		  ThisRobot -> TextToBeDisplayed = _("Haha, you missed me!");
 		}
 	    }
 #endif
