@@ -54,31 +54,29 @@ float AC_Gain_Per_Dex_Point[]={     -1 ,     0.5 ,         0.5  ,       0.5 };
 
 #define CLASS_X 175
 
-#define EXPERIENCE_Y 55
+#define EXPERIENCE_Y 56
 #define NEXT_LEVEL_Y 82
 
-#define GOLD_Y 132
+#define GOLD_Y 133
 
-#define DAMAGE_X 260
-#define DAMAGE_Y 225
+#define DAMAGE_X 255
+#define DAMAGE_Y 193
 
-#define RECHARGE_X 260
-#define RECHARGE_Y 200
+#define TOHIT_X 255
+#define TOHIT_Y 167
 
-#define AC_X 260
-#define AC_Y 171
+#define AC_X 255
+#define AC_Y 138
 
-#define LV_1_BOT_HITS_CHANCE_X 254
-#define LV_1_BOT_HITS_CHANCE_Y 249
 
-#define MELEE_SKILL_X 130
-#define MELEE_SKILL_Y 346
-#define RANGED_SKILL_X 130
-#define RANGED_SKILL_Y 373
-#define SPELLCASTING_SKILL_X 130
-#define SPELLCASTING_SKILL_Y 398
-#define HACKING_SKILL_X 130
-#define HACKING_SKILL_Y 421
+#define MELEE_SKILL_X 247
+#define MELEE_SKILL_Y 228
+#define RANGED_SKILL_X MELEE_SKILL_X
+#define RANGED_SKILL_Y 252
+#define SPELLCASTING_SKILL_X MELEE_SKILL_X
+#define SPELLCASTING_SKILL_Y 276
+#define HACKING_SKILL_X MELEE_SKILL_X
+#define HACKING_SKILL_Y 301
 
 /* ----------------------------------------------------------------------
  *
@@ -173,10 +171,10 @@ InitiateNewCharacter ( int PlayerNum , int CharacterClass )
 	    Me [ PlayerNum ] .Inventory[ 3 ].type = ITEM_SMALL_HEALTH_POTION;
 	    Me [ PlayerNum ] .Inventory[ 3 ].inventory_position.x = 1;
 	    Me [ PlayerNum ] .Inventory[ 3 ].inventory_position.y = INVENTORY_GRID_HEIGHT-1;
-	    FillInItemProperties ( & Me [ PlayerNum ] .Inventory[ 0 ] , TRUE , 0 );
-	    FillInItemProperties ( & Me [ PlayerNum ] .Inventory[ 1 ] , TRUE , 0 );
-	    FillInItemProperties ( & Me [ PlayerNum ] .Inventory[ 2 ] , TRUE , 0 );
-	    FillInItemProperties ( & Me [ PlayerNum ] .Inventory[ 3 ] , TRUE , 0 );
+	    FillInItemProperties ( & Me [ PlayerNum ] .Inventory[ 0 ] , TRUE , 0 , 1);
+	    FillInItemProperties ( & Me [ PlayerNum ] .Inventory[ 1 ] , TRUE , 0 , 1);
+	    FillInItemProperties ( & Me [ PlayerNum ] .Inventory[ 2 ] , TRUE , 0 , 1);
+	    FillInItemProperties ( & Me [ PlayerNum ] .Inventory[ 3 ] , TRUE , 0 , 1);
 	    break;
 	    
 	case SNIPER_BOT: 
@@ -196,9 +194,9 @@ InitiateNewCharacter ( int PlayerNum , int CharacterClass )
 	    Me [ PlayerNum ] .Inventory[ 2 ].type = ITEM_SMALL_HEALTH_POTION;
 	    Me [ PlayerNum ] .Inventory[ 2 ].inventory_position.x = 1;
 	    Me [ PlayerNum ] .Inventory[ 2 ].inventory_position.y = INVENTORY_GRID_HEIGHT-1;
-	    FillInItemProperties ( & Me [ PlayerNum ] .Inventory[ 0 ] , TRUE , 0 );
-	    FillInItemProperties ( & Me [ PlayerNum ] .Inventory[ 1 ] , TRUE , 0 );
-	    FillInItemProperties ( & Me [ PlayerNum ] .Inventory[ 2 ] , TRUE , 0 );
+	    FillInItemProperties ( & Me [ PlayerNum ] .Inventory[ 0 ] , TRUE , 0 , 1);
+	    FillInItemProperties ( & Me [ PlayerNum ] .Inventory[ 1 ] , TRUE , 0 , 1);
+	    FillInItemProperties ( & Me [ PlayerNum ] .Inventory[ 2 ] , TRUE , 0 , 1);
 	    break;
 	    
 	case MIND_BOT: 
@@ -218,9 +216,9 @@ InitiateNewCharacter ( int PlayerNum , int CharacterClass )
 	    Me [ PlayerNum ] .Inventory[ 2 ].type = ITEM_SMALL_MANA_POTION;
 	    Me [ PlayerNum ] .Inventory[ 2 ].inventory_position.x = 1;
 	    Me [ PlayerNum ] .Inventory[ 2 ].inventory_position.y = INVENTORY_GRID_HEIGHT-1;
-	    FillInItemProperties ( & Me [ PlayerNum ] .Inventory[ 0 ] , TRUE , 0 );
-	    FillInItemProperties ( & Me [ PlayerNum ] .Inventory[ 1 ] , TRUE , 0 );
-	    FillInItemProperties ( & Me [ PlayerNum ] .Inventory[ 2 ] , TRUE , 0 );
+	    FillInItemProperties ( & Me [ PlayerNum ] .Inventory[ 0 ] , TRUE , 0 , 1);
+	    FillInItemProperties ( & Me [ PlayerNum ] .Inventory[ 1 ] , TRUE , 0 , 1);
+	    FillInItemProperties ( & Me [ PlayerNum ] .Inventory[ 2 ] , TRUE , 0 , 1);
 	    break;
 	default: 
 	    DebugPrintf ( 0 , "\nERROR!! UNKNOWN CHARACTER CLASS REQUESTED!!! Terminating... " );
@@ -231,7 +229,7 @@ InitiateNewCharacter ( int PlayerNum , int CharacterClass )
     UpdateAllCharacterStats( PlayerNum );
     
     Me [ PlayerNum ] .energy = Me [ PlayerNum ] .maxenergy;
-    Me [ PlayerNum ] .mana = Me [ PlayerNum ] .maxmana;
+    Me [ PlayerNum ] .temperature = 0;
     DebugPrintf( 1 , "\n Me [ PlayerNum ] .energy : %f . " , Me [ PlayerNum ] .energy );
     Me [ PlayerNum ] .health = Me [ PlayerNum ] .energy;	/* start with max. health */
     
@@ -243,8 +241,8 @@ InitiateNewCharacter ( int PlayerNum , int CharacterClass )
     Me [ PlayerNum ] .aux1_item.currently_held_in_hand = FALSE;
     Me [ PlayerNum ] .aux2_item.currently_held_in_hand = FALSE;
     
-    FillInItemProperties ( & ( Me [ PlayerNum ] .weapon_item ) , TRUE , 0 );
-    FillInItemProperties ( & ( Me [ PlayerNum ] .drive_item ) , TRUE , 0 );
+    FillInItemProperties ( & ( Me [ PlayerNum ] .weapon_item ) , TRUE , 0 , 1);
+    FillInItemProperties ( & ( Me [ PlayerNum ] .drive_item ) , TRUE , 0 , 1);
     
     
     Item_Held_In_Hand = ( -1 );
@@ -272,7 +270,6 @@ InitiateNewCharacter ( int PlayerNum , int CharacterClass )
 void
 DisplayButtons( void )
 {
-    static int WasPressed;
 
     //--------------------
     // When the Tux has some extra skill points, that can be distributed
@@ -289,7 +286,7 @@ DisplayButtons( void )
     if ( MouseCursorIsOnButton( INV_SCREEN_TOGGLE_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) )
     {
 	ShowGenericButtonFromList ( INV_SCREEN_TOGGLE_BUTTON_YELLOW );
-	if ( axis_is_active && !WasPressed )
+	if ( MouseLeftClicked())
 	{
 	    toggle_game_config_screen_visibility ( GAME_CONFIG_SCREEN_VISIBLE_INVENTORY );
 	    DebugPrintf ( 2 , "\nClick inside inventory button registered..." );
@@ -298,7 +295,7 @@ DisplayButtons( void )
     else if ( MouseCursorIsOnButton( CHA_SCREEN_TOGGLE_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) )
     {
 	ShowGenericButtonFromList ( CHA_SCREEN_TOGGLE_BUTTON_YELLOW );
-	if ( axis_is_active && !WasPressed )
+	if ( MouseLeftClicked() )
 	{
 	    toggle_game_config_screen_visibility ( GAME_CONFIG_SCREEN_VISIBLE_CHARACTER );
 	    DebugPrintf ( 2 , "\nClick inside character button registered..." );
@@ -307,7 +304,7 @@ DisplayButtons( void )
     else if ( MouseCursorIsOnButton( SKI_SCREEN_TOGGLE_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) )
     {
 	ShowGenericButtonFromList ( SKI_SCREEN_TOGGLE_BUTTON_YELLOW );
-	if ( axis_is_active && !WasPressed )
+	if ( MouseLeftClicked() )
 	{
 	    toggle_game_config_screen_visibility ( GAME_CONFIG_SCREEN_VISIBLE_SKILLS );
 	    DebugPrintf ( 2 , "\nClick inside skills button registered..." );
@@ -316,7 +313,7 @@ DisplayButtons( void )
     else if ( MouseCursorIsOnButton( LOG_SCREEN_TOGGLE_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) )
     {
 	ShowGenericButtonFromList ( LOG_SCREEN_TOGGLE_BUTTON_YELLOW );
-	if ( axis_is_active && !WasPressed )
+	if ( MouseLeftClicked() )
 	{
 	    DebugPrintf ( 2 , "\nClick inside questlog button registered..." );
 	    quest_browser_interface ( );
@@ -324,36 +321,21 @@ DisplayButtons( void )
     }
     else if ( MouseCursorIsOnButton( WEAPON_MODE_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) )
     {
-	if ( axis_is_active && !WasPressed )
+	if ( MouseLeftClicked() )
 	{
 	TuxReloadWeapon ( );
 	}
     }
     else if ( MouseCursorIsOnButton( SKI_ICON_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) )
     {
-	if ( axis_is_active && !WasPressed )
+	if ( MouseLeftClicked() )
 	{
         toggle_game_config_screen_visibility ( GAME_CONFIG_SCREEN_VISIBLE_SKILLS );
 	}
     }
     
-    WasPressed = axis_is_active;
-    
 }; // void DisplayButtons( void )
 
-/* ----------------------------------------------------------------------
- * This function checks if a given screen position lies within the 
- * strength plus button or not
- * ---------------------------------------------------------------------- */
-int
-CursorIsOnStrButton( int x , int y )
-{
-    if ( x > CharacterRect.x + BUTTON_MOD_X + STR_NOW_X + BUTTON_WIDTH ) return ( FALSE );
-    if ( x < CharacterRect.x + BUTTON_MOD_X + STR_NOW_X ) return ( FALSE );
-    if ( y > CharacterRect.y + BUTTON_MOD_X + STR_Y + BUTTON_HEIGHT ) return ( FALSE );
-    if ( y < CharacterRect.y + BUTTON_MOD_X + STR_Y ) return ( FALSE );
-    return ( TRUE );
-}; // int CursorIsOnStrButton( int x , int y )
 
 /* ----------------------------------------------------------------------
  * This function adds any bonuses that might be on the influencers things
@@ -374,7 +356,7 @@ AddInfluencerItemAttributeBonus( item* BonusItem )
   // In case of a unique special plugin, we do the nescessary modification
   // here...
   //
-  if ( BonusItem->type == ITEM_START_PLUGIN_WARRIOR )
+/*  if ( BonusItem->type == ITEM_START_PLUGIN_WARRIOR )
     {
       Me [ 0 ] . freezing_melee_targets = 7 ;
     }
@@ -384,12 +366,11 @@ AddInfluencerItemAttributeBonus( item* BonusItem )
     }
   if ( BonusItem->type == ITEM_START_PLUGIN_HACKER )
     {
-      for ( i = 0 ; i < NUMBER_OF_SKILLS ; i ++ ) 
+      for ( i = 0 ; i < number_of_skills ; i ++ ) 
 	{
 	  Me [ 0 ] . SkillLevel [ i ] += 2 ;
 	}
-      // Me [ 0 ] . spell_level_bonus = 2 ;
-    }
+    }*/
 
   //--------------------
   // In case of a suffix modifier, we need to apply the suffix...
@@ -441,10 +422,10 @@ AddInfluencerItemSecondaryBonus( item* BonusItem )
 	// prefix-lists here...
 	//
 	Me [ 0 ] . to_hit    += BonusItem -> bonus_to_tohit ;
-	Me [ 0 ] . maxmana   += BonusItem -> bonus_to_force ;
+	Me [ 0 ] . max_temperature   += BonusItem -> bonus_to_force ;
 	Me [ 0 ] . maxenergy += BonusItem -> bonus_to_life ; 
 	Me [ 0 ] . health_recovery_rate += BonusItem -> bonus_to_health_recovery ; 
-	Me [ 0 ] . mana_recovery_rate += BonusItem -> bonus_to_mana_recovery ; 
+	Me [ 0 ] . cooling_rate += BonusItem -> bonus_to_cooling_rate ; 
 	
 	Me [ 0 ] . resist_disruptor   += BonusItem -> bonus_to_resist_disruptor ;
 	Me [ 0 ] . resist_fire        += BonusItem -> bonus_to_resist_fire ;
@@ -468,7 +449,7 @@ check_for_new_experience_level_reached ( int PlayerNum )
 
     if ( Me [ PlayerNum ] . exp_level >= 24 )
 	{
-	SetNewBigScreenMessage( "Max level reached!");
+	SetNewBigScreenMessage(_("Max level reached!"));
 	return;
 	}
 
@@ -511,7 +492,7 @@ check_for_new_experience_level_reached ( int PlayerNum )
 	// Also when a new level is reached, we will display a big message
 	// right over the combat window.
 	//
-	SetNewBigScreenMessage( "Level Gained!" );
+	SetNewBigScreenMessage(_("Level Gained!"));
 	Takeover_Game_Won_Sound();
     }
 }; // void check_for_new_experience_level_reached ( int PlayerNum )
@@ -539,10 +520,8 @@ update_all_primary_stats ( int PlayerNum )
     //--------------------
     // Now we re-initialize the SKILL LEVELS
     //
-    for ( i = 0 ; i < NUMBER_OF_SKILLS ; i ++ ) 
-    {
-	Me [ PlayerNum ] . SkillLevel [ i ] = Me [ PlayerNum ] . base_skill_level [ i ] ;
-    }
+    for ( i = 0; i < number_of_skills; i ++)
+	 Me [ PlayerNum ] . SkillLevel[i] =  Me [ PlayerNum ] . base_skill_level[i];
 
     //--------------------
     // Now we add all bonuses to the influencers PRIMARY stats
@@ -555,6 +534,31 @@ update_all_primary_stats ( int PlayerNum )
     AddInfluencerItemAttributeBonus( & Me [ PlayerNum ] . aux1_item );
     AddInfluencerItemAttributeBonus( & Me [ PlayerNum ] . aux2_item );
 
+    item * itrot [7] = {  & Me [ PlayerNum ] . armour_item,  & Me [ PlayerNum ] . weapon_item ,  & Me [ PlayerNum ] . drive_item ,  
+    		& Me [ PlayerNum ] . shield_item , & Me [ PlayerNum ] . special_item ,  & Me [ PlayerNum ] . aux1_item ,
+		& Me [ PlayerNum ] . aux2_item };
+    i = 0;
+    while ( i < 7 ) 
+	{
+	if ( itrot [ i ] -> type == -1 ) 
+		{
+		i ++;
+		continue;
+		}
+	if ( ! ItemUsageRequirementsMet ( itrot [ i ] , FALSE ) )
+		{ //we have to move away the item
+		if ( ! AddFloorItemDirectlyToInventory ( itrot [ i ] ) ) itrot [ i ] -> type = -1;
+		else 
+			{ //inventory is full... ouch
+			DropItemToTheFloor(itrot[i], Me[0].pos.x, Me[0].pos.y, Me[0].pos.z);
+			itrot [ i ] -> type = -1;
+			}
+		}
+	i ++;
+	}
+
+
+
     //--------------------
     // Maybe there is some boost from a potion or magic spell going on right
     // now...
@@ -590,7 +594,7 @@ update_secondary_stats_from_primary_stats ( int PlayerNum )
     //--------------------
     // The maximum mana value computed from the primary stats
     //
-    Me [ PlayerNum ] . maxmana = 
+    Me [ PlayerNum ] . max_temperature = 
 	( Me [ PlayerNum ] . Magic )    * Mana_Gain_Per_Magic_Point [ Me [ PlayerNum ] . character_class ];
 
     //--------------------
@@ -607,7 +611,7 @@ update_secondary_stats_from_primary_stats ( int PlayerNum )
     //--------------------
     // base regeneration speed set to 0.2 points per second
     Me [ PlayerNum ] . health_recovery_rate = 0.2;
-    Me [ PlayerNum ] . mana_recovery_rate = 0.2;
+    Me [ PlayerNum ] . cooling_rate = 0.2;
 }; // void update_secondary_stats_from_primary_stats ( int PlayerNum )
 
 /* ----------------------------------------------------------------------
@@ -795,9 +799,9 @@ UpdateAllCharacterStats ( int PlayerNum )
 	
 	
     //--------------------
-    // Check player's health and mana
+    // Check player's health and temperature
     if ( Me [ PlayerNum ] . energy > Me [ PlayerNum ] . maxenergy ) Me [ PlayerNum ] . energy = Me [ PlayerNum ] . maxenergy;
-    if ( Me [ PlayerNum ] . mana > Me [ PlayerNum ] . maxmana ) Me [ PlayerNum ] . mana = Me [ 0 ] . maxmana ;
+    if ( Me [ PlayerNum ] . temperature < 0 ) Me [ PlayerNum ] . temperature = 0;
 
 
     //--------------------
@@ -829,7 +833,7 @@ show_character_screen_skills ( int player_num )
 Error: melee weapon skill seems out of bounds.",
 				   PLEASE_INFORM, IS_FATAL );
     }
-    DisplayText( AllSkillTexts [ Me [ player_num ] . melee_weapon_skill ] , 
+    DisplayText( _(AllSkillTexts [ Me [ player_num ] . melee_weapon_skill ]), 
 		 MELEE_SKILL_X + CharacterRect.x , MELEE_SKILL_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
 
     //--------------------
@@ -844,7 +848,7 @@ Error: melee weapon skill seems out of bounds.",
 Error: ranged weapon skill seems out of bounds.",
 				   PLEASE_INFORM, IS_FATAL );
     }
-    DisplayText( AllSkillTexts [ Me [ player_num ] . ranged_weapon_skill ] , 
+    DisplayText( _(AllSkillTexts [ Me [ player_num ] . ranged_weapon_skill ]), 
 		 RANGED_SKILL_X + CharacterRect.x , RANGED_SKILL_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
 
     //--------------------
@@ -854,12 +858,12 @@ Error: ranged weapon skill seems out of bounds.",
     if ( ( Me [ player_num ] . spellcasting_skill < 0 ) ||
 	 ( Me [ player_num ] . spellcasting_skill >= NUMBER_OF_SKILL_LEVELS ) )
     {
-	fprintf ( stderr , "\nspellcasting_skill: %d." , Me [ player_num ] . spellcasting_skill );
+	fprintf ( stderr , "\nProgramming_Skill: %d." , Me [ player_num ] . spellcasting_skill );
 	GiveStandardErrorMessage ( __FUNCTION__ , "\
-Error: spellcasting skill seems out of bounds.",
+Error: Programming_Skill skill seems out of bounds.",
 				   PLEASE_INFORM, IS_FATAL );
     }
-    DisplayText( AllSkillTexts [ Me [ player_num ] . spellcasting_skill ] , 
+    DisplayText( _(AllSkillTexts [ Me [ player_num ] . spellcasting_skill ]), 
 		 SPELLCASTING_SKILL_X + CharacterRect.x , SPELLCASTING_SKILL_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
 
     //--------------------
@@ -874,7 +878,7 @@ Error: spellcasting skill seems out of bounds.",
 Error: hacking skill seems out of bounds.",
 				   PLEASE_INFORM, IS_FATAL );
     }
-    DisplayText( AllSkillTexts [ Me [ player_num ] . hacking_skill ] , 
+    DisplayText( _(AllSkillTexts [ Me [ player_num ] . hacking_skill ]), 
 		 HACKING_SKILL_X + CharacterRect.x , HACKING_SKILL_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
 
     /*
@@ -903,7 +907,7 @@ ShowCharacterScreen ( int player_num )
     //
     if ( GameConfig.CharacterScreen_Visible == FALSE ) return;
 
-    SetCurrentFont ( FPS_Display_BFont );
+    SetCurrentFont ( Message_BFont );
     
     // --------------------
     // We will need the current mouse position on several spots...
@@ -922,16 +926,10 @@ ShowCharacterScreen ( int player_num )
     
     blit_special_background ( CHARACTER_SCREEN_BACKGROUND_CODE );
     
-    //--------------------
-    // Now we can start to fill in the character values:
-    // Name, Class, Level, Exp, Strength, Dex, ...
-    //
-    DisplayText( Me[0].character_name , 20 + CharacterRect.x , 18 + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
+    SetCurrentFont ( Menu_BFont );
+    DisplayText( Me[0].character_name , 20 + CharacterRect.x , 12 + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
+    SetCurrentFont ( Message_BFont );
     
-    if ( Me [ 0 ] . is_town_guard_member )
-	DisplayText( "Red Guard" , CLASS_X + CharacterRect . x , 18 + CharacterRect . y , &CharacterRect , TEXT_STRETCH );
-    else
-	DisplayText( "Novice" , CLASS_X + CharacterRect . x , 18 + CharacterRect . y , &CharacterRect , TEXT_STRETCH );
     
     /*
       switch ( Me[0].character_class )
@@ -952,88 +950,65 @@ ShowCharacterScreen ( int player_num )
       }
     */
     
-    sprintf( CharText , "%4d", Me[0].exp_level );
-    DisplayText( CharText , 62 + CharacterRect.x , 56 + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
+    sprintf( CharText , "%d", Me[0].exp_level );
+    DisplayText( CharText , 110 + CharacterRect.x , 73 + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
     
-    // Me[0].Experience = RealScore;
-    sprintf( CharText , "%6ld", Me[0].Experience ); // this should be the real score, sooner or later
-    DisplayText( CharText , 240 + CharacterRect.x ,  EXPERIENCE_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
+    sprintf( CharText , "%lu", Me[0].Experience ); 
+    DisplayText( CharText , 110 + CharacterRect.x ,  89 + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
     
-    sprintf( CharText , "%6ld", Me[0].ExpRequired ); 
-    DisplayText( CharText , 240 + CharacterRect.x ,  NEXT_LEVEL_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH ) ;
+    sprintf( CharText , "%lu", Me[0].ExpRequired );
+    DisplayText( CharText , 110 + CharacterRect.x ,  107 + CharacterRect.y , &CharacterRect , TEXT_STRETCH ) ;
     
     sprintf( CharText , "%6ld", Me[0].Gold ); 
-    DisplayText( CharText , 240 + CharacterRect.x ,  GOLD_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
+    DisplayText( CharText , 240 + CharacterRect.x ,  71 + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
     
-    SetCurrentFont( FPS_Display_BFont) ;
-    sprintf( CharText , "%d", Me[0].base_strength );
-    DisplayText( CharText , STR_BASE_X + CharacterRect.x , STR_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
-    sprintf( CharText , "%d", Me[0].Strength );
-    if ( Me[0].Strength != Me[0].base_strength ) SetCurrentFont( Red_BFont) ;
-    DisplayText( CharText , STR_NOW_X + CharacterRect.x , STR_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
+    SetCurrentFont( Message_BFont) ;
+    sprintf( CharText , "%d", Me[0].Strength);
+    if ( Me[0].Strength != Me[0].base_strength ) 
+	sprintf ( CharText + strlen(CharText), " (%+d)", Me[0].Strength - Me[0].base_strength); 
+    DisplayText( CharText , STR_X + CharacterRect.x , STR_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
     
-    SetCurrentFont( FPS_Display_BFont) ;
-    sprintf( CharText , "%d", Me[0].base_magic );
-    DisplayText( CharText , 100 + CharacterRect.x , MAG_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
+    SetCurrentFont( Message_BFont) ;
     sprintf( CharText , "%d", Me[0].Magic );
-    if ( Me[0].Magic != Me[0].base_magic ) SetCurrentFont( Red_BFont) ;
-    DisplayText( CharText , 148 + CharacterRect.x , MAG_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
+    if ( Me[0].Magic != Me[0].base_magic ) 
+	sprintf ( CharText + strlen(CharText), " (%+d)", Me[0].Magic - Me[0].base_magic); 
+    DisplayText( CharText , STR_X + CharacterRect.x , MAG_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
     
-    SetCurrentFont( FPS_Display_BFont) ;
-    sprintf( CharText , "%d", Me[0].base_dexterity );
-    DisplayText( CharText , 100 + CharacterRect.x , DEX_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
+    SetCurrentFont( Message_BFont) ;
     sprintf( CharText , "%d", Me[0].Dexterity );
-    if ( Me[0].Dexterity != Me[0].base_dexterity ) SetCurrentFont( Red_BFont) ;
-    DisplayText( CharText , 148 + CharacterRect.x , DEX_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
+    if ( Me[0].Dexterity != Me[0].base_dexterity ) 
+	sprintf ( CharText + strlen(CharText), " (%+d)", Me[0].Dexterity - Me[0].base_dexterity); 
+    DisplayText( CharText , STR_X + CharacterRect.x , DEX_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
     
-    SetCurrentFont( FPS_Display_BFont) ;
-    sprintf( CharText , "%d", Me[0].base_vitality );
-    DisplayText( CharText , 100 + CharacterRect.x , VIT_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
+    SetCurrentFont( Message_BFont) ;
     sprintf( CharText , "%d", Me[0].Vitality );
-    if ( Me[0].Vitality != Me[0].base_vitality ) SetCurrentFont( Red_BFont) ;
-    DisplayText( CharText , 148 + CharacterRect.x , VIT_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
+    if ( Me[0].Vitality != Me[0].base_vitality ) 
+	sprintf ( CharText + strlen(CharText), " (%+d)", Me[0].Vitality - Me[0].base_vitality); 
+    DisplayText( CharText , STR_X + CharacterRect.x , VIT_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
     
-    SetCurrentFont( FPS_Display_BFont) ;
+    SetCurrentFont( Message_BFont) ;
     sprintf( CharText , "%d", Me[0].points_to_distribute );
-    DisplayText( CharText , 100 + CharacterRect.x , POINTS_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
+    DisplayText( CharText , STR_X + CharacterRect.x , POINTS_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
     
-    sprintf( CharText , "%d", (int) Me[0].maxenergy );
-    DisplayText( CharText , 95 + CharacterRect.x , 293 + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
+    sprintf( CharText , "%d/%d", (int) Me[0].energy, (int) Me[0].maxenergy );
+    DisplayText( CharText , 105 + CharacterRect.x , 289 + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
     
-    sprintf( CharText , "%d", (int) Me[0].energy );
-    DisplayText( CharText , 143 + CharacterRect.x , 293 + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
-    
-    sprintf( CharText , "%d", (int) Me[0].maxmana );
-    DisplayText( CharText , 95 + CharacterRect.x , 318 + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
-    
-    sprintf( CharText , "%d", (int) Me[0].mana );
-    DisplayText( CharText , 143 + CharacterRect.x , 318 + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
-    
-    sprintf( CharText , "%d-%d", (int) Me[0].base_damage , (int) Me[0].base_damage + (int) Me[0].damage_modifier );
-    DisplayText( CharText , DAMAGE_X + CharacterRect.x , DAMAGE_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
-    
-    // sprintf( CharText , "%d", (int) Me[0].RechargeTimeModifier );
-    sprintf( CharText , "%d", (int) Me[0].to_hit );
-    strcat( CharText , "%" );
-    DisplayText( CharText , RECHARGE_X + CharacterRect.x , RECHARGE_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
+    sprintf( CharText , "%d/%d", (int) Me [ 0 ] . temperature, (int) Me[0].max_temperature );
+    DisplayText( CharText , 105 + CharacterRect.x , 308+ CharacterRect.y , &CharacterRect , TEXT_STRETCH );
+
+    sprintf( CharText , "%d/%d", (int) Me [ 0 ] . running_power, (int) Me [ 0 ] . max_running_power );
+    DisplayText( CharText , 105 + CharacterRect.x , 327 + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
     
     sprintf( CharText , "%d", (int) Me[0].AC );
     DisplayText( CharText , AC_X + CharacterRect.x , AC_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
+
+    sprintf( CharText , "%d%%", (int) Me[0].to_hit );
+    DisplayText( CharText , TOHIT_X + CharacterRect.x , TOHIT_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
+
+    sprintf( CharText , "%d-%d", (int) Me[0].base_damage , (int) Me[0].base_damage + (int) Me[0].damage_modifier );
+    DisplayText( CharText , DAMAGE_X + CharacterRect.x , DAMAGE_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
+    
     
-    sprintf( CharText , " %d%%", (int) Me [ 0 ] . lv_1_bot_will_hit_percentage );
-    DisplayText( CharText , LV_1_BOT_HITS_CHANCE_X + CharacterRect.x , LV_1_BOT_HITS_CHANCE_Y + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
-
-    //--------------------
-    // We fill in the numbers for the current running power.
-    //
-    sprintf( CharText , "%3d", (int) Me [ 0 ] . max_running_power );
-    DisplayText( CharText , 223 + CharacterRect.x , 275 + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
-    sprintf( CharText , "%3d", (int) Me [ 0 ] . running_power );
-    DisplayText( CharText , 269 + CharacterRect.x , 275 + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
-
-
-    sprintf( CharText , "%3d", (int) Me [ 0 ] . resist_disruptor );
-    DisplayText( CharText , 269 + CharacterRect.x , 305 + CharacterRect.y , &CharacterRect , TEXT_STRETCH );
     
     //--------------------
     // Now we print out the current skill levels in hacking skill, 
@@ -1055,8 +1030,8 @@ ShowCharacterScreen ( int player_num )
 void
 HandleCharacterScreen ( int player_num )
 {
-    static int MouseButtonPressedPreviousFrame = FALSE;
 
+    if ( ! GameConfig . CharacterScreen_Visible ) return;
     //--------------------
     // It might be the case, that the character has some points to distribute upon the character
     // stats.  Then of course, we must display the plus button instead of all character 'now' values
@@ -1064,35 +1039,35 @@ HandleCharacterScreen ( int player_num )
     // Me[0].points_to_distribute = 5;
     if ( Me[0].points_to_distribute > 0 )
     {
-	if ( MouseCursorIsOnButton( MORE_STR_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && ( axis_is_active ) && ( ! MouseButtonPressedPreviousFrame ) )
+	if ( MouseCursorIsOnButton( MORE_STR_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && MouseLeftClicked() )
 	{
 	    Me[0].base_strength++;
 	    Me[0].points_to_distribute--;
 	    if ( Me[0].points_to_distribute <= 0 )
 	    {
-		while ( SpacePressed() );
+		while ( MouseLeftPressed() );
 	    }
 	}
-	if ( MouseCursorIsOnButton( MORE_DEX_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && ( axis_is_active ) && ( ! MouseButtonPressedPreviousFrame ) )
+	if ( MouseCursorIsOnButton( MORE_DEX_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && MouseLeftClicked() )
 	{
 	    Me[0].base_dexterity++;
 	    Me[0].points_to_distribute--;
 	    if ( Me[0].points_to_distribute <= 0 )
 	    {
-		while ( SpacePressed() );
+		while ( MouseLeftPressed() );
 	    }
 	}
-	if ( MouseCursorIsOnButton( MORE_MAG_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && ( axis_is_active ) && ( ! MouseButtonPressedPreviousFrame ) )
+	if ( MouseCursorIsOnButton( MORE_MAG_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && MouseLeftClicked() )
 	{
 	    Me[0].base_magic++;
 	    Me[0].points_to_distribute--;
-	    Me[0].mana += Mana_Gain_Per_Magic_Point [ Me [ 0 ] . character_class ];
+	    Me[0].max_temperature += Mana_Gain_Per_Magic_Point [ Me [ 0 ] . character_class ];
 	    if ( Me[0].points_to_distribute <= 0 )
 	    {
-		while ( SpacePressed() );
+		while ( MouseLeftPressed() );
 	    }
 	}
-	if ( MouseCursorIsOnButton( MORE_VIT_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && ( axis_is_active ) && ( ! MouseButtonPressedPreviousFrame ) )
+	if ( MouseCursorIsOnButton( MORE_VIT_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && MouseLeftClicked() )
 	{
 	    Me[0].base_vitality++;
 	    Me[0].points_to_distribute--;
@@ -1102,7 +1077,7 @@ HandleCharacterScreen ( int player_num )
 	    Me[0].energy += Energy_Gain_Per_Vit_Point [ Me [ 0 ] . character_class ];	  
 	    if ( Me[0].points_to_distribute <= 0 )
 	    {
-		while ( SpacePressed() );
+		while ( MouseLeftPressed() );
 	    }
 	}
 	
@@ -1114,14 +1089,6 @@ HandleCharacterScreen ( int player_num )
     }
     
     
-    //--------------------
-    // We want to know, if the button was pressed the previous frame when we
-    // are in the next frame and back in this function.  Therefore we store
-    // the current button situation, so that we can conclude on button just
-    // pressed later.
-    //
-    MouseButtonPressedPreviousFrame = axis_is_active;
-
 }; // HandleCharacterScreen ( void )
 
 #undef _character_c
