@@ -47,7 +47,8 @@ dialogue_option ChatRoster[MAX_DIALOGUE_OPTIONS_IN_ROSTER];
 EXTERN char *PrefixToFilename[ ENEMY_ROTATION_MODELS_AVAILABLE ];
 char* chat_protocol = NULL ;
 
-char *language_dirs[] = { "", "de/", "" };
+char *language_dirs[] = { "", "de/", "fr/", "pl/", "" };
+char *language_font_classes[] = { "", "", "", ".8859-2", "" };
  
 void DoChatFromChatRosterData( int PlayerNum , int ChatPartnerCode , Enemy ChatDroid , int ClearProtocol );
 
@@ -120,7 +121,13 @@ ResolveDialogSectionToChatFlagsIndex ( char* SectionName )
     if ( strcmp ( SectionName , "Kevin" ) == 0 ) return PERSON_KEVIN;
     if ( strcmp ( SectionName , "Jasmine" ) == 0 ) return PERSON_JASMINE;
     if ( strcmp ( SectionName , "Lukas" ) == 0 ) return PERSON_LUKAS;
-
+    if ( strcmp ( SectionName , "SADD" ) == 0 ) return PERSON_SADD;
+    if ( strcmp ( SectionName , "Tania" ) == 0 ) return PERSON_TANIA;
+    if ( strcmp ( SectionName , "SACD" ) == 0 ) return PERSON_SACD;
+    if ( strcmp ( SectionName , "Koan" ) == 0 ) return PERSON_KOAN;
+    if ( strcmp ( SectionName , "Boris" ) == 0 ) return PERSON_BORIS;
+    if ( strcmp ( SectionName , "Lina" ) == 0 ) return PERSON_LINA;
+    if ( strcmp ( SectionName , "Serge" ) == 0 ) return PERSON_SERGE;
     if ( strncmp ( SectionName , "subdlg_" , 6 ) == 0 ) return PERSON_SUBDIALOG_DUMMY;
 
     DebugPrintf ( -1000 , "\n--------------------\nSectionName: %s." , SectionName );
@@ -135,7 +142,7 @@ corresponding chat flags array index." ,
 
 /* ----------------------------------------------------------------------
  * This function plants a cookie, i.e. sets a new text string with the
- * purpose of serving as a flag.  These flags can be set from the dialog
+ * purpose of serving as a flag.  These flags can be set/unset from the dialog
  * file and used from within there and they get stored and loaded with
  * every gave via the tux_t structure.
  * ---------------------------------------------------------------------- */
@@ -223,6 +230,53 @@ This should not be possible without a severe bug in FreedroidRPG.",
     
 }; // void PlantCookie ( char* CookieString , int PlayerNum )
 
+
+/* ----------------------------------------------------------------------
+ * This function deletes planted cookie, i.e. delete a text string with the
+ * purpose of serving as a flag.  These flags can be set/unset from the dialog
+ * file and used from within there and they get stored and loaded with
+ * every gave via the tux_t structure.
+ * ---------------------------------------------------------------------- */
+void
+DeleteCookie ( char* CookieString , int PlayerNum )
+{
+    DebugPrintf ( -4 , "\nDeleting cookie: '%s'." , CookieString );
+    
+    if ( strlen ( CookieString ) > 1 )
+    {
+	DebugPrintf ( 1 , "\nLast character of cookie text received: %c." , 
+		      CookieString [ strlen ( CookieString ) - 1 ] );
+	if ( CookieString [ strlen ( CookieString ) - 1 ] == ':' )
+	{
+	    CookieString [ strlen ( CookieString ) - 1 ] = 0 ;
+	    DebugPrintf ( 1 , "\nRemoving trailing ':' character from cookie text...");
+	}
+    }
+
+    int i;
+    for ( i = 0 ; i < MAX_COOKIES ; i ++ )
+	{
+	DebugPrintf ( 1 , "\nCookie entry to compare to: %s." , Me [ PlayerNum ] . cookie_list [ i ] );
+	if ( ! strlen ( Me [ PlayerNum ] . cookie_list [ i ] ) ) continue;
+	if ( ! strcmp ( Me [ PlayerNum ] . cookie_list [ i ] , CookieString ) ) 
+		break;
+	//--------------------
+	// Now some extra safety, cause the ':' termination character might still be on 
+	// the cookie or on the comparison string
+	//
+	if ( strcmp ( Me [ 0 ] . cookie_list [ i ] , CookieString ) >= ( ( int ) strlen ( CookieString ) ) ) 
+	    break; 
+	}
+	
+    if (i == MAX_COOKIES){
+        DebugPrintf ( -4 , "Cookie not found.");
+    } else {
+	strcpy ( Me [ 0 ] . cookie_list [ i ] , "" ) ;
+	DebugPrintf ( 1 , "Cookie deleted.");
+    }
+}; // void DeleteCookie ( char* CookieString , int PlayerNum )
+
+
 /* ----------------------------------------------------------------------
  * This function restores all chat-with-friendly-droid variables to their
  * initial values.  This means, that NOT ALL FLAGS CAN BE SET HERE!!  Some
@@ -420,7 +474,7 @@ ExecuteChatExtra ( char* ExtraCommandString , Enemy ChatDroid )
     char *TempMessage;
     item NewItem;
     char tmp_filename [ 5000 ] ;
-    char* fpath;
+    char fpath[2048];
     int i;
     int mis_num , mis_diary_entry_num;
     
@@ -467,6 +521,10 @@ ExecuteChatExtra ( char* ExtraCommandString , Enemy ChatDroid )
 	ChatDroid -> CompletelyFixed = FALSE ;
 	ChatDroid -> follow_tux = FALSE ;
     }
+    else if ( ! strcmp ( ExtraCommandString , "KillTux" ) )
+    {
+	Me [ 0 ] . energy = 0;
+    }
     else if ( ! strcmp ( ExtraCommandString , "MakeTuxTownGuardMember" ) )
     {
 	DebugPrintf ( -1000 , "\nTux should now be a member of the old town's guard." );
@@ -486,64 +544,107 @@ ExecuteChatExtra ( char* ExtraCommandString , Enemy ChatDroid )
     else if ( ! strcmp ( ExtraCommandString , "IncreaseSpellcastingSkill" ) )
     {
 	ImproveSkill(&Me [ 0 ] . spellcasting_skill); 
-	SetNewBigScreenMessage( "Spellcasting ability improved!" );
+	SetNewBigScreenMessage( "Programming skill increased!" );
     }
     else if ( ! strcmp ( ExtraCommandString , "IncreaseHackingSkill" ) )
     {
 	ImproveSkill(&Me [ 0 ] . hacking_skill); 
 	SetNewBigScreenMessage( "Hacking ability improved!" );
     }
-    else if ( ! strcmp ( ExtraCommandString , "IncreaseExtractPlasmaTransistorSkill" ) )
+    else if ( CountStringOccurences ( ExtraCommandString , "IncreaseProgramVersionName:" ) )
     {
-	Me [ 0 ] . base_skill_level [ SPELL_EXTRACT_PLASMA_TRANSISTORS ] ++; 
-	SetNewBigScreenMessage( "transistors learned!" );
-	SetNewBigScreenMessage( "Extraction of plasma" );
+	DebugPrintf( CHAT_DEBUG_LEVEL , "\nExtra invoked increasing program version. --> have to decode... " );
+	char * pos = strstr(ExtraCommandString, "IncreaseProgramVersionName");
+	pos += strlen("IncreaseProgramVersionName:");
+	char * pos2 = pos;
+	while ( * pos2 != '\"') pos2++;
+	char pname [ pos2 - pos + 1 ];
+	strncpy(pname, pos, pos2 - pos);
+	pname[pos2-pos] = 0;
+	DebugPrintf( CHAT_DEBUG_LEVEL , "\n...decoding...Program name is: %d." , pname );
+	Me [ 0 ] . base_skill_level [ get_program_index_with_name(pname) ] ++;
     }
-    else if ( ! strcmp ( ExtraCommandString , "IncreaseExtractSuperconductorSkill" ) )
+    else if ( CountStringOccurences ( ExtraCommandString , "TuxLoseHP:" ) )
     {
-	Me [ 0 ] . base_skill_level [ SPELL_EXTRACT_SUPERCONDUCTORS ] ++; 
-	SetNewBigScreenMessage( "Extraction of superconductors learned!" );
+	char * pos = strstr(ExtraCommandString, "TuxLoseHP");
+	pos += strlen("TuxLoseHP:");
+	while ( ! isdigit ( * pos ) || *pos != '-' ) pos ++;
+	char * pos2 = pos;
+	while ( isdigit(*pos2) || *pos2 == '-' ) pos2++;
+	char pname [ pos2 - pos + 1 ];
+	strncpy(pname, pos, pos2 - pos);
+	pname[pos2-pos] = 0;
+	Me [ 0 ] . energy -= atoi ( pname ) ;
     }
-    else if ( ! strcmp ( ExtraCommandString , "IncreaseExtractConverterSkill" ) )
+    else if ( CountStringOccurences ( ExtraCommandString , "DeleteItem:" ) )
     {
-	Me [ 0 ] . base_skill_level [ SPELL_EXTRACT_ANTIMATTER_CONVERTERS ] ++; 
-	SetNewBigScreenMessage( "converters learned!" );
-	SetNewBigScreenMessage( "Extraction of antimatter-matter" );
-    }
-    else if ( ! strcmp ( ExtraCommandString , "IncreaseExtractInverterSkill" ) )
-    {
-	Me [ 0 ] . base_skill_level [ SPELL_EXTRACT_ENTROPY_INVERTERS ] ++; 
-	SetNewBigScreenMessage( "Extraction of entropy inverters learned!" );
-    }
-    else if ( ! strcmp ( ExtraCommandString , "IncreaseExtractCondensatorSkill" ) )
-    {
-	Me [ 0 ] . base_skill_level [ SPELL_EXTRACT_TACHYON_CONDENSATORS ] ++; 
-	SetNewBigScreenMessage( "condensators learned!" );
-	SetNewBigScreenMessage( "Extraction of tachyon " );
+	char * pos = strstr(ExtraCommandString, "DeleteItem");
+	pos += strlen("DeleteItem:");
+	while ( ! isdigit(*pos) ) pos ++;
+	char * pos2 = pos;
+	while ( isdigit(*pos2) ) pos2 ++;
+	
+	char pname[15];
+	int multiplicity = 1;
+
+	strncpy(pname, pos, pos2-pos);
+	pname[pos2-pos] = 0;
+	TempValue = atoi(pname);
+
+	if(*pos2 == ':')
+	    {
+	    pos=pos2 + 1;
+	    pos2 ++;
+            while( isdigit(*pos2) ) pos2++;
+	    strncpy(pname, pos, pos2-pos);
+	    multiplicity = atoi(pname);
+	    }
+	else multiplicity = 1;
+
+	DeleteInventoryItemsOfType( TempValue , multiplicity, 0 );      
     }
     else if ( CountStringOccurences ( ExtraCommandString , "GiveItem:" ) )
     {
-	DebugPrintf( CHAT_DEBUG_LEVEL , "\nExtra invoked giving an item to the Tux. --> have to decode... " );
-	ReadValueFromString( ExtraCommandString , "GiveItem:" , "%d" , 
-			     &TempValue , ExtraCommandString + strlen ( ExtraCommandString ) + 0 );
-	DebugPrintf( CHAT_DEBUG_LEVEL , "\n...decoding...item to give is: %d." , TempValue );
+	char * pos = strstr(ExtraCommandString, "GiveItem");
+	pos += strlen("GiveItem:");
+	while ( ! isdigit(*pos) ) pos ++;
+	char * pos2 = pos;
+	while ( isdigit(*pos2) ) pos2 ++;
+	
+	char pname[15];
+	strncpy(pname, pos, pos2-pos);
+	pname[pos2-pos] = 0;
+	TempValue = atoi(pname);
+
 	NewItem.type = TempValue  ;
 	NewItem.prefix_code = (-1);
 	NewItem.suffix_code = (-1);
-	FillInItemProperties ( &NewItem , TRUE , 0 );
+	FillInItemProperties ( &NewItem , TRUE , 0 , 1);
+
+	if(*pos2 == ':')
+	    {
+	    pos=pos2 + 1;
+	    pos2 ++;
+            while( isdigit(*pos2) ) pos2++;
+	    strncpy(pname, pos, pos2-pos);
+	    NewItem.multiplicity = atoi(pname);
+	    }
+	else NewItem.multiplicity = 1;
+
+
 	//--------------------
 	// Either we put the new item directly into inventory or we issue a warning
 	// that there is no room and then drop the item to the floor directly under 
 	// the current Tux position.  That can't fail, right?
 	//
-	if ( !TryToIntegrateItemIntoInventory ( & NewItem , 1 ) )
+	if ( !TryToIntegrateItemIntoInventory ( & NewItem , NewItem.multiplicity ) )
 	{
 	    DropItemToTheFloor ( &NewItem , Me [ 0 ] . pos . x , Me [ 0 ] . pos . y , Me [ 0 ] . pos. z ) ;
-	    SetNewBigScreenMessage( "1 Item received (on floor)" );
+	    SetNewBigScreenMessage( _("1 Item received (on floor)") );
 	}
 	else
 	{
-	    SetNewBigScreenMessage( "1 Item received!" );
+	    SetNewBigScreenMessage( _("1 Item received!") );
 	}
     }
     else if ( CountStringOccurences ( ExtraCommandString , "OpenQuestDiaryEntry:" ) )
@@ -578,7 +679,7 @@ ExecuteChatExtra ( char* ExtraCommandString , Enemy ChatDroid )
 	strcat ( tmp_filename , ".dialog" );
 	char finaldir[50];
 	sprintf(finaldir, "%s%s", DIALOG_DIR, language_dirs[GameConfig.language]);
-	fpath = find_file ( tmp_filename , finaldir, FALSE);
+	find_file (tmp_filename , finaldir, fpath, 0);
 	
 	for ( i = 0 ; i < MAX_DIALOGUE_OPTIONS_IN_ROSTER ; i ++ )
 	{
@@ -591,10 +692,9 @@ ExecuteChatExtra ( char* ExtraCommandString , Enemy ChatDroid )
 	}
 	
 	LoadChatRosterWithChatSequence ( fpath );
-	// ChatDroid -> will_rush_tux = TRUE ;
-	ChatDroid -> combat_state = RUSH_TUX_ON_SIGHT_AND_OPEN_TALK ;
 	DoChatFromChatRosterData( 0 , PERSON_SUBDIALOG_DUMMY , ChatDroid , FALSE );
-	
+	if ( ! ChatDroid -> energy ) //if the droid was killed, end the chat
+		return 1;
 	push_or_pop_chat_roster ( POP_ROSTER );
 	
     }
@@ -604,6 +704,12 @@ ExecuteChatExtra ( char* ExtraCommandString , Enemy ChatDroid )
 		     ExtraCommandString + strlen ( "PlantCookie:" ) );
 	PlantCookie ( ExtraCommandString + strlen ( "PlantCookie:" ) , 0 ) ;
     }
+    else if ( CountStringOccurences ( ExtraCommandString , "DeleteCookie:" ) )
+    {
+	DebugPrintf( CHAT_DEBUG_LEVEL , "\nExtra invoked deleting of a cookie: %s. Doing it... " ,
+		     ExtraCommandString + strlen ( "DeleteCookie:" ) );
+	DeleteCookie ( ExtraCommandString + strlen ( "DeleteCookie:" ) , 0 ) ;
+    }
     else if ( CountStringOccurences ( ExtraCommandString , "InitTradeWithCharacter:" ) )
     {
 	TempValue = ResolveDialogSectionToChatFlagsIndex ( ExtraCommandString + strlen ( "InitTradeWithCharacter:" ) ) ;
@@ -694,40 +800,6 @@ ExecuteChatExtra ( char* ExtraCommandString , Enemy ChatDroid )
 	sprintf ( WorkString , "%d bucks received" , TempValue );
 	SetNewBigScreenMessage ( WorkString );
     }
-    else if ( CountStringOccurences ( ExtraCommandString , "DeleteAllInventoryItemsWithCode:" ) )
-    {
-	DebugPrintf( CHAT_DEBUG_LEVEL , "\nExtra invoked deletion of all inventory items with a certain code. --> have to decode... " );
-	ReadValueFromString( ExtraCommandString , "DeleteAllInventoryItemsWithCode:" , "%d" , 
-			     &TempValue , ExtraCommandString + strlen ( ExtraCommandString ) + 0 );
-	DebugPrintf( CHAT_DEBUG_LEVEL , "\n...decoding... code of item to delete found is: %d." , TempValue );
-	DeleteAllInventoryItemsOfType( TempValue , 0 );      
-    }
-    else if ( CountStringOccurences ( ExtraCommandString , "DeleteAllInventoryItemsOfType:" ) )
-    {
-	DebugPrintf( CHAT_DEBUG_LEVEL , "\nExtra invoked deletion of all inventory items of type '%s'. --> have to decode... " ,
-		     ExtraCommandString + strlen ( "DeleteAllInventoryItemsOfType:" ) );
-	
-	if ( !strcmp ( ExtraCommandString + strlen ( "DeleteAllInventoryItemsOfType:" ) , "ITEM_DIXONS_TOOLBOX" ) )
-	{
-	    TempValue = ITEM_DIXONS_TOOLBOX;
-	}
-	else if ( !strcmp ( ExtraCommandString + strlen ( "DeleteAllInventoryItemsOfType:" ) , "ITEM_RED_DILITIUM_CRYSTAL" ) )
-	{
-	    TempValue = ITEM_RED_DILITIUM_CRYSTAL;
-	}
-	else
-	{
-	    fprintf( stderr, "\n\nErrorneous string: %s \n" , 
-		     ExtraCommandString + strlen ( "DeleteAllInventoryItemsOfType:" ) );
-	    GiveStandardErrorMessage ( __FUNCTION__  , "\
-ERROR:  UNKNOWN ITEM STRING GIVEN AS ITEM TO DELETE FROM INVENTORY!",
-				       PLEASE_INFORM, IS_FATAL );
-	}
-	
-	DebugPrintf( CHAT_DEBUG_LEVEL , "\n...decoding...item to remove is: %d." , TempValue );
-	DeleteAllInventoryItemsOfType( TempValue , 0 );      
-	
-    }
     else if ( ! strcmp ( ExtraCommandString , "CompletelyHealTux" ) )
     {
 	Me [ 0 ] . energy = Me [ 0 ] . maxenergy ;
@@ -755,7 +827,7 @@ make_sure_chat_portraits_loaded_for_this_droid ( Enemy this_droid )
 {
     SDL_Surface* Small_Droid;
     SDL_Surface* Large_Droid;
-    char *fpath;
+    char fpath[2048];
     char fname[500];
     int i;
     int model_number;
@@ -794,7 +866,7 @@ make_sure_chat_portraits_loaded_for_this_droid ( Enemy this_droid )
     strcpy( fname, "droids/" );
     strcat( fname, PrefixToFilename [ model_number ] ) ;
     strcat( fname , "/portrait.png" );
-    fpath = find_file (fname, GRAPHICS_DIR, FALSE);
+    find_file (fname, GRAPHICS_DIR, fpath, 0);
     DebugPrintf ( 2 , "\nFilename used for portrait: %s." , fpath );
     
     Small_Droid = our_IMG_load_wrapper (fpath) ;
@@ -802,7 +874,7 @@ make_sure_chat_portraits_loaded_for_this_droid ( Enemy this_droid )
     {
 	strcpy( fname, "droids/" );
 	strcat( fname, "DefaultPortrait.png" );
-	fpath = find_file (fname, GRAPHICS_DIR, FALSE);
+	find_file (fname, GRAPHICS_DIR, fpath, 0);
 	Small_Droid = our_IMG_load_wrapper ( fpath ) ;
     }
     if ( Small_Droid == NULL )
@@ -835,7 +907,7 @@ make_sure_all_chat_portraits_are_loaded ( void )
 {
     SDL_Surface* Small_Droid;
     SDL_Surface* Large_Droid;
-    char *fpath;
+    char fpath[2048];
     char fname[500];
     int i;
     static int first_call = TRUE ;
@@ -861,7 +933,7 @@ make_sure_all_chat_portraits_are_loaded ( void )
 	strcpy( fname, "droids/" );
 	strcat( fname, PrefixToFilename [ i ] ) ;
 	strcat( fname , "/portrait.png" );
-	fpath = find_file (fname, GRAPHICS_DIR, FALSE);
+	find_file (fname, GRAPHICS_DIR, fpath, 0);
 	DebugPrintf ( -1000, "\nFilename used for portrait: %s." , fpath );
 	
 	Small_Droid = our_IMG_load_wrapper (fpath) ;
@@ -869,7 +941,7 @@ make_sure_all_chat_portraits_are_loaded ( void )
 	{
 	    strcpy( fname, "droids/" );
 	    strcat( fname, "DefaultPortrait.png" );
-	    fpath = find_file (fname, GRAPHICS_DIR, FALSE);
+	    find_file (fname, GRAPHICS_DIR, fpath, 0);
 	    Small_Droid = our_IMG_load_wrapper (fpath) ;
 	}
 	if ( Small_Droid == NULL )
@@ -913,14 +985,13 @@ PrepareMultipleChoiceDialog ( Enemy ChatDroid , int with_flip )
     // loaded....
     //
     make_sure_chat_portraits_loaded_for_this_droid ( ChatDroid ) ;
-    //make_sure_all_chat_portraits_are_loaded ( );
     
     //--------------------
     // We select small font for the menu interaction...
     //
     SetCurrentFont( FPS_Display_BFont );
     
-    AssembleCombatPicture ( USE_OWN_MOUSE_CURSOR ) ;
+//    AssembleCombatPicture ( USE_OWN_MOUSE_CURSOR ) ;
     blit_special_background ( CHAT_DIALOG_BACKGROUND_PICTURE_CODE );
     our_SDL_blit_surface_wrapper ( chat_portrait_of_droid [ ChatDroid -> type ] . surface , NULL , 
 				   Screen , &Droid_Image_Window );
@@ -1303,7 +1374,7 @@ DoChatFromChatRosterData( int PlayerNum , int ChatPartnerCode , Enemy ChatDroid
 	}
 	else
 	{
-	    MenuSelection = ChatDoMenuSelectionFlagged ( "What will you say?" , DialogMenuTexts , Me [ PlayerNum ] . Chat_Flags [ ChatPartnerCode ]  , 1 , -1 , FPS_Display_BFont , ChatDroid );
+	    MenuSelection = ChatDoMenuSelectionFlagged ( _("What will you say?") , DialogMenuTexts , Me [ PlayerNum ] . Chat_Flags [ ChatPartnerCode ]  , 1 , -1 , FPS_Display_BFont , ChatDroid );
 	    //--------------------
 	    // We do some correction of the menu selection variable:
 	    // The first entry of the menu will give a 1 and so on and therefore
@@ -1372,7 +1443,6 @@ DialogPartnersTurnToEachOther ( Enemy ChatDroid )
     //
     ChatDroid -> speed . x = 0 ;
     ChatDroid -> speed . y = 0 ;
-    AnimateEnemys ( ) ; 
     
     //--------------------
     // At first do some waiting before the turning around starts...
@@ -1501,7 +1571,7 @@ ChatWithFriendlyDroid( Enemy ChatDroid )
     SDL_Rect Chat_Window;
     char* DialogMenuTexts[ MAX_ANSWERS_PER_PERSON ];
     int ChatFlagsIndex = (-1);
-    char *fpath;
+    char fpath[2048];
     char tmp_filename[5000];
     
     //--------------------
@@ -1531,7 +1601,7 @@ ChatWithFriendlyDroid( Enemy ChatDroid )
     
     // From initiating transfer mode, space might still have been pressed. 
     // So we wait till it's released...
-    while ( SpacePressed ( ) );
+    while ( MouseLeftPressed ( ) || MouseRightPressed() );
     
     //--------------------
     // We clean out the chat roster from any previous use
@@ -1550,7 +1620,7 @@ ChatWithFriendlyDroid( Enemy ChatDroid )
     strcat ( tmp_filename , ".dialog" );
     char finaldir[50];
     sprintf(finaldir, "%s%s", DIALOG_DIR, language_dirs[GameConfig.language]);
-    fpath = find_file ( tmp_filename , finaldir, FALSE);
+    find_file (tmp_filename , finaldir, fpath, 0);
     LoadChatRosterWithChatSequence ( fpath );
 
     if ( ! Me [ 0 ] . chat_character_initialized [ ChatFlagsIndex ] )
