@@ -108,7 +108,7 @@ enum
   };
 #define NOT_LOADED_MARKER "nothing_loaded"
 
-#define ENEMY_ROTATION_MODELS_AVAILABLE 34
+#define ENEMY_ROTATION_MODELS_AVAILABLE 35
 #define ROTATION_ANGLES_PER_ROTATION_MODEL 8
 
 #define MAX_ENEMY_MOVEMENT_PHASES 50
@@ -128,7 +128,8 @@ enum
 #define MAX_OBSTACLE_NAMES_PER_LEVEL 100
 #define MAX_OBSTACLE_DESCRIPTIONS_PER_LEVEL 100
 
-#define FLOOR_TILES_VISIBLE_AROUND_TUX 11
+#define FLOOR_TILES_VISIBLE_AROUND_TUX ((GameConfig . screen_width >= 1024 ? 12 : GameConfig . screen_width >= 800 ? 9 : 7))
+#define MAX_FLOOR_TILES_VISIBLE_AROUND_TUX 12
 // #define MAX_OBSTACLES_GLUED_TO_ONE_MAP_TILE 4
 #define MAX_OBSTACLES_GLUED_TO_ONE_MAP_TILE 5
 #define MAX_ITEMS_PER_LEVEL 300
@@ -142,8 +143,8 @@ enum
 #define NUMBER_OF_ITEM_PICTURES 70
 #define NUMBER_OF_MOUSE_CURSOR_PICTURES 2
 
-#define ITEM_DROP_PERCENTAGE 20
-#define GOLD_DROP_PERCENTAGE 20
+#define ITEM_DROP_PERCENTAGE 25
+#define GOLD_DROP_PERCENTAGE 15
 
 #define MAX_DIALOGUE_OPTIONS_IN_ROSTER 100
 #define MAX_REPLIES_PER_OPTION 100
@@ -165,10 +166,16 @@ enum
 #define NUMBER_OF_SKILL_LEVELS 10
 #define NUMBER_OF_SKILL_PAGES 8
 #define NUMBER_OF_SKILLS_PER_SKILL_PAGE 5
-#define NUMBER_OF_SKILLS ( NUMBER_OF_SKILLS_PER_SKILL_PAGE * NUMBER_OF_SKILL_PAGES )
-
 #define MAX_ACTIVE_SPELLS 100
+#define MAX_NUMBER_OF_PROGRAMS 50
 
+enum skill_forms
+{
+    PROGRAM_FORM_IMMEDIATE = 60000, //instant hit whatever behind cursor
+    PROGRAM_FORM_RADIAL, //nova
+    PROGRAM_FORM_BULLET, //fire a bullet
+    PROGRAM_FORM_SELF, //instant hit player
+};
 
 enum _global_ingame_modes
 {
@@ -191,32 +198,7 @@ enum _game_config_screen_visible_parameters
     GAME_CONFIG_SCREEN_VISIBLE_INVENTORY = 8001 ,
     GAME_CONFIG_SCREEN_VISIBLE_SKILLS = 8002 ,
     GAME_CONFIG_SCREEN_VISIBLE_CHARACTER = 8003 ,
-};
-
-enum _spell_names
-{
-  SPELL_TRANSFERMODE = 0, // 0
-  SPELL_LOOT_CHEST_OR_DEAD_BODY, 
-  SPELL_REPAIR_SKILL, // 
-  SPELL_WEAPON, // 
-  SPELL_IDENTIFY_SKILL, // 
-  SPELL_FORCE_TO_ENERGY, // 
-  SPELL_TELEPORT_HOME, // 
-  SPELL_FIREY_BOLT, // 
-  SPELL_COLD_BOLT, // 
-  SPELL_FORCE_EXPLOSION_CIRCLE, // 
-  SPELL_POISON_BOLT, // 
-  SPELL_PARALYZE_BOLT, // 
-  SPELL_DETECT_ITEM, // 
-  SPELL_RADIAL_EMP_WAVE, //
-  SPELL_RADIAL_VMX_WAVE, // 
-  SPELL_RADIAL_FIRE_WAVE, // 
-  SPELL_EXTRACT_PLASMA_TRANSISTORS,
-  SPELL_EXTRACT_SUPERCONDUCTORS,
-  SPELL_EXTRACT_ANTIMATTER_CONVERTERS,
-  SPELL_EXTRACT_ENTROPY_INVERTERS,
-  SPELL_EXTRACT_TACHYON_CONDENSATORS,
-  SPELL_FORCE_EXPLOSION_RAY, // 
+    GAME_CONFIG_SCREEN_VISIBLE_SKILL_EXPLANATION = 8004 ,
 };
 
 //--------------------
@@ -224,7 +206,6 @@ enum _spell_names
 // cause here I can't check if the code is still running without it
 //
 #define FILENAME_LEN	5000
-#define SHIP_EXT	".shp"
 
 #define END_OF_OFFSET_FILE_STRING "** End of iso_image offset file **"
 #define START_OF_OFFSET_FILE_STRING "** Start of iso_image offset file **"
@@ -257,27 +238,7 @@ enum
 //
 #define LEVEL_EDITOR_ZOOM_OUT_FACT 3.0
 
-//--------------------
-// This controls the zoom factor for the automap.  Since this uses
-// a different update policy than the level editor, even strong zoom
-// will not be a problem here...
-//
-// However some other considerations must be taken into account:  OPENGL
-// DOES IN GENERAL NOT WORK WELL ANY MORE WITH TEXTURES LARGER THAN 2024
-// AND SOMETIMES EVEN NOT WELL WITH ANYTHING > 256 (old vodoo cards!!!)
-// EVEN GEFORCE II HAS PROBLEMS WITH 2048 TEXTURE SIZE.
-//
-// Therefore some sanity-factor is introduced here:  it will scale down
-// the internal automap texture but scale it up again when the acutal
-// part-transparent blit is being done.  Using 0.25 for the sanity factor
-// should be the safest bet.  However quality is poor:  you get lots of
-// rectangular blocks where a wall/door/tree would be.  So I'll try 512
-// texture size here.  Vodoo users can recompile the game for their needs...
-// 
 #define AUTOMAP_ZOOM_OUT_FACT 8.0
-#define AUTOMAP_SANITY_FACTOR 1
-#define AUTOMAP_TEXTURE_WIDTH (2048*AUTOMAP_SANITY_FACTOR)
-#define AUTOMAP_TEXTURE_HEIGHT (1024*AUTOMAP_SANITY_FACTOR)
 
 #define LIGHT_RADIUS_STRETCH_TEXTURE_WIDTH 64
 #define LIGHT_RADIUS_STRETCH_TEXTURE_HEIGHT 64
@@ -365,7 +326,7 @@ enum
 #define MAX_AMOUNT_OF_TEXTURES_WE_WILL_USE 10000
 
 #define SCROLLSTARTX		User_Rect.x
-#define SCROLLSTARTY		GameConfig . screen_height
+#define SCROLLSTARTY		GameConfig . screen_height - 100
 
 #define INITIAL_DIGIT_LENGTH (8*2)
 #define INITIAL_DIGIT_HEIGHT (9*2)
@@ -464,6 +425,13 @@ enum _non_player_characters
     PERSON_KEVIN,
     PERSON_LUKAS,
     PERSON_JASMINE,
+    PERSON_SADD,
+    PERSON_SACD,
+    PERSON_TANIA,
+    PERSON_KOAN,
+    PERSON_BORIS,
+    PERSON_LINA,
+    PERSON_SERGE,
     LAST_PERSON
   };
 #define MAX_PERSONS             (LAST_PERSON)
@@ -580,6 +548,9 @@ enum
     LEVEL_EDITOR_TOGGLE_TOOLTIPS_BUTTON_OFF,
     LEVEL_EDITOR_TOGGLE_COLLISION_RECTS_BUTTON ,
     LEVEL_EDITOR_TOGGLE_COLLISION_RECTS_BUTTON_OFF,
+    LEVEL_EDITOR_TOGGLE_GRID_BUTTON,
+    LEVEL_EDITOR_TOGGLE_GRID_BUTTON_FULL,
+    LEVEL_EDITOR_TOGGLE_GRID_BUTTON_OFF,
 
     LEVEL_EDITOR_NEXT_ITEM_GROUP_BUTTON,
     LEVEL_EDITOR_PREV_ITEM_GROUP_BUTTON,
@@ -628,6 +599,7 @@ enum
     LEVEL_EDITOR_CONTAINERS_TAB,
     LEVEL_EDITOR_PLANTS_TAB,
     LEVEL_EDITOR_ALL_TAB,
+    LEVEL_EDITOR_QUICK_TAB,
 
     QUEST_BROWSER_EXIT_BUTTON,
     QUEST_BROWSER_OPEN_QUESTS_BUTTON,
@@ -659,16 +631,13 @@ enum
 #define CHAT_SUBDIALOG_WINDOW_W ((337)*GameConfig . screen_width/640)
 #define CHAT_SUBDIALOG_WINDOW_H ((216)*GameConfig . screen_height/480)
 
-#define STR_BASE_X 100
-#define STR_NOW_X 148
-#define STR_Y 143
-#define DEX_Y 171
-#define MAG_Y 197
-#define VIT_Y 227
+#define STR_X 95
+#define STR_Y 141
+#define DEX_Y 165
+#define MAG_Y 190
+#define VIT_Y 218
 #define POINTS_Y 252
 
-#define BUTTON_MOD_X (-6)
-#define BUTTON_MOD_Y (-4)
 #define BUTTON_WIDTH 35
 #define BUTTON_HEIGHT 19
 
@@ -740,7 +709,7 @@ enum
 
 #define MAX_ENEMYS_ON_SHIP	1000
 #define MAX_INFLU_POSITION_HISTORY 10000
-#define MAX_MISSIONS_IN_GAME 10         // how many missions can there be at most in Freedroid
+#define MAX_MISSIONS_IN_GAME 12         // how many missions can there be at most in Freedroid
 #define MAX_MISSION_TRIGGERED_ACTIONS 10
 #define MAX_MISSION_DESCRIPTION_TEXTS 10
 
@@ -839,7 +808,9 @@ enum _busytype
     NONE=0,
     DRINKING_POTION=1,
     WEAPON_FIREWAIT,
-    WEAPON_RELOAD
+    WEAPON_RELOAD,
+    THROWING_GRENADE,
+    RUNNING_PROGRAM,
 };
 //--------------------
 // The possible edito modes for the level editor
@@ -880,7 +851,6 @@ enum _enemy_combat_target_codes
 };
 enum
 {
-    MOUSE_CURSOR_CROSSHAIR_SHAPE = -401 ,
     MOUSE_CURSOR_ARROW_SHAPE = -402
 }; 
 enum
@@ -1025,7 +995,7 @@ enum
   ISO_AUTOGUN_N = 33,
   ISO_AUTOGUN_E = 34,
   ISO_AUTOGUN_S = 35,
-
+//see at the end for disabled autoguns
   //--------------------
   // These obstacles are generated from 'iso_cave_walls.blend' file
   // in the cvs rep.
@@ -1399,9 +1369,39 @@ enum
   
   ISO_TRANSP_FOR_WATER,
   
-  ISO_BRICK_WALL_EH , // = 134 ,
+  ISO_BRICK_WALL_EH , // = 322 ,
   ISO_BRICK_WALL_EV ,
 
+  ISO_DIS_AUTOGUN_W,
+  ISO_DIS_AUTOGUN_N,
+  ISO_DIS_AUTOGUN_E,
+  ISO_DIS_AUTOGUN_S,
+
+  ISO_BRICK_WALL_CABLES_H ,
+  ISO_BRICK_WALL_CABLES_V ,
+
+  ISO_BRICK_WALL_CABLES_CORNER_1 ,
+  ISO_BRICK_WALL_CABLES_CORNER_2 , 
+  ISO_BRICK_WALL_CABLES_CORNER_3 , 
+  ISO_BRICK_WALL_CABLES_CORNER_4 ,
+
+  ISO_RESTAURANT_DESK_1,
+  ISO_RESTAURANT_DESK_2,
+  ISO_RESTAURANT_BIGSHELF_1,
+  ISO_RESTAURANT_BIGSHELF_2,
+
+  ISO_CRYSTALS_1,
+  ISO_CRYSTALS_2,
+  ISO_CRYSTALS_3,
+  ISO_CRYSTALS_4,
+  ISO_CRYSTALS_5,
+  ISO_CRYSTALS_6,
+
+  ISO_GREY_WALL_CORNER_1,
+  ISO_GREY_WALL_CORNER_2,
+  ISO_GREY_WALL_CORNER_3,
+  ISO_GREY_WALL_CORNER_4,
+
   NUMBER_OF_OBSTACLE_TYPES
 };
 
@@ -1497,6 +1497,8 @@ enum
   ISO_SAND_FLOOR_5,
   ISO_SAND_FLOOR_6,
 
+
+
   ALL_ISOMETRIC_FLOOR_TILES 
 };
 
