@@ -188,13 +188,6 @@ set_mouse_cursor_to_shape ( int given_shape )
 
     switch ( given_shape )
     {
-	case MOUSE_CURSOR_CROSSHAIR_SHAPE:
-	    // SDL_SetCursor( init_system_cursor( crosshair_mouse_cursor ) );
-	    // current_mouse_cursor_shape = MOUSE_CURSOR_CROSSHAIR_SHAPE ;
-	    current_cursor = init_system_cursor( arrow_mouse_cursor ) ;
-	    SDL_SetCursor( current_cursor ) ;
-	    current_mouse_cursor_shape = MOUSE_CURSOR_ARROW_SHAPE ;
-	    break;
 	case MOUSE_CURSOR_ARROW_SHAPE:
 	    current_cursor = init_system_cursor( arrow_mouse_cursor ) ;
 	    SDL_SetCursor( current_cursor ) ;
@@ -205,7 +198,7 @@ set_mouse_cursor_to_shape ( int given_shape )
 ERROR: Unhandled mouse cursor shape type received.",
 				       PLEASE_INFORM, IS_FATAL );
 	    SDL_SetCursor( init_system_cursor( crosshair_mouse_cursor ) );
-	    current_mouse_cursor_shape = MOUSE_CURSOR_CROSSHAIR_SHAPE ;
+	    current_mouse_cursor_shape = MOUSE_CURSOR_ARROW_SHAPE ;
 	    break;
     }
 }; // void set_mouse_cursor_to_shape ( int given_shape ) 
@@ -256,7 +249,7 @@ blit_our_own_mouse_cursor ( void )
     int i;
     static iso_image mouse_cursors [ 16 ] ;
     char constructed_filename[2000];
-    char* fpath;
+    char fpath[2048];
     int cursor_index = (-1) ;
 
     //--------------------
@@ -268,7 +261,7 @@ blit_our_own_mouse_cursor ( void )
 	for ( i = 0 ; i < 12 ; i ++ )
 	{
 	    sprintf ( constructed_filename , "mouse_cursor_%04d.png" , i );
-	    fpath = find_file ( constructed_filename , GRAPHICS_DIR, FALSE );
+	    find_file (constructed_filename , GRAPHICS_DIR, fpath, 0 );
 	    get_iso_image_from_file_and_path ( fpath , & ( mouse_cursors [ i ] ) , FALSE ) ;
 	    if ( mouse_cursors [ i ] . surface == NULL ) 
 	    {
@@ -339,12 +332,12 @@ Error loading flag image.",
     //
     if ( use_open_gl )
     {
-	blit_open_gl_texture_to_screen_position ( mouse_cursors [ cursor_index ] , 
+	blit_open_gl_texture_to_screen_position ( &mouse_cursors [ cursor_index ] , 
 						  GetMousePos_x () , GetMousePos_y () , TRUE );
     }
     else
     {
-	blit_iso_image_to_screen_position ( mouse_cursors [ cursor_index ] , 
+	blit_iso_image_to_screen_position ( &mouse_cursors [ cursor_index ] , 
 					    GetMousePos_x () , GetMousePos_y () );
     }
 
@@ -362,7 +355,7 @@ blit_mouse_cursor_corona ( void )
     int i;
     static iso_image mouse_cursor_coronas [ 16 ] ;
     char constructed_filename[2000];
-    char* fpath;
+char fpath[2048];
     moderately_finepoint offset_vector;
     int our_obstacle_index ;
     int our_enemy_index;
@@ -385,7 +378,7 @@ blit_mouse_cursor_corona ( void )
 	for ( i = 0 ; i < 8 ; i ++ )
 	{
 	    sprintf ( constructed_filename , "mouse_cursor_corona_%04d.png" , i );
-	    fpath = find_file ( constructed_filename , GRAPHICS_DIR, FALSE );
+	    find_file (constructed_filename , GRAPHICS_DIR, fpath, 0 );
 	    get_iso_image_from_file_and_path ( fpath , & ( mouse_cursor_coronas [ i ] ) , FALSE ) ;
 	    if ( mouse_cursor_coronas [ i ] . surface == NULL ) 
 	    {
@@ -430,12 +423,12 @@ Error loading flag image.",
 
 	if ( use_open_gl )
 	{
-	    blit_open_gl_texture_to_screen_position ( mouse_cursor_coronas [ i ] , 
+	    blit_open_gl_texture_to_screen_position ( &mouse_cursor_coronas [ i ] , 
 						      GetMousePos_x () + offset_vector . x , GetMousePos_y () + offset_vector . y , TRUE );
 	}
 	else
 	{
-	    blit_iso_image_to_map_position ( mouse_cursor_coronas [ i ] , 
+	    blit_iso_image_to_map_position ( &mouse_cursor_coronas [ i ] , 
 					     GetMousePos_x () , GetMousePos_x () );
 	}
     }
@@ -464,6 +457,7 @@ get_obstacle_below_mouse_cursor ( void )
 void
 fade_out_using_gamma_ramp ( void )
 {
+    if ( !GameConfig . do_fadings ) return;
     int i = 0;
     Activate_Conservative_Frame_Computation( );
     #ifdef HAVE_LIBGL
@@ -505,6 +499,7 @@ fade_out_using_gamma_ramp ( void )
 void
 fade_in_using_gamma_ramp ( void )
 {
+if ( !GameConfig . do_fadings ) return;
 int i;
 Activate_Conservative_Frame_Computation( );
 
@@ -596,7 +591,6 @@ do_graphical_number_selection_in_range ( int lower_range , int upper_range, int
 {
     static SDL_Surface* SelectionKnob = NULL ;
     int ok_button_was_pressed = FALSE;
-    int left_mouse_pressed_previous_frame = FALSE;
     int knob_start_x = UNIVERSAL_COORD_W(200);
     int knob_end_x = UNIVERSAL_COORD_W(390);
     if(!(upper_range - lower_range))
@@ -616,7 +610,11 @@ do_graphical_number_selection_in_range ( int lower_range , int upper_range, int
     // Next we prepare the selection knob for all later operations
     //
     if ( SelectionKnob == NULL )
-	SelectionKnob = our_IMG_load_wrapper( find_file ( "mouse_buttons/number_selector_selection_knob.png" , GRAPHICS_DIR, FALSE ) );
+	{
+	char fpath[2048];
+	find_file ( "mouse_buttons/number_selector_selection_knob.png" , GRAPHICS_DIR, fpath, 0);
+	SelectionKnob = our_IMG_load_wrapper( fpath );
+	}
     if ( SelectionKnob == NULL )
     {
 	fprintf( stderr, "\n\nSDL_GetError: %s \n" , SDL_GetError() );
@@ -628,9 +626,11 @@ ERROR LOADING SELECTION KNOB IMAGE FILE!",
     knob_target_rect . w = SelectionKnob -> w;
     knob_target_rect . h = SelectionKnob -> h;
     
-    while ( SpacePressed() );
+    while ( SpacePressed() || MouseLeftPressed());
     while ( ! ok_button_was_pressed )
     {
+	track_last_frame_input_status(); //activate the *WasPressed functions
+
 	//--------------------
 	// Now we assemble and show the screen, which includes 
 	// 1. the background
@@ -651,7 +651,7 @@ ERROR LOADING SELECTION KNOB IMAGE FILE!",
 	blit_our_own_mouse_cursor ( );
 	our_SDL_flip_wrapper ( Screen );
 	
-	if ( ( SpacePressed() && axis_is_active ) && ( ! left_mouse_pressed_previous_frame ) ) 
+	if ( MouseLeftClicked() )
 	{
 	    //--------------------
 	    // Maybe the user has just 'grabbed the knob?  Then we need to
@@ -690,7 +690,8 @@ ERROR LOADING SELECTION KNOB IMAGE FILE!",
 	    }
 	    
 	}
-	if ( ! ( SpacePressed() && axis_is_active ) ) knob_is_grabbed = FALSE ;
+	if ( ! MouseLeftPressed() ) knob_is_grabbed = FALSE ;
+
 	
 	if ( knob_is_grabbed )
 	{
@@ -700,7 +701,33 @@ ERROR LOADING SELECTION KNOB IMAGE FILE!",
 	}
 	
 	
-	left_mouse_pressed_previous_frame = axis_is_active ;
+ 	if ( RightPressed() &&  !RightWasPressed() )
+	    {
+	     if ( knob_end_x - knob_start_x - knob_offset_x > ((knob_end_x - knob_start_x) / (upper_range - lower_range)))
+                        {
+                        knob_offset_x += (knob_end_x - knob_start_x) / (upper_range - lower_range + 1);
+                        }
+                if ( knob_offset_x < knob_end_x - knob_start_x - 1)
+                        knob_offset_x ++;
+	
+	    }
+
+	if (LeftPressed() && !LeftWasPressed())
+	    {
+	    if(knob_offset_x > ((knob_end_x - knob_start_x) / (upper_range - lower_range + 1)))
+                        {
+                        knob_offset_x -= (knob_end_x - knob_start_x) / (upper_range - lower_range + 1);
+                        }
+                if(knob_offset_x > 0)
+                        knob_offset_x --;
+
+	    }
+
+	if (EnterPressed())
+	    {
+            ok_button_was_pressed = TRUE ;
+	    }
+
 	SDL_Delay (1);
     }
     
@@ -1331,7 +1358,7 @@ TakeScreenshot( void )
   // Now that a screenshot has been taken, we might as well start
   // the sound of a camera taking a picture... :)
   //
-  PlayOnceNeededSoundSample( "effects/CameraTakesPicture.wav" , FALSE , TRUE ) ;
+  PlayOnceNeededSoundSample( "effects/CameraTakesPicture.ogg" , FALSE , TRUE ) ;
 
   //--------------------
   // Taking the screenshot, converting is and saving it, maybe also
@@ -1459,120 +1486,6 @@ DisplayImage( char *datafile )
 
 }; // void DisplayImage( char *datafile )
 
-/* ----------------------------------------------------------------------
- * This function loads the configuration file for a theme, containing 
- * such things as the number of bullet phases and the position for droid
- * digits in that theme.
- * ---------------------------------------------------------------------- */
-void 
-LoadThemeConfigurationFile(void)
-{
-  char *Data;
-  char *ReadPointer;
-  char *fpath;
-  char *EndOfThemesBulletData;
-  char *EndOfThemesBlastData;
-  char *EndOfThemesDigitData;
-  int BulletIndex;
-  int NumberOfBulletTypesInConfigFile=0;
-  
-#define END_OF_THEME_DATA_STRING "**** End of theme data section ****"
-#define END_OF_THEME_BLAST_DATA_STRING "*** End of themes blast data section ***" 
-#define END_OF_THEME_BULLET_DATA_STRING "*** End of themes bullet data section ***" 
-#define END_OF_THEME_DIGIT_DATA_STRING "*** End of themes digit data section ***" 
-
-
-  fpath = find_file ("config.theme", GRAPHICS_DIR, TRUE);
-
-  DebugPrintf ( 1 , "\nvoid LoadThemeConfigurationFile: Data will be taken from file %s.  Commencing...\n " , fpath );
-
-  Data = ReadAndMallocAndTerminateFile( fpath , END_OF_THEME_DATA_STRING ) ;
-
-  EndOfThemesBulletData = LocateStringInData ( Data , END_OF_THEME_BULLET_DATA_STRING );
-  EndOfThemesBlastData  = LocateStringInData ( Data , END_OF_THEME_BLAST_DATA_STRING  );
-  EndOfThemesDigitData  = LocateStringInData ( Data , END_OF_THEME_DIGIT_DATA_STRING  );
-
-  //--------------------
-  // Now the file is read in entirely and
-  // we can start to analyze its content, 
-  //
-#define BLAST_ONE_NUMBER_OF_PHASES_STRING "How many phases in Blast one :"
-#define BLAST_TWO_NUMBER_OF_PHASES_STRING "How many phases in Blast two :"
-
-  ReadValueFromString( Data , BLAST_ONE_NUMBER_OF_PHASES_STRING , "%d" , 
-		       &Blastmap[0].phases , EndOfThemesBlastData );
-
-  ReadValueFromString( Data , BLAST_TWO_NUMBER_OF_PHASES_STRING , "%d" , 
-		       &Blastmap[1].phases , EndOfThemesBlastData );
-  Blastmap [ 2 ] . phases = Blastmap [ 1 ] . phases;
-
-  //--------------------
-  // Now we read in the total time amount for each animation
-  //
-#define BLAST_ONE_TOTAL_AMOUNT_OF_TIME_STRING "Time in seconds for the hole animation of blast one :"
-#define BLAST_TWO_TOTAL_AMOUNT_OF_TIME_STRING "Time in seconds for the hole animation of blast two :"
-
-  ReadValueFromString( Data , BLAST_ONE_TOTAL_AMOUNT_OF_TIME_STRING , "%lf" , 
-		       &Blastmap[0].total_animation_time , EndOfThemesBlastData );
-
-  ReadValueFromString( Data , BLAST_TWO_TOTAL_AMOUNT_OF_TIME_STRING , "%lf" , 
-		       &Blastmap[1].total_animation_time , EndOfThemesBlastData );
-
-  Blastmap [ 2 ] . total_animation_time = Blastmap [ 1 ] . total_animation_time;
-
-  //--------------------
-  // Next we read in the number of phases that are to be used for each bullet type
-  ReadPointer = Data ;
-  while ( ( ReadPointer = strstr ( ReadPointer , "For Bullettype Nr.=" ) ) != NULL )
-    {
-      ReadValueFromString( ReadPointer , "For Bullettype Nr.=" , "%d" , &BulletIndex , EndOfThemesBulletData );
-      if ( BulletIndex >= Number_Of_Bullet_Types )
-	{
-	  GiveStandardErrorMessage ( __FUNCTION__  , "\
-A BLAST WAS FOUND TO EXIST OUTSIDE THE BOUNDS OF THE MAP.\n\
-The theme configuration file seems to be BOGUS!!!\n\
-The number of bullettypes mentioned therein does not match the number\n\
-of bullettypes mentioned in the freedroid.ruleset file!!!\n\
-\n\
-Either there was a specification for the number of phases in a bullet type\n\
-that does not at all exist in the ruleset or an existing bullettype has not\n\
-been assigned a number of phases in the themes config file.\n\
-\n\
-This might indicate that either the ruleset file is corrupt or the \n\
-theme.config configuration file is corrupt or (less likely) that there\n\
-is a severe bug in the reading function.",
-				     NO_NEED_TO_INFORM, IS_FATAL );
-	}
-      ReadValueFromString( ReadPointer , "we will use number of phases=" , "%d" , 
-			   &Bulletmap[BulletIndex].phases , EndOfThemesBulletData );
-      ReadValueFromString( ReadPointer , "and number of phase changes per second=" , "%lf" , 
-			   &Bulletmap[BulletIndex].phase_changes_per_second , EndOfThemesBulletData );
-      ReadPointer++;
-      NumberOfBulletTypesInConfigFile ++;
-    }
-  //--------------------
-  // LEAVE THIS SECURITY CHECK IN HERE!!!! IT IS VITAL!!!
-  // *ALSO* LEAVE IN THE SECURITY CHECK ABOVE!!! PLEASE!!!
-  //
-  if ( NumberOfBulletTypesInConfigFile != Number_Of_Bullet_Types )
-    {
-      GiveStandardErrorMessage ( __FUNCTION__  , "\
-The theme configuration file seems to be COMPLETELY BOGUS!!!\n\
-The number of bullettypes mentioned therein does not match the number\n\
-of bullettypes mentioned in the freedroid.ruleset file!!!\n\
-\n\
-Either there was a specification for the number of phases in a bullet type\n\
-that does not at all exist in the ruleset or an existing bullettype has not\n\
-been assigned a number of phases in the themes config file.\n\
-\n\
-This might indicate that either the ruleset file is corrupt or the \n\
-theme.config configuration file is corrupt or (less likely) that there\n\
-is a severe bug in the reading function.",
-				 NO_NEED_TO_INFORM, IS_FATAL );
-	}
-
-}; // void LoadThemeConfigurationFile ( void )
-
 /* ----------------------------------------------------------------------
  *
  *
@@ -1581,8 +1494,9 @@ void
 get_standard_iso_floor_tile_size ( void )
 {
     SDL_Surface *standard_floor_tile;
-
-    standard_floor_tile = our_IMG_load_wrapper( find_file ( "floor_tiles/iso_miscellaneous_floor_0000.png" , GRAPHICS_DIR, FALSE ) );
+    char fp[2048];
+    find_file ( "floor_tiles/iso_miscellaneous_floor_0000.png" , GRAPHICS_DIR, fp, 0);
+    standard_floor_tile = our_IMG_load_wrapper( fp );
     if ( standard_floor_tile == NULL )
     {
 	fprintf( stderr, "\n\nSDL_GetError: %s \n" , SDL_GetError() );
@@ -1637,16 +1551,7 @@ InitPictures (void)
     
     ShowStartupPercentage ( 18 ) ; 
     
-    // In the following we will be reading in image information.  But the number
-    // of images to read in and the way they are displayed might be strongly dependant
-    // on the theme.  That is not at all a problem.  We just got to read in the
-    // theme configuration file again.  After that is done, the following reading
-    // commands will do the right thing...
-    LoadThemeConfigurationFile();
-    
-    ShowStartupPercentage ( 20 ) ; 
-    
-    set_mouse_cursor_to_shape ( MOUSE_CURSOR_CROSSHAIR_SHAPE ) ;
+    set_mouse_cursor_to_shape ( MOUSE_CURSOR_ARROW_SHAPE ) ;
     
     ShowStartupPercentage ( 22 ) ; 
     
@@ -1700,17 +1605,14 @@ InitOurBFonts ( void )
 {
 #define ALL_BFONTS_WE_LOAD 6
 
-#define PARA_FONT_FILE 		"font/parafont.png"
-#define MENU_FONT_FILE 		"font/cpuFont.png"
-// #define MESSAGE_FONT_FILE 	"font/ArialGold.png"
-// #define MESSAGE_FONT_FILE 	"font/SmallStone.png"
-#define MESSAGE_FONT_FILE 	"font/small_white.png"
-#define RED_FONT_FILE 		"font/font05_red.png"
-#define BLUE_FONT_FILE 		"font/font05_white.png"
-#define FPS_FONT_FILE 		"font/font05.png"
-// #define FPS_FONT_FILE 		"font/SmallStone.png"
+#define PARA_FONT_FILE 		"font/parafont"
+#define MENU_FONT_FILE 		"font/cpuFont"
+#define MESSAGE_FONT_FILE 	"font/small_white"
+#define RED_FONT_FILE 		"font/font05_red"
+#define BLUE_FONT_FILE 		"font/font05_white"
+#define FPS_FONT_FILE 		"font/font05"
 
-    char* fpath;
+char fpath[2048];
     int i;
     char* MenuFontFiles[ALL_BFONTS_WE_LOAD] =
 	{
@@ -1733,12 +1635,29 @@ InitOurBFonts ( void )
     
     for ( i = 0 ; i < ALL_BFONTS_WE_LOAD ; i ++ )
     {
-	fpath = find_file ( MenuFontFiles [ i ] , GRAPHICS_DIR , FALSE);
+	extern char * language_font_classes[];
+        char constructed_fname[2048];
+	sprintf(constructed_fname, "%s", MenuFontFiles [ i ] );
+	strcat(constructed_fname, language_font_classes[GameConfig.language] );
+	strcat(constructed_fname, ".png");
+
+	if ( find_file (constructed_fname , GRAPHICS_DIR , fpath, 0) != 0 ) 
+		{ //if the file wasn't found, default to the standard ASCII7bit file
+		sprintf(constructed_fname, "%s.png",  MenuFontFiles [ i ]);
+	        if ( find_file (constructed_fname , GRAPHICS_DIR , fpath, 0) != 0 ) 
+			{
+		        fprintf (stderr, "\n\nFont file: '%s'.\n" , MenuFontFiles [ i ] );
+			GiveStandardErrorMessage ( __FUNCTION__  , "\
+A font file for the BFont library was not found.",
+                                       PLEASE_INFORM, IS_FATAL );
+			}
+		}
+
 	if ( ( *MenuFontPointers [ i ] = LoadFont ( fpath ) ) == NULL )
 	{
 	    fprintf (stderr, "\n\nFont file: '%s'.\n" , MenuFontFiles [ i ] );
 	    GiveStandardErrorMessage ( __FUNCTION__  , "\
-A font file for the BFont library was not found.",
+A font file for the BFont library could not be loaded.",
 				       PLEASE_INFORM, IS_FATAL );
 	} 
 	else
@@ -1749,6 +1668,30 @@ A font file for the BFont library was not found.",
     
 }; // InitOurBFonts ( void )
 
+void
+FreeOurBFonts ( void )
+{
+int i;
+BFont_Info** MenuFontPointers[ALL_BFONTS_WE_LOAD] =
+	{
+	    &Menu_BFont,
+	    &Message_BFont,
+	    &Para_BFont,
+	    &FPS_Display_BFont,
+	    &Red_BFont,
+	    &Blue_BFont
+	};
+
+ for ( i = 0 ; i < ALL_BFONTS_WE_LOAD ; i ++ )
+    {
+    if (*MenuFontPointers [ i ] != NULL)
+	    {
+	    FreeFont( *MenuFontPointers [ i ]);
+	    *MenuFontPointers [ i ] = NULL;
+	    }
+    }
+}; // FreeOurBFonts ( void )
+
 /* -----------------------------------------------------------------
  * This funciton initialises the timer subsystem.
  * -----------------------------------------------------------------*/
@@ -1942,7 +1885,7 @@ set_video_mode_for_open_gl ( void )
     
     // video_flags |= SDL_HWPALETTE;       /* Store the palette in hardware */
     //video_flags |= SDL_RESIZABLE;       /* Enable window resizing */
-    if (fullscreen_on) video_flags |= SDL_FULLSCREEN;
+    if (GameConfig . fullscreen_on) video_flags |= SDL_FULLSCREEN;
     if ( vid_info->hw_available )
 	video_flags |= SDL_HWSURFACE;
   else
@@ -2054,7 +1997,7 @@ InitVideo (void)
     const SDL_VideoInfo *vid_info;
     char vid_driver[81];
     Uint32 video_flags = 0 ;  // flags for SDL video mode 
-    char *fpath;
+char fpath[2048];
     char window_title_string[200];
     
     //--------------------
@@ -2112,7 +2055,7 @@ InitVideo (void)
     {
 	// RP: let's try without those...
 	// video_flags = SDL_SWSURFACE | SDL_HWPALETTE ;
-	if (fullscreen_on) video_flags |= SDL_FULLSCREEN;
+	if (GameConfig . fullscreen_on) video_flags |= SDL_FULLSCREEN;
 	
 	if( !(Screen = SDL_SetVideoMode ( GameConfig . screen_width, GameConfig . screen_height , 0 , video_flags )) )
 	{
@@ -2141,7 +2084,7 @@ InitVideo (void)
     if ( vid_info->wm_available )  /* if there's a window-manager */
     {
 	SDL_WM_SetCaption ( window_title_string , "" );
-	fpath = find_file ( ICON_FILE , GRAPHICS_DIR , FALSE );
+	find_file (ICON_FILE , GRAPHICS_DIR , fpath, 0 );
 	SDL_WM_SetIcon( our_IMG_load_wrapper ( fpath ) , NULL );
     }
     
