@@ -556,13 +556,13 @@ blit_classic_SDL_light_radius( void )
 {
     static int first_call = TRUE ;
     int i, j ;
-    char* fpath;
+char fpath[2048];
     char constructed_file_name[2000];
     int our_height, our_width, our_max_height, our_max_width;
     int light_strength;
     moderately_finepoint target_pos;
-    static int pos_x_grid [ (int)(FLOOR_TILES_VISIBLE_AROUND_TUX * ( 1.0 / LIGHT_RADIUS_CHUNK_SIZE ) * 2) ] [ (int)(FLOOR_TILES_VISIBLE_AROUND_TUX * ( 1.0 / LIGHT_RADIUS_CHUNK_SIZE ) * 2 ) ] ;
-    static int pos_y_grid [ (int)(FLOOR_TILES_VISIBLE_AROUND_TUX * ( 1.0 / LIGHT_RADIUS_CHUNK_SIZE ) * 2) ] [ (int)(FLOOR_TILES_VISIBLE_AROUND_TUX * ( 1.0 / LIGHT_RADIUS_CHUNK_SIZE ) * 2 ) ] ;
+    static int pos_x_grid [ (int)(MAX_FLOOR_TILES_VISIBLE_AROUND_TUX * ( 1.0 / LIGHT_RADIUS_CHUNK_SIZE ) * 2) ] [ (int)(MAX_FLOOR_TILES_VISIBLE_AROUND_TUX * ( 1.0 / LIGHT_RADIUS_CHUNK_SIZE ) * 2 ) ] ;
+    static int pos_y_grid [ (int)(MAX_FLOOR_TILES_VISIBLE_AROUND_TUX * ( 1.0 / LIGHT_RADIUS_CHUNK_SIZE ) * 2) ] [ (int)(MAX_FLOOR_TILES_VISIBLE_AROUND_TUX * ( 1.0 / LIGHT_RADIUS_CHUNK_SIZE ) * 2 ) ] ;
     static SDL_Rect target_rectangle;
     int chunk_size_x;
     int chunk_size_y;
@@ -578,7 +578,7 @@ blit_classic_SDL_light_radius( void )
 	for ( i = 0 ; i < NUMBER_OF_SHADOW_IMAGES ; i ++ )
 	{
 	    sprintf ( constructed_file_name , "light_radius_chunks/iso_light_radius_darkness_%04d.png" , i + 1 );
-	    fpath = find_file ( constructed_file_name , GRAPHICS_DIR , FALSE );
+	    find_file (constructed_file_name , GRAPHICS_DIR , fpath, 0 );
 	    get_iso_image_from_file_and_path ( fpath , & ( light_radius_chunk [ i ] ) , TRUE ) ;
 	    tmp = light_radius_chunk [ i ] . surface ;
 	    light_radius_chunk [ i ] . surface = SDL_DisplayFormatAlpha ( light_radius_chunk [ i ] . surface ) ; 
