@@ -65,15 +65,15 @@ extern SDL_Surface *zoomSurface(SDL_Surface * src, double zoomx, double zoomy, i
 
 mouse_press_button AllMousePressButtons[ MAX_MOUSE_PRESS_BUTTONS ] =
   {
-    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 216 , 480-46 ,  46 ,  14 } , TRUE , FALSE } ,
-    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 307 , 480-46 ,  46 ,  14 } , TRUE , FALSE } ,
-    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 261 , 480-46 ,  46 ,  14 } , TRUE , FALSE } ,
-    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 354 , 480-46 ,  46 ,  14 } , TRUE , FALSE } ,
-    { UNLOADED_ISO_IMAGE , "mouse_buttons/cha_button_red.png"               , { 307 , 480-46 ,  46 ,  14 } , TRUE , FALSE } ,
-    { UNLOADED_ISO_IMAGE , "mouse_buttons/log_button_yellow.png"            , { 216 , 480-46 ,  46 ,  14 } , TRUE , FALSE } ,
-    { UNLOADED_ISO_IMAGE , "mouse_buttons/cha_button_yellow.png"            , { 307 , 480-46 ,  46 ,  14 } , TRUE , FALSE } ,
-    { UNLOADED_ISO_IMAGE , "mouse_buttons/inv_button_yellow.png"            , { 261 , 480-46 ,  46 ,  14 } , TRUE , FALSE } ,
-    { UNLOADED_ISO_IMAGE , "mouse_buttons/ski_button_yellow.png"            , { 354 , 480-46 ,  46 ,  14 } , TRUE , FALSE } ,
+    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 239 , 480-47 ,  46 ,  14 } , TRUE , FALSE } ,
+    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 334 , 480-47 ,  46 ,  14 } , TRUE , FALSE } ,
+    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 283 , 480-47 ,  46 ,  14 } , TRUE , FALSE } ,
+    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 378 , 480-47 ,  46 ,  14 } , TRUE , FALSE } ,
+    { UNLOADED_ISO_IMAGE , "mouse_buttons/cha_button_red.png"               , { 334 , 480-47 ,  46 ,  14 } , TRUE , FALSE } ,
+    { UNLOADED_ISO_IMAGE , "mouse_buttons/log_button_yellow.png"            , { 239 , 480-47 ,  46 ,  14 } , TRUE , FALSE } ,
+    { UNLOADED_ISO_IMAGE , "mouse_buttons/cha_button_yellow.png"            , { 334 , 480-47 ,  46 ,  14 } , TRUE , FALSE } ,
+    { UNLOADED_ISO_IMAGE , "mouse_buttons/inv_button_yellow.png"            , { 283 , 480-47 ,  46 ,  14 } , TRUE , FALSE } ,
+    { UNLOADED_ISO_IMAGE , "mouse_buttons/ski_button_yellow.png"            , { 378 , 480-47 ,  46 ,  14 } , TRUE , FALSE } ,
     { UNLOADED_ISO_IMAGE , "mouse_buttons/UPButton.png"                     , { 600 ,  94 ,  40 ,  40 } , TRUE , FALSE } ,
     { UNLOADED_ISO_IMAGE , "mouse_buttons/DOWNButton.png"                   , { 600 , 316 ,  40 ,  40 } , TRUE , FALSE } ,
     { UNLOADED_ISO_IMAGE , "mouse_buttons/LEFTButton.png"                   , { 300 ,   5 , 100 ,  50 } , TRUE , FALSE } ,
@@ -120,8 +120,8 @@ mouse_press_button AllMousePressButtons[ MAX_MOUSE_PRESS_BUTTONS ] =
     { UNLOADED_ISO_IMAGE , "mouse_buttons/RightShopButton.png"              , { 576 , 447 ,  26 ,  26 } , TRUE , FALSE } ,
     { UNLOADED_ISO_IMAGE , "mouse_buttons/LeftShopButton.png"               , {   5 ,  16 ,  26 ,  26 } , TRUE , FALSE } ,
     { UNLOADED_ISO_IMAGE , "mouse_buttons/RightShopButton.png"              , { 580 ,  13 ,  26 ,  26 } , TRUE , FALSE } ,
-    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , {  3 ,  25 ,  15 ,  60 } , FALSE , FALSE } ,
-    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                       , { 620 ,  26 ,  15 ,  60 } , FALSE , FALSE } ,
+    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorObjectSelectorLeft.png", {  3 ,  25 ,  15 ,  60 } , FALSE , FALSE } ,
+    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorObjectSelectorRight.png", { 620 ,  26 ,  15 ,  60 } , FALSE , FALSE } ,
 
     { UNLOADED_ISO_IMAGE , "mouse_buttons/number_selector_ok_button.png"    , { 308 , 288 ,  48 ,  48 } , TRUE , FALSE } ,
     { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 148 , 244 ,  35 ,  35 } , TRUE , FALSE } ,
@@ -134,7 +134,7 @@ mouse_press_button AllMousePressButtons[ MAX_MOUSE_PRESS_BUTTONS ] =
     { UNLOADED_ISO_IMAGE , "mouse_buttons/repair_button.png"                , { 199 , 225 ,  47 ,  47 } , TRUE , FALSE } ,
     { UNLOADED_ISO_IMAGE , "mouse_buttons/identify_button.png"              , { 199 , 275 ,  47 ,  47 } , TRUE , FALSE } ,
 
-    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 0 + 11 , 435 , 271 , 18 } , FALSE , FALSE } ,
+    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 0 + 17 , 424 , 33 , 33 } , FALSE , FALSE } ,
 
     { UNLOADED_ISO_IMAGE , "mouse_buttons/GoLevelNorthButton.png"           , { -50-6 , -50-8 , 25 ,  25 } , FALSE , FALSE } ,
     { UNLOADED_ISO_IMAGE , "mouse_buttons/GoLevelSouthButton.png"           , { -50-6 , -4-25 , 25 ,  25 } , FALSE , FALSE } ,
@@ -176,6 +176,9 @@ mouse_press_button AllMousePressButtons[ MAX_MOUSE_PRESS_BUTTONS ] =
     { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorToggleTooltipsButtonOff.png"  , { 300 , 90 , 0 ,  0 } , FALSE , FALSE } , 
     { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorToggleCollisionRectsButton.png"  , { 330 , 90 , 0 ,  0 } , FALSE , FALSE } , 
     { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorToggleCollisionRectsButtonOff.png"  , { 330 , 90 , 0 ,  0 } , FALSE , FALSE } , 
+    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorToggleGridButton.png"  , { 360 , 90 , 0 ,  0 } , FALSE , FALSE } , 
+    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorToggleGridButtonFull.png"  , { 360 , 90 , 0 ,  0 } , FALSE , FALSE } , 
+    { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorToggleGridButtonOff.png"  , { 360 , 90 , 0 ,  0 } , FALSE , FALSE } , 
 
     { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorNextItemGroup.png"     , { 55 + 64 * 8 , 32+5*66 , 0 ,  0 } , TRUE , FALSE } ,
     { UNLOADED_ISO_IMAGE , "mouse_buttons/LevelEditorPrevItemGroup.png"     , { 55          , 32+5*66 , 0 ,  0 } , TRUE , FALSE } ,
@@ -202,10 +205,10 @@ mouse_press_button AllMousePressButtons[ MAX_MOUSE_PRESS_BUTTONS ] =
     { UNLOADED_ISO_IMAGE , "mouse_buttons/ScrollDialogMenuUp.png"           , { 235 , (480-20-130-20-2) , 160 ,  20 } , TRUE , FALSE } ,
     { UNLOADED_ISO_IMAGE , "mouse_buttons/ScrollDialogMenuDown.png"         , { 235 , (480-22) , 160 ,  20 } , TRUE , FALSE } ,
 
-    { UNLOADED_ISO_IMAGE , "mouse_buttons/AttributePlusButton.png"                   , { 0 + BUTTON_MOD_X + STR_NOW_X  , STR_Y  , 38 , 22 } , FALSE , FALSE } ,
-    { UNLOADED_ISO_IMAGE , "mouse_buttons/AttributePlusButton.png"                   , { 0 + BUTTON_MOD_X + STR_NOW_X  , MAG_Y  , 38 , 22 } , FALSE , FALSE } ,
-    { UNLOADED_ISO_IMAGE , "mouse_buttons/AttributePlusButton.png"                   , { 0 + BUTTON_MOD_X + STR_NOW_X  , DEX_Y  , 38 , 22 } , FALSE , FALSE } ,
-    { UNLOADED_ISO_IMAGE , "mouse_buttons/AttributePlusButton.png"                   , { 0 + BUTTON_MOD_X + STR_NOW_X  , VIT_Y  , 38 , 22 } , FALSE , FALSE } ,
+    { UNLOADED_ISO_IMAGE , "mouse_buttons/AttributePlusButton.png"                   , { 0 + STR_X + 45 , STR_Y - 5 , 38 , 22 } , FALSE , FALSE } ,
+    { UNLOADED_ISO_IMAGE , "mouse_buttons/AttributePlusButton.png"                   , { 0 + STR_X + 45 , MAG_Y - 5 , 38 , 22 } , FALSE , FALSE } ,
+    { UNLOADED_ISO_IMAGE , "mouse_buttons/AttributePlusButton.png"                   , { 0 + STR_X + 45 , DEX_Y - 5 , 38 , 22 } , FALSE , FALSE } ,
+    { UNLOADED_ISO_IMAGE , "mouse_buttons/AttributePlusButton.png"                   , { 0 + STR_X + 45 , VIT_Y - 5 , 38 , 22 } , FALSE , FALSE } ,
 
     //--------------------
     // These two buttons are for the scrolling text during the
@@ -233,16 +236,17 @@ mouse_press_button AllMousePressButtons[ MAX_MOUSE_PRESS_BUTTONS ] =
     { UNLOADED_ISO_IMAGE , "mouse_buttons/ScrollDialogMenuOff.png"          , { 342 , 272 , 160 ,  20 } , TRUE , TRUE } ,
 
     //--------------------
-    // These 7 buttons are for the level editor and will not need
+    // These 8 buttons are for the level editor and will not need
     // any scaling...
     //
-    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 0   , 3 , 99 ,  14 } , FALSE , FALSE } ,
-    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 102 , 3 , 99 ,  14 } , FALSE , FALSE } ,
-    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 203 , 3 , 99 ,  14 } , FALSE , FALSE } ,
-    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 304 , 3 , 99 ,  14 } , FALSE , FALSE } ,
-    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 405 , 3 , 99 ,  14 } , FALSE , FALSE } ,
-    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 506 , 3 , 99 ,  14 } , FALSE , FALSE } ,
-    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 606 , 3 , 34 ,  14 } , FALSE , FALSE } ,
+    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 0   , 0 , 78 ,  14 } , FALSE , FALSE } ,
+    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 80  , 0 , 78 ,  14 } , FALSE , FALSE } ,
+    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 160 , 0 , 78 ,  14 } , FALSE , FALSE } ,
+    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 240 , 0 , 78 ,  14 } , FALSE , FALSE } ,
+    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 320 , 0 , 78 ,  14 } , FALSE , FALSE } ,
+    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 400 , 0 , 78 ,  14 } , FALSE , FALSE } ,
+    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 480 , 0 , 78 ,  14 } , FALSE , FALSE } ,
+    { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 560 , 0 , 78 ,  14 } , FALSE , FALSE } ,
 
 
     { UNLOADED_ISO_IMAGE , "THIS_DOESNT_NEED_BLITTING"                      , { 486 , 324  , 73 ,  73 } , TRUE , FALSE } ,
@@ -252,10 +256,10 @@ mouse_press_button AllMousePressButtons[ MAX_MOUSE_PRESS_BUTTONS ] =
     { UNLOADED_ISO_IMAGE , "mouse_buttons/quest_browser_done_quests_off.png" , { 478 , 149 , 153 ,  38 } , TRUE , FALSE } ,
     { UNLOADED_ISO_IMAGE , "mouse_buttons/quest_browser_notes.png"          , { 478 , 203 , 153 ,  38 } , TRUE , FALSE } ,
     { UNLOADED_ISO_IMAGE , "mouse_buttons/quest_browser_notes_off.png"      , { 478 , 203 , 153 ,  38 } , TRUE , FALSE } ,
-    { UNLOADED_ISO_IMAGE , "mouse_buttons/ScrollDialogMenuUp.png"           , { 183 , 8   , 160 ,  20 } , TRUE , TRUE } ,
-    { UNLOADED_ISO_IMAGE , "mouse_buttons/ScrollDialogMenuDown.png"         , { 183 , 450 , 160 ,  20 } , TRUE , TRUE } ,
-    { UNLOADED_ISO_IMAGE , "mouse_buttons/quest_browser_item_short.png"     , { 108 , 86  , 26  ,  26 } , TRUE , TRUE } ,
-    { UNLOADED_ISO_IMAGE , "mouse_buttons/quest_browser_item_long.png"      , { 108 , 86  , 26  ,  26 } , TRUE , TRUE } ,
+    { UNLOADED_ISO_IMAGE , "mouse_buttons/ScrollDialogMenuUp.png"           , { 181 , 12   , 160 ,  20 } , TRUE , TRUE } ,
+    { UNLOADED_ISO_IMAGE , "mouse_buttons/ScrollDialogMenuDown.png"         , { 181 , 452 , 160 ,  20 } , TRUE , TRUE } ,
+    { UNLOADED_ISO_IMAGE , "mouse_buttons/quest_browser_item_short.png"     , { 108 , 86  , 26  ,  26 } , FALSE , TRUE } ,
+    { UNLOADED_ISO_IMAGE , "mouse_buttons/quest_browser_item_long.png"      , { 108 , 86  , 26  ,  26 } , FALSE , TRUE } ,
 
     { UNLOADED_ISO_IMAGE , "mouse_buttons/takeover_help_button.png"         , { 78 , 23 , 153 ,  38 } , FALSE , FALSE } ,
 
@@ -566,7 +570,7 @@ void
 ShowGenericButtonFromList ( int ButtonIndex )
 { 
     SDL_Surface *tmp;
-    char *fpath;
+char fpath[2048];
     SDL_Rect Temp_Blitting_Rect;
     
     //--------------------
@@ -599,7 +603,7 @@ button index given exceeds the number of buttons defined in freedroid.",
     if ( ( AllMousePressButtons [ ButtonIndex ] . button_image . surface == NULL ) &&
 	 ( ! AllMousePressButtons [ ButtonIndex ] . button_image . texture_has_been_created ) )
     {
-	fpath = find_file ( AllMousePressButtons[ ButtonIndex ] . button_image_file_name , GRAPHICS_DIR, FALSE);
+	find_file (AllMousePressButtons[ ButtonIndex ] . button_image_file_name , GRAPHICS_DIR, fpath, 0);
 	tmp = our_IMG_load_wrapper( fpath );
 	if ( tmp == NULL )
 	{
@@ -608,7 +612,8 @@ button index given exceeds the number of buttons defined in freedroid.",
 An image file for a button that should be displayed on the screen couldn't\n\
 be successfully loaded into memory.\n\
 This is an indication of a severe bug/installation problem of freedroid.",
-				       PLEASE_INFORM, IS_FATAL );
+				       PLEASE_INFORM, IS_WARNING_ONLY );
+	return;
 	}
 	AllMousePressButtons[ ButtonIndex ] . button_image . surface = our_SDL_display_format_wrapperAlpha ( tmp );
 	SDL_FreeSurface ( tmp );
@@ -665,7 +670,7 @@ This is an indication of a severe bug/installation problem of freedroid.",
 
     if ( use_open_gl )
     {
-	blit_open_gl_texture_to_screen_position ( AllMousePressButtons [ ButtonIndex ] . button_image , Temp_Blitting_Rect . x , Temp_Blitting_Rect . y , TRUE ) ;
+	blit_open_gl_texture_to_screen_position ( &AllMousePressButtons [ ButtonIndex ] . button_image , Temp_Blitting_Rect . x , Temp_Blitting_Rect . y , TRUE ) ;
     }
     else
     {
@@ -711,52 +716,19 @@ char *our_config_dir = NULL;
 
 /* -----------------------------------------------------------------
  * find a given filename in subdir relative to FD_DATADIR, 
- * using theme subdir if use_theme==TRUE
  *
  * if you pass NULL as subdir, it will be ignored
  *
- * returns pointer to _static_ string array File_Path, which 
- * contains the full pathname of the file.
- *
- * !! do never try to free the returned string !!
+ * fills in the (ALLOC'd) string and returns 0 if okay, 1 on error
  *
  * ----------------------------------------------------------------- */
-char *
-find_file (char *fname, char *subdir, int use_theme)
+int
+find_file (char *fname, char *subdir, char * File_Path, int silent)
 {
-    //--------------------
-    // WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! 
-    // 
-    // WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! 
-    //
-    // This hack will only work if there is NEVER ANY NESTED use of find_file!!
-    // Otherwise one file is found, a new search is started and overwrites the
-    // previous file name.  If that one is then used again, unpredictable results
-    // may occur.
-    //
-    // But the benefit of it is, of course, that memory leaking will be reduced,
-    // even if the returned string is never freed, as it must be to prevent
-    // segmentation faults this way anyway!
-    //
-    // WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! 
-    // 
-    // WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! 
-    //
-    // 
-    // Because of the things mentioned above, FIND_FILE MUST NOT EVER BE USED
-    // FROM A CALLBACK FUNCTION, cause then it migth be A NESTED FUNCTION CALL!
-    //
-    // IN Case of a Callback function, best use a separate version of this function,
-    // best called find_file_for_callbacks.
-    //
-    // WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! 
-    // 
-    // WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! 
-    //
     int i;
-    static char File_Path[5000];   /* hope this will be enough */
     FILE *fp;  // this is the file we want to find?
     
+    *File_Path=0;
     if (!fname)
     {
 	GiveStandardErrorMessage ( __FUNCTION__  , "\
@@ -770,20 +742,18 @@ This is indicates a severe bug in Freedroid.",  PLEASE_INFORM, IS_FATAL );
     for ( i = 0 ; i < 2 ; i++ )
     {
 	if (i==0)
-	    strcpy (File_Path, "..");   /* first try local subdirs */
+	    sprintf ((File_Path), "..");   /* first try local subdirs */
 	if (i==1)
-	    strcpy (File_Path, FD_DATADIR); /* then the DATADIR */
+	    sprintf ((File_Path), "%s", FD_DATADIR); /* then the DATADIR */
 	
-	strcat (File_Path, "/");
-	strcat (File_Path, subdir);
-	strcat (File_Path, "/");
+	strcat ((File_Path), "/");
+	strcat ((File_Path), subdir);
+	strcat ((File_Path), "/");
 	
-	if (use_theme)
-	    strcat (File_Path, GameConfig.Theme_SubPath);
 	
-	strcat (File_Path, fname);
+	strcat ((File_Path), fname);
 	
-	if ( (fp = fopen (File_Path, "rb")) != NULL)  /* found it? */
+	if ( (fp = fopen ((File_Path), "r")) != NULL)  /* found it? */
 	{
 	    fclose (fp);
 	    break;
@@ -793,218 +763,23 @@ This is indicates a severe bug in Freedroid.",  PLEASE_INFORM, IS_FATAL );
 	    if ( i == 0 )
 		DebugPrintf( 1 , "\nfind_file could not succeed with LOCAL path: %s." , File_Path );
 	    else
-	    {
-		DebugPrintf ( -4 , "The file name was: %s.\n" , fname );
-		GiveStandardErrorMessage ( __FUNCTION__  , "File not found even in data dir (2nd attempt).", 
+		{
+                if ( ! silent )
+	    	    {
+		    DebugPrintf ( -4 , "The file name was: %s.\n" , fname );
+		    GiveStandardErrorMessage ( __FUNCTION__  , "File not found even in data dir (2nd attempt).", 
 					   NO_NEED_TO_INFORM , IS_WARNING_ONLY );
-	    }
+		    }
+		return 1;
+	        }
 	}
     } // for i 
     
     // DebugPrintf( 0 , "\nfind_file determined file path: %s." , File_Path );
     
-    return (File_Path);
-    
+    return 0;    
 }; // char * find_file ( ... )
 
-/* -----------------------------------------------------------------
- * find a given filename in subdir relative to FD_DATADIR, 
- * using theme subdir if use_theme==TRUE
- *
- * if you pass NULL as subdir, it will be ignored
- *
- * returns pointer to _static_ string array File_Path, which 
- * contains the full pathname of the file.
- *
- * !! do never try to free the returned string !!
- *
- * ----------------------------------------------------------------- */
-char *
-find_file_silent (char *fname, char *subdir, int use_theme)
-{
-    //--------------------
-    // WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! 
-    // 
-    // WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! 
-    //
-    // This hack will only work if there is NEVER ANY NESTED use of find_file!!
-    // Otherwise one file is found, a new search is started and overwrites the
-    // previous file name.  If that one is then used again, unpredictable results
-    // may occur.
-    //
-    // But the benefit of it is, of course, that memory leaking will be reduced,
-    // even if the returned string is never freed, as it must be to prevent
-    // segmentation faults this way anyway!
-    //
-    // WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! 
-    // 
-    // WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! 
-    //
-    // 
-    // Because of the things mentioned above, FIND_FILE MUST NOT EVER BE USED
-    // FROM A CALLBACK FUNCTION, cause then it migth be A NESTED FUNCTION CALL!
-    //
-    // IN Case of a Callback function, best use a separate version of this function,
-    // best called find_file_for_callbacks.
-    //
-    // WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! 
-    // 
-    // WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! 
-    //
-    int i;
-    static char File_Path[5000];   /* hope this will be enough */
-    FILE *fp;  // this is the file we want to find?
-
-    DebugPrintf ( 2 , "\n%s(): received fname=%s subdir=%s use_theme=%d." ,
-		  __FUNCTION__ , fname , subdir , use_theme );
-    
-    if (!fname)
-    {
-	GiveStandardErrorMessage ( __FUNCTION__  , "\
-A find_file call has been issued to generate the full path name of a\n\
-certain file, but the file name given is an empty string!\n\
-This is indicates a severe bug in Freedroid.",  PLEASE_INFORM, IS_FATAL );
-    }
-    if (!subdir)
-	subdir = "";
-    
-    for ( i = 0 ; i < 2 ; i++ )
-    {
-	if (i==0)
-	    strcpy (File_Path, "..");   // first try local subdirs 
-	if (i==1)
-	    strcpy (File_Path, FD_DATADIR); // then the DATADIR 
-	
-	strcat (File_Path, "/");
-	strcat (File_Path, subdir);
-	strcat (File_Path, "/");
-	
-	if ( use_theme )
-	    strcat ( File_Path , GameConfig . Theme_SubPath );
-	
-	strcat ( File_Path , fname );
-	
-	if ( ( fp = fopen ( File_Path , "rb" ) ) != NULL )  // found it? 
-	{
-	    fclose (fp);
-	    break;
-	}
-	else
-	{
-	    //--------------------
-	    // This is the *silent* version of the find-file function,
-	    // so we don't do anything here...
-	    //
-	    if ( i >= 1 )
-	    {
-		DebugPrintf ( 1 , "\n%s(): returning NULL!" , __FUNCTION__ );
-		return ( NULL );
-	    }
-	}
-    } // for i 
-    
-    // DebugPrintf( 0 , "\nfind_file determined file path: %s." , File_Path );
-    
-    DebugPrintf ( 2 , "\n%s(): returning suposedly non-NULL!" , __FUNCTION__ );
-    return ( File_Path );
-    
-}; // char * find_file_silent ( ... )
-
-/* -----------------------------------------------------------------
- * find a given filename in subdir relative to FD_DATADIR, 
- * using theme subdir if use_theme==TRUE
- *
- * if you pass NULL as subdir, it will be ignored
- *
- * returns pointer to _static_ string array File_Path, which 
- * contains the full pathname of the file.
- *
- * !! do never try to free the returned string !!
- *
- * ----------------------------------------------------------------- */
-char *
-find_file_for_callbacks (char *fname, char *subdir, int use_theme)
-{
-
-  //--------------------
-  // WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! 
-  // 
-  // WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! 
-  //
-  // This hack will only work if there is NEVER ANY NESTED use of find_file!!
-  // Otherwise one file is found, a new search is started and overwrites the
-  // previous file name.  If that one is then used again, unpredictable results
-  // may occur.
-  //
-  // But the benefit of it is, of course, that memory leaking will be reduced,
-  // even if the returned string is never freed, as it must be to prevent
-  // segmentation faults this way anyway!
-  //
-  // WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! 
-  // 
-  // WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! 
-  //
-  // 
-  // Because of the things mentioned above, FIND_FILE MUST NOT EVER BE USED
-  // FROM A CALLBACK FUNCTION, cause then it migth be A NESTED FUNCTION CALL!
-  //
-  // IN Case of a Callback function, best use a separate version of this function,
-  // best called find_file_for_callbacks.
-  //
-  // WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! 
-  // 
-  // WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! WARNING! 
-  //
-  int i;
-  static char File_Path[5000];   /* hope this will be enough */
-  FILE *fp;  // this is the file we want to find?
-
-  if (!fname)
-    {
-      GiveStandardErrorMessage ( __FUNCTION__  , "\
-A find_file call has been issued to generate the full path name of a\n\
-certain file, but the file name given is an empty string!\n\
-This is indicates a severe bug in Freedroid.",
-				 PLEASE_INFORM, IS_FATAL );
-    }
-  if (!subdir)
-    subdir = "";
-
-  for ( i = 0 ; i < 2 ; i++ )
-    {
-      if (i==0)
-	strcpy (File_Path, "..");   /* first try local subdirs */
-      if (i==1)
-	strcpy (File_Path, FD_DATADIR); /* then the FD_DATADIR */
-
-      strcat (File_Path, "/");
-      strcat (File_Path, subdir);
-      strcat (File_Path, "/");
-
-      if (use_theme)
-	strcat (File_Path, GameConfig.Theme_SubPath);
-
-      strcat (File_Path, fname);
-      
-      if ( (fp = fopen (File_Path, "rb")) != NULL)  /* found it? */
-	{
-	  fclose (fp);
-	  break;
-	}
-      else
-	{
-	  if ( i == 0 )
-	    DebugPrintf( 1 , "\nfind_file could not succeed with LOCAL path: %s." , File_Path );
-	  else
-	    GiveStandardErrorMessage ( __FUNCTION__  , "File not found even in data dir (2nd attempt).", NO_NEED_TO_INFORM , IS_WARNING_ONLY );
-	}
-    } // for i 
-
-  // DebugPrintf( 0 , "\nfind_file determined file path: %s." , File_Path );
-
-  return (File_Path);
-	
-}; // char * find_file_for_callbacks ( ... )
 
 /* ----------------------------------------------------------------------
  * This function realises the Pause-Mode: the game process is halted,
@@ -1022,7 +797,7 @@ Pause ( void )
     
     Me [ 0 ] . status = PAUSE;
     AssembleCombatPicture ( DO_SCREEN_UPDATE | USE_OWN_MOUSE_CURSOR );
-    append_new_game_message ( "Pausing game..." );
+    append_new_game_message ( _("Pausing game...") );
     while ( PPressed () )
 	SDL_Delay (1); /* Wait for the pause key to be released */
 
@@ -1033,7 +808,7 @@ Pause ( void )
 	DisplayBanner ( );
 	AssembleCombatPicture ( USE_OWN_MOUSE_CURSOR );
 /*	CenteredPutStringFont ( Screen , Message_BFont , 200 , "G A M E     P A U S E D" ) ;*/
-	CenteredPutStringFont ( Screen , Menu_BFont , 200 , "GAME PAUSED" ) ;
+	CenteredPutStringFont ( Screen , Menu_BFont , 200 , _("GAME PAUSED") );
 	our_SDL_flip_wrapper ( Screen );
 	
 	if ( CPressed ( ) )
@@ -1063,7 +838,7 @@ Pause ( void )
 	
     } // while (Pause) 
 
-    append_new_game_message ( "Game resumed." );
+    append_new_game_message ( _("Game resumed.") );
     return;
 
 }; // void Pause ( void ) 
@@ -1504,7 +1279,7 @@ move_all_items_to_level ( int target_level )
  * ship.  THIS CAN BE A POSITION ON A DIFFERENT LEVEL.
  * ---------------------------------------------------------------------- */
 void
-Teleport ( int LNum , float X , float Y , int PlayerNum , int Shuffling , int with_sound_and_fading )
+Teleport ( int LNum , float X , float Y , int PlayerNum , int with_sound_and_fading )
 {
     int curLevel = LNum;
     int array_num = 0;
@@ -1563,8 +1338,6 @@ Teleport ( int LNum , float X , float Y , int PlayerNum , int Shuffling , int wi
 	//
 	CurLevel = curShip . AllLevels [ array_num ] ;
 	
-	ClearDetectedItemList ( PlayerNum );
-	
 	Me [ PlayerNum ] . pos . x = X;
 	Me [ PlayerNum ] . pos . y = Y;
 	Me [ PlayerNum ] . pos . z = array_num; 
@@ -1691,7 +1464,7 @@ This indicates an error in the map system of Freedroid.",
     
     if ( with_sound_and_fading ) 
     {
-	sprintf ( game_message_text , "Arrived at %s." , curShip . AllLevels [ Me [ PlayerNum ] . pos . z ] -> Levelname );
+	sprintf ( game_message_text , _("Arrived at %s.") , curShip . AllLevels [ Me [ PlayerNum ] . pos . z ] -> Levelname );
 	append_new_game_message ( game_message_text );
 	AssembleCombatPicture ( SHOW_ITEMS | USE_OWN_MOUSE_CURSOR ); 
 	//our_SDL_flip_wrapper ( Screen );
@@ -1797,6 +1570,7 @@ settings file will be generated.",
     GameConfig . Inventory_Visible = FALSE ;
     GameConfig . Mission_Log_Visible = FALSE ;
     GameConfig . SkillScreen_Visible = FALSE ;
+    GameConfig . skill_explanation_screen_visible = FALSE ;
     GameConfig . Automap_Visible = FALSE ;
     
     if ( command_line_override_for_screen_resolution )
@@ -1824,14 +1598,6 @@ output.",
 				   NO_NEED_TO_INFORM , IS_WARNING_ONLY );
     }
 
-    //--------------------
-    // In OpenGL, there is no need for the reduced menu display (which is
-    // based on restoring a saved "screenshot", which isn't working so well
-    // in OpenGL anyway) so we don't even allow for reduced menus in this
-    // mode.
-    //
-    if ( use_open_gl ) GameConfig . menu_mode = MENU_MODE_DEFAULT;
-
     return (OK);
     
 }; // int LoadGameConfig ( void )
@@ -2182,9 +1948,13 @@ ExecuteEvent ( int EventNumber , int PlayerNum )
     {
 	our_obstacle = give_pointer_to_obstacle_with_label ( AllTriggeredActions [ EventNumber ] . modify_obstacle_with_label ) ;
 	obstacle_level_num = give_level_of_obstacle_with_label ( AllTriggeredActions [ EventNumber ] . modify_obstacle_with_label ) ;
-	our_obstacle -> type = AllTriggeredActions [ EventNumber ] . modify_obstacle_to_type ;
-	
 	obstacle_level = curShip . AllLevels [ obstacle_level_num ] ;
+	if ( AllTriggeredActions [ EventNumber ] . modify_obstacle_to_type )
+		our_obstacle -> type = AllTriggeredActions [ EventNumber ] . modify_obstacle_to_type ;
+	else {
+		delete_obstacle (  curShip . AllLevels [ obstacle_level_num ], our_obstacle);
+	     }
+
 	//--------------------
 	// Now we make sure the door lists and that are all updated...
 	//
@@ -2210,7 +1980,7 @@ ExecuteEvent ( int EventNumber , int PlayerNum )
 	Teleport ( AllTriggeredActions[ EventNumber ].TeleportTargetLevel ,
 		   AllTriggeredActions[ EventNumber ].TeleportTarget.x + 0.5 ,
 		   AllTriggeredActions[ EventNumber ].TeleportTarget.y + 0.5 ,
-		   PlayerNum , FALSE , TRUE );
+		   PlayerNum , TRUE );
     }
     
     // Does the defined action assign the influencer a mission?
@@ -2226,7 +1996,37 @@ ExecuteEvent ( int EventNumber , int PlayerNum )
 	Me[0].TextVisibleTime=0;
 	Me[0].TextToBeDisplayed=AllTriggeredActions[ EventNumber ].InfluencerSayText;
     }
-    
+
+    // Does the defined action change another action trigger?
+    if ( strlen ( AllTriggeredActions[ EventNumber ] . modify_event_trigger_with_action_label ) > 0 )
+	{
+	//look for the target event trigger
+	event_trigger * target_event = NULL;
+	int i;
+        for ( i = 0 ; i < MAX_EVENT_TRIGGERS ; i++ )
+		{
+		if ( ! strcmp (AllEventTriggers[i].TargetActionLabel ,  AllTriggeredActions[ EventNumber ] . modify_event_trigger_with_action_label ) )
+			target_event = &AllEventTriggers[i];
+		}
+	
+	//Shall we disable the event trigger?
+	if ( AllTriggeredActions[ EventNumber ] . modify_event_trigger_value == 0 )
+		{
+		target_event -> enabled = 0;
+		}
+
+	//Shall we enable the event trigger?
+	if ( AllTriggeredActions[ EventNumber ] . modify_event_trigger_value == 1 )
+		{
+		target_event -> enabled = 1;
+		}
+	}
+
+   // Does the defined action run another action ?
+   if ( strlen ( AllTriggeredActions [ EventNumber ] . also_execute_action_label ) > 0 )
+	{
+	ExecuteActionWithLabel ( AllTriggeredActions [ EventNumber ] . also_execute_action_label, 0 );
+	}
 }; // void ExecuteEvent ( int EventNumber )
 
 /* ----------------------------------------------------------------------
@@ -2269,6 +2069,7 @@ CheckForTriggeredEventsAndStatements ( int PlayerNum )
     {
 	// if ( AllEventTriggers[i].EventNumber == (-1) ) continue;  // thats a sure sign this event doesn't need attention
 	if ( strcmp (AllEventTriggers[i].TargetActionLabel , "none" ) == 0 ) continue;  // thats a sure sign this event doesn't need attention
+	if ( AllEventTriggers[i].enabled == 0 ) continue;  // this trigger is not enabled
 	
 	// --------------------
 	// So at this point we know, that the event trigger is somehow meaningful. 
@@ -2342,7 +2143,7 @@ ReadSint16 (void * memory)
   Sint16 ret;
 
   memcpy (&ret, memory, sizeof(Sint16));
-#ifdef __APPLE_CC__
+#if SDL_BYTEORDER == SDL_BIG_ENDIAN
   endian_swap ( (char*)&ret, sizeof (Sint16), 1);
 #endif
 
