@@ -3,7 +3,6 @@
  *   Copyright (c) 1994, 2002, 2003 Johannes Prix
  *   Copyright (c) 1994, 2002 Reinhard Prix
  *
- *
  *  This file is part of Freedroid
  *
  *  Freedroid is free software; you can redistribute it and/or modify
@@ -35,7 +34,6 @@
 #define EXTERN extern
 #endif
 
-
 // automap.c
 #undef EXTERN
 #ifdef _automap_c
@@ -60,7 +58,7 @@ EXTERN void ResetGameConfigToDefaultValues ( void );
 EXTERN void ShowStartupPercentage ( int Percentage ) ;
 EXTERN void ParseCommandLine ( int argc , char *const argv[] );
 EXTERN void ClearAutomapData( void );
-EXTERN void InitFreedroid ( void );
+EXTERN void InitFreedroid ( int, char ** );
 EXTERN void PrepareStartOfNewCharacter ( void ) ;
 EXTERN void ThouArtDefeated ( void );
 EXTERN void ThouHastWon ( void );
@@ -89,16 +87,28 @@ EXTERN void InitInfluPositionHistory( int player_num );
 EXTERN float GetInfluPositionHistoryX( int Index );
 EXTERN float GetInfluPositionHistoryY( int Index );
 EXTERN float GetInfluPositionHistoryZ( int Index );
-EXTERN void FireTuxRangedWeaponRaw ( int player_num , int weapon_item_type , int bullet_image_type , int ForceMouseUse , int FreezeSeconds , float PoisonDuration , float PoisonDamagePerSec , float ParalysationDuration , int HitPercentage , moderately_finepoint target_location ) ;
+EXTERN void FillInDefaultBulletStruct ( int player_num, bullet * CurBullet, int bullet_image_type, int weapon_item_type );
+EXTERN void FireTuxRangedWeaponRaw ( int player_num , int weapon_item_type , int bullet_image_type , bullet *, moderately_finepoint target_location ) ;
 EXTERN void move_tux ( int player_num ) ;
 EXTERN void animate_tux ( int player_num ) ;
 EXTERN void check_tux_enemy_collision (void);
 EXTERN void start_tux_death_explosions (void);
-#define translate_map_point_to_screen_pixel_x(X,Y)  ( UserCenter_x + rintf(( X + Me [ 0 ] . pos . y - Me [ 0 ] . pos . x - Y ) * (iso_floor_tile_width_over_two) ) )
-#define translate_map_point_to_screen_pixel_y(X,Y)  ( UserCenter_y + rintf(( X + Y - Me [ 0 ] . pos . x - Me [ 0 ] . pos . y ) * (iso_floor_tile_height_over_two))) 
+#define translate_map_point_to_screen_pixel translate_map_point_to_screen_pixel_macro
+#define translate_map_point_to_screen_pixel_macro(X,Y,x_res,y_res,zoom_factor) {\
+  if((x_res)!=NULL)\
+    (*(x_res)) = rintf ((UserCenter_x) + \
+      ( (X) + Me[0].pos.y - Me[0].pos.x - (Y) ) * iso_floor_tile_width*0.5*(zoom_factor)) ;\
+  if((y_res)!=NULL)\
+    (*(y_res)) = rintf ((UserCenter_y) + \
+      ( (X) + (Y) - Me[0].pos.x - Me[0].pos.y ) * iso_floor_tile_height*0.5*(zoom_factor)) ;\
+}
+#define translate_map_point_to_screen_pixel_x(X,Y)  ( UserCenter_x + rintf(( (X) + Me [ 0 ] . pos . y - Me [ 0 ] . pos . x - (Y) ) * (iso_floor_tile_width_over_two) ) )
+#define translate_map_point_to_screen_pixel_y(X,Y)  ( UserCenter_y + rintf(( (X) + (Y) - Me [ 0 ] . pos . x - Me [ 0 ] . pos . y ) * (iso_floor_tile_height_over_two))) 
+EXTERN void translate_map_point_to_screen_pixel_func( float x_map_pos, float y_map_pos, int * x_res, int * y_res, float zoom_factor);
 EXTERN int translate_map_point_to_screen_pixel_deviation_tracking ( float x_map_pos , float y_map_pos , int give_x );
-EXTERN int translate_map_point_to_zoomed_screen_pixel ( float x_map_pos , float y_map_pos , int give_x );
+//EXTERN void translate_map_point_to_zoomed_screen_pixel ( float x_map_pos , float y_map_pos , int* x_res, int* y_res);
 EXTERN inline float translate_pixel_to_map_location ( int player_num , float axis_x , float axis_y , int give_x ) ;
+EXTERN void skew_and_blit_rect( float x1, float y1, float x2, float y2, Uint32 color);
 EXTERN float translate_pixel_to_zoomed_map_location ( int player_num , float axis_x , float axis_y , int give_x );
 EXTERN void blit_zoomed_iso_image_to_map_position ( iso_image* our_iso_image , float pos_x , float pos_y );
 EXTERN int tux_can_walk_this_line ( int player_num , float x1, float y1 , float x2 , float y2 );
@@ -145,7 +155,6 @@ EXTERN void PutItem ( int ItemNumber , int mask , int put_thrown_items_flag , in
 EXTERN void PutBlast (int);
 EXTERN void PutEnemy (int Enum, int x , int y , int mask , int highlight );
 EXTERN void PutMouseMoveCursor ( void ) ;
-EXTERN void ShowRobotPicture (int PosX, int PosY, int Number);
 EXTERN void ShowInventoryScreen ( void );
 EXTERN void clear_all_loaded_tux_images ( int with_free );
 EXTERN int set_rotation_index_for_this_robot ( enemy* ThisRobot );
@@ -203,23 +212,22 @@ EXTERN void clear_screen (void) ;
 EXTERN void blit_open_gl_light_radius ( void );
 EXTERN void blit_open_gl_stretched_texture_light_radius ( void ) ;
 EXTERN void PutPixel_open_gl ( int x, int y, Uint32 pixel);
-EXTERN void blit_rotated_open_gl_texture_with_center ( iso_image our_floor_iso_image , int x , int y , float angle_in_degree ) ;
+EXTERN void blit_rotated_open_gl_texture_with_center ( iso_image * our_floor_iso_image , int x , int y , float angle_in_degree ) ;
 EXTERN void remove_open_gl_blending_mode_again ( void );
 EXTERN void prepare_open_gl_for_blending_textures( void );
 EXTERN void GL_HighlightRectangle ( SDL_Surface* Surface , SDL_Rect Area , unsigned char r , unsigned char g , unsigned char b , unsigned char alpha );
 EXTERN void ShowInventoryScreenBackground ( void );
 EXTERN void show_character_screen_background ( void );
 EXTERN int safely_initialize_our_default_open_gl_parameters ( void ) ;
-EXTERN void blit_open_gl_texture_to_map_position ( iso_image our_floor_iso_image , float our_col , float our_line , double r , double g , double b , int highlight_texture, int blend ) ;
-EXTERN void blit_zoomed_open_gl_texture_to_map_position ( iso_image our_floor_iso_image , float our_col , float our_line , float r , float g , float b , int highlight_texture, int blend ) ;
-EXTERN void blit_open_gl_texture_to_screen_position ( iso_image our_floor_iso_image , int x , int y , int set_gl_parameters ) ;
-EXTERN void blit_semitransparent_open_gl_texture_to_screen_position ( iso_image our_floor_iso_image , int x , int y , float scale_factor ) ;
-EXTERN void blit_zoomed_open_gl_texture_to_screen_position ( iso_image* our_floor_iso_image , int x , int y , int set_gl_parameters , float zoom_factor ) ;
+EXTERN void blit_open_gl_texture_to_map_position ( iso_image * our_floor_iso_image , float our_col , float our_line , float r , float g , float b , int highlight_texture, int blend ) ;
+EXTERN void blit_zoomed_open_gl_texture_to_map_position ( iso_image * our_floor_iso_image , float our_col , float our_line , float r , float g , float b , int highlight_texture, int blend ) ;
+EXTERN void blit_open_gl_texture_to_screen_position ( iso_image * our_floor_iso_image , int x , int y , int set_gl_parameters ) ;
+EXTERN void blit_semitransparent_open_gl_texture_to_screen_position ( iso_image * our_floor_iso_image , int x , int y , float scale_factor ) ;
+EXTERN void blit_zoomed_open_gl_texture_to_screen_position ( iso_image * our_floor_iso_image , int x , int y , int set_gl_parameters , float zoom_factor ) ;
 EXTERN void blit_special_background ( int background_code );
 EXTERN void flush_background_image_cache ( void );
 EXTERN void open_gl_check_error_status ( const char* name_of_calling_function );
-EXTERN void blit_open_gl_texture_to_full_screen ( iso_image our_floor_iso_image , int x , int y , int set_gl_parameters ) ;
-
+EXTERN void blit_open_gl_texture_to_full_screen ( iso_image * our_floor_iso_image , int x , int y , int set_gl_parameters ) ;
 
 // blocks.c 
 #undef EXTERN
@@ -249,13 +257,13 @@ EXTERN void Load_Bullet_Surfaces (void);
 EXTERN void Load_Blast_Surfaces (void);
 EXTERN void load_all_isometric_floor_tiles ( void );
 EXTERN void load_all_obstacles ( void );
-EXTERN void blit_iso_image_to_map_position ( iso_image our_iso_image , float pos_x , float pos_y );
+EXTERN void blit_iso_image_to_map_position ( iso_image * our_iso_image , float pos_x , float pos_y );
 EXTERN void blit_iso_image_to_map_position_in_buffer ( SDL_Surface *current_buffer , 
-						       iso_image our_iso_image , float pos_x , float pos_y );
-EXTERN int iso_image_positioned_inside_copy_rectangle ( iso_image our_iso_image , float pos_x , float pos_y , 
+						       iso_image * our_iso_image , float pos_x , float pos_y );
+EXTERN int iso_image_positioned_inside_copy_rectangle ( iso_image * our_iso_image , float pos_x , float pos_y , 
 							float shift_x , float shift_y );
-EXTERN void blit_iso_image_to_screen_position ( iso_image our_iso_image , float pos_x , float pos_y );
-EXTERN void blit_outline_of_iso_image_to_map_position ( iso_image our_iso_image , float pos_x , float pos_y );
+EXTERN void blit_iso_image_to_screen_position ( iso_image * our_iso_image , float pos_x , float pos_y );
+EXTERN void blit_outline_of_iso_image_to_map_position ( iso_image * our_iso_image , float pos_x , float pos_y );
 
 // graphics.c 
 #undef EXTERN
@@ -281,6 +289,8 @@ EXTERN void SetCombatScaleTo(float);
 EXTERN void InitPictures (void);
 EXTERN void InitTimer (void);
 EXTERN void InitVideo (void);
+EXTERN void InitOurBFonts (void);
+EXTERN void FreeOurBFonts (void);
 EXTERN void ClearGraphMem ( void );
 EXTERN void SDL_HighlightRectangle ( SDL_Surface* Surface , SDL_Rect Area );
 EXTERN void HighlightRectangle ( SDL_Surface* Surface , SDL_Rect Area );
@@ -340,7 +350,7 @@ EXTERN void ActSpecialField ( int player_num ) ;
 
 EXTERN void CountNumberOfDroidsOnShip ( void );
 EXTERN int LoadShip (char *filename);
-EXTERN int SaveShip(char *filename);
+EXTERN int SaveShip(const char *filename);
 EXTERN void GetAllAnimatedMapTiles (Level Lev);
 EXTERN int GetCrew (char *shipname);
 
@@ -414,13 +424,12 @@ EXTERN void play_sample_using_WAV_cache_v( char* SoundSampleFileName , int With_
 #else
 #define EXTERN extern
 #endif
-EXTERN void handle_player_identification_command ( int player_num );
+EXTERN void handle_player_identification_command ( );
 EXTERN void MoveItem( item* SourceItem , item* DestItem );
 EXTERN void silently_unhold_all_items ( void );
-EXTERN int required_spellcasting_skill_for_item ( int item_type );
 EXTERN int required_magic_stat_for_next_level_and_item ( int item_type );
 EXTERN int CountItemtypeInInventory( int Itemtype , int player_num );
-EXTERN void DeleteAllInventoryItemsOfType( int Itemtype , int player_num );
+EXTERN void DeleteInventoryItemsOfType( int Itemtype , int amount, int player_num );
 EXTERN void DeleteOneInventoryItemsOfType( int Itemtype , int player_num );
 EXTERN void DamageItem( item* CurItem );
 EXTERN int GetFreeInventoryIndex( void );
@@ -428,7 +437,7 @@ EXTERN int ItemCanBeDroppedInInv ( int ItemType , int InvPos_x , int InvPos_y );
 EXTERN long calculate_item_buy_price ( item* BuyItem );
 EXTERN long calculate_item_repair_price ( item* repair_item );
 EXTERN long calculate_item_sell_price ( item* BuyItem );
-EXTERN void FillInItemProperties( item* ThisItem , int FullDuration , int TreasureChestRange );
+EXTERN void FillInItemProperties( item* ThisItem , int FullDuration , int TreasureChestRange , int multiplicity);
 EXTERN void DamageAllEquipment( int player_num ) ;
 EXTERN void DropChestItemAt( int ItemType , float x , float y , int prefix , int suffix , int TreasureChestRange );
 EXTERN void DropItemAt( int ItemType , int level_num , float x , float y , int prefix , int suffix , int TreasureChestRange , int multiplicity );
@@ -452,7 +461,7 @@ EXTERN int DropHeldItemToTheFloor ( void );
 EXTERN void DropItemToTheFloor ( Item DropItemPointer , float x , float y , int levelnum ) ;
 EXTERN void ShowQuickInventory ( void );
 EXTERN void HandleInventoryScreen ( void );
-EXTERN void AddFloorItemDirectlyToInventory( item* ItemPointer );
+EXTERN int AddFloorItemDirectlyToInventory( item* ItemPointer );
 EXTERN void CopyItem( item* SourceItem , item* DestItem , int MakeSound );
 EXTERN void DeleteItem( item* Item );
 EXTERN void DropRandomItem( int level_num , float x , float y , int TreasureChestRange , int ForceMagical , int ForceDrop , int ChestItem );
@@ -496,12 +505,14 @@ EXTERN void give_new_name_to_obstacle ( Level EditLevel , obstacle* our_obstacle
 EXTERN void RadialVMXWave ( gps ExpCenter , int SpellCostsMana );
 EXTERN void RadialEMPWave ( gps ExpCenter , int SpellCostsMana );
 EXTERN void RadialFireWave ( gps ExpCenter , int SpellCostsMana );
-EXTERN void ClearDetectedItemList( int player_num );
 EXTERN void ShowSkillsScreen ( void );
-EXTERN void HandleCurrentlyActivatedSkill( int player_num );
+EXTERN void HandleCurrentlyActivatedSkill();
+EXTERN int DoSkill( int skill_index, int SpellCost);
 EXTERN void activate_nth_aquired_skill ( int skill_num );
 EXTERN void ImproveSkill(int *skill);
-
+EXTERN int calculate_program_heat_cost(int program_id);
+EXTERN int calculate_program_hit_damage(int program_id);
+EXTERN int get_program_index_with_name(const char *);
 // input.c 
 #undef EXTERN
 #ifdef _input_c
@@ -509,14 +520,17 @@ EXTERN void ImproveSkill(int *skill);
 #else
 #define EXTERN extern
 #endif
+EXTERN Uint8 * key_pressed_real_frame;
+EXTERN Uint8 * key_pressed_last_frame;
+EXTERN Uint8 mouse_state_last_frame;
+EXTERN int keyboard_update();
+EXTERN void track_last_frame_input_status();
+EXTERN void init_keyboard_input_array();
+
 EXTERN int MouseWheelUpPressed(void);
 EXTERN int MouseWheelDownPressed(void);
-EXTERN int MouseRightPressed(void);
-EXTERN int MouseLeftPressed(void);
 EXTERN int GetMousePos_x(void);
 EXTERN int GetMousePos_y(void);
-EXTERN void Init_Joy(void);
-EXTERN void ReactToSpecialKeys(void);
 EXTERN int Shift_Was_Pressed(void);
 EXTERN int LeftShiftWasPressed(void);
 EXTERN int RightShiftWasPressed(void);
@@ -526,46 +540,108 @@ EXTERN int LeftCtrlWasPressed(void);
 EXTERN int Alt_Was_Pressed(void);
 EXTERN int LeftAltWasPressed(void);
 EXTERN int RightAltWasPressed(void);
+EXTERN void Init_Joy(void);
+EXTERN void ReactToSpecialKeys(void);
 EXTERN void Init_SDL_Keyboard(void);
 EXTERN int getchar_raw (void);
-EXTERN int keyboard_update(void);
 EXTERN void ClearKbState (void);
-EXTERN int LeftPressed (void);
-EXTERN int RightPressed (void);
-EXTERN int UpPressed (void);
-EXTERN int DownPressed (void);
-EXTERN int SpacePressed (void);
-EXTERN int EnterPressed (void);
-EXTERN int EscapePressed (void);
-EXTERN int TabPressed (void);
-EXTERN int Shift_Is_Pressed(void);
-EXTERN int BackspacePressed (void);
-EXTERN int LeftCtrlPressed (void);
-EXTERN int KP_PLUS_Pressed (void);
-EXTERN int KP_MINUS_Pressed (void);
-EXTERN int KP_MULTIPLY_Pressed (void);
-EXTERN int KP_DIVIDE_Pressed (void);
-EXTERN int Number0Pressed (void); EXTERN int Number1Pressed (void); EXTERN int Number2Pressed (void);
-EXTERN int Number3Pressed (void); EXTERN int Number4Pressed (void); EXTERN int Number5Pressed (void);
-EXTERN int Number6Pressed (void); EXTERN int Number7Pressed (void); EXTERN int Number8Pressed (void);
-EXTERN int Number9Pressed (void); EXTERN int KP0Pressed (void); EXTERN int KP1Pressed (void);
-EXTERN int KP2Pressed (void); EXTERN int KP3Pressed (void); EXTERN int KP4Pressed (void);
-EXTERN int KP5Pressed (void); EXTERN int KP6Pressed (void); EXTERN int KP7Pressed (void);
-EXTERN int KP8Pressed (void); EXTERN int KP9Pressed (void); EXTERN int F1Pressed (void); 
-EXTERN int F2Pressed (void); EXTERN int F3Pressed (void); EXTERN int F4Pressed (void);
-EXTERN int F5Pressed (void); EXTERN int F6Pressed (void); EXTERN int F7Pressed (void);
-EXTERN int F8Pressed (void); EXTERN int F9Pressed (void); EXTERN int F10Pressed (void);
-EXTERN int F11Pressed (void); EXTERN int F12Pressed (void); EXTERN int APressed (void);
-EXTERN int BPressed (void); EXTERN int CPressed (void); EXTERN int DPressed (void);
-EXTERN int EPressed (void); EXTERN int FPressed (void); EXTERN int GPressed (void);
-EXTERN int HPressed (void); EXTERN int IPressed (void); EXTERN int JPressed (void);
-EXTERN int KPressed (void); EXTERN int LPressed (void); EXTERN int MPressed (void);
-EXTERN int NPressed (void); EXTERN int OPressed (void); EXTERN int PPressed (void);
-EXTERN int QPressed (void); EXTERN int RPressed (void); EXTERN int SPressed (void);
-EXTERN int TPressed (void); EXTERN int UPressed (void); EXTERN int VPressed (void);
-EXTERN int WPressed (void); EXTERN int XPressed (void); EXTERN int YPressed (void);
-EXTERN int ZPressed (void);
-EXTERN int NoDirectionPressed (void);
+EXTERN int MouseRightPressed(); 
+EXTERN int MouseLeftPressed();
+EXTERN int MouseLeftClicked();
+EXTERN int MouseRightClicked();
+EXTERN int LeftPressed () ;
+EXTERN int RightPressed () ;
+EXTERN int LeftWasPressed () ;
+EXTERN int RightWasPressed () ;
+EXTERN int UpPressed () ;
+EXTERN int DownPressed () ;
+EXTERN int SpacePressed () ;
+EXTERN int EnterPressed () ;
+EXTERN int EscapePressed () ;
+EXTERN int TabPressed () ;
+EXTERN int BackspacePressed () ;
+EXTERN int LeftCtrlPressed () ;
+EXTERN int CtrlWasPressed () ;
+EXTERN int CtrlPressed () ;
+EXTERN int ShiftPressed () ;
+EXTERN int ShiftWasPressed () ;
+EXTERN int AltWasPressed () ;
+EXTERN int AltPressed () ;
+EXTERN int KP_PLUS_Pressed () ;
+EXTERN int KP_MINUS_Pressed () ;
+EXTERN int KP_MULTIPLY_Pressed () ;
+EXTERN int KP_DIVIDE_Pressed () ;
+EXTERN int Number0Pressed () ;
+EXTERN int Number0Hit () ;
+EXTERN int Number1Pressed () ;
+EXTERN int Number1Hit () ;
+EXTERN int Number2Pressed () ;
+EXTERN int Number2Hit () ;
+EXTERN int Number3Pressed () ;
+EXTERN int Number3Hit () ;
+EXTERN int Number4Pressed () ;
+EXTERN int Number4Hit () ;
+EXTERN int Number5Pressed () ;
+EXTERN int Number5Hit () ;
+EXTERN int Number6Pressed () ;
+EXTERN int Number6Hit () ;
+EXTERN int Number7Pressed () ;
+EXTERN int Number7Hit () ;
+EXTERN int Number8Pressed () ;
+EXTERN int Number8Hit () ;
+EXTERN int Number9Pressed () ;
+EXTERN int Number9Hit () ;
+EXTERN int KP0Pressed () ;
+EXTERN int KP1Pressed () ;
+EXTERN int KP2Pressed () ;
+EXTERN int KP3Pressed () ;
+EXTERN int KP4Pressed () ;
+EXTERN int KP5Pressed () ;
+EXTERN int KP6Pressed () ;
+EXTERN int KP7Pressed () ;
+EXTERN int KP8Pressed () ;
+EXTERN int KP9Pressed () ;
+EXTERN int F1Pressed () ;
+EXTERN int F2Pressed () ;
+EXTERN int F3Pressed () ;
+EXTERN int F4Pressed () ;
+EXTERN int F5Pressed () ;
+EXTERN int F6Pressed () ;
+EXTERN int F7Pressed () ;
+EXTERN int F8Pressed () ;
+EXTERN int F9Pressed () ;
+EXTERN int F10Pressed () ;
+EXTERN int F11Pressed () ;
+EXTERN int F12Pressed () ;
+EXTERN int APressed () ;
+EXTERN int BPressed () ;
+EXTERN int CPressed () ;
+EXTERN int DPressed () ;
+EXTERN int EPressed () ;
+EXTERN int FPressed () ;
+EXTERN int GPressed () ;
+EXTERN int HPressed () ;
+EXTERN int IPressed () ;
+EXTERN int JPressed () ;
+EXTERN int KPressed () ;
+EXTERN int LPressed () ;
+EXTERN int LHit () ;
+EXTERN int MPressed () ;
+EXTERN int NPressed () ;
+EXTERN int OPressed () ;
+EXTERN int PPressed () ;
+EXTERN int QPressed () ;
+EXTERN int RPressed () ;
+EXTERN int SPressed () ;
+EXTERN int TPressed () ;
+EXTERN int THit () ;
+EXTERN int UPressed () ;
+EXTERN int VPressed () ;
+EXTERN int WPressed () ;
+EXTERN int XPressed () ;
+EXTERN int YPressed () ;
+EXTERN int ZWasPressed () ;
+EXTERN int ZHit () ;
 EXTERN void toggle_game_config_screen_visibility ( int screen_visible );
 
 // menu.c 
@@ -583,7 +659,7 @@ EXTERN int DoMenuSelection( char* InitialText , char* MenuTexts[10] , int FirstI
 EXTERN int ChatDoMenuSelectionFlagged( char* InitialText , char* MenuTexts[ MAX_ANSWERS_PER_PERSON] , 
 				       unsigned char Chat_Flags[ MAX_ANSWERS_PER_PERSON ] , int FirstItem , 
 				       int background_code , void* MenuFont , enemy* ChatDroid );
-EXTERN int ChatDoMenuSelection( char* InitialText , char* MenuTexts[10] , int FirstItem , int background_code , void* MenuFont , enemy* ChatDroid );
+EXTERN int ChatDoMenuSelection( char* MenuTexts[10] , int FirstItem , void* MenuFont , enemy* ChatDroid );
 EXTERN void StartupMenu (void);
 EXTERN void BuySellMenu ( void );
 EXTERN void InitiateMenu( int background_code );
@@ -614,9 +690,7 @@ EXTERN void ReadValueFromStringWithDefault( char* SearchBeginPointer , const cha
 EXTERN void ReadValueFromString( char* SearchBeginPointer , const char* ValuePreceedText , const char* FormatString , void* TargetValue , char* EndOfSearchSectionPointer );
 EXTERN char* ReadAndMallocAndTerminateFile( char* filename , const char* File_End_String ) ;
 EXTERN char* LocateStringInData ( char* SearchBeginPointer, const char* SearchTextPointer ) ;
-EXTERN char * find_file (char *fname, char *datadir, int use_theme);
-EXTERN char * find_file_silent (char *fname, char *datadir, int use_theme);
-EXTERN char * find_file_for_callbacks (char *fname, char *datadir, int use_theme);
+EXTERN int find_file (char *fname, char *datadir, char * File_Path, int silent);
 EXTERN void CheckForTriggeredEventsAndStatements ( int player_num );
 EXTERN void Pause (void);
 EXTERN void ComputeFPSForThisFrame(void);
@@ -627,7 +701,7 @@ EXTERN void Activate_Conservative_Frame_Computation(void);
 EXTERN void gotoxy (int, int);
 EXTERN int MyRandom (int);
 EXTERN void Armageddon (void);
-EXTERN void Teleport ( int LNum , float X , float Y , int player_num , int Shuffling , int WithSound ) ;
+EXTERN void Teleport ( int LNum , float X , float Y , int player_num , int WithSound ) ;
 EXTERN int SaveGameConfig (void);
 EXTERN int LoadGameConfig (void);
 EXTERN void InsertNewMessage (void);
@@ -672,7 +746,7 @@ EXTERN void occasionally_update_first_and_last_bot_indices ( void );
 #define EXTERN extern
 #endif
 EXTERN int GreatItemShow ( int NumberOfItems , item* ShowPointerList[ MAX_ITEMS_IN_INVENTORY ] );
-EXTERN void ShowDeckMap (Level deck);
+EXTERN void ShowDeckMap ();
 EXTERN void ShowItemInfo ( item* ShowItem , int page , char ShowArrows , int background_code , int title_text_flag );
 EXTERN void EnterLift (void);
 EXTERN void EnterItemIdentificationBooth( void );
@@ -680,7 +754,6 @@ EXTERN void EnterCodepanel (void);
 EXTERN void EnterConsole (void);
 EXTERN void AlleLevelsGleichFaerben (void);
 EXTERN void ClearUserFenster (void);
-void GreatDruidShow (void);
 void ShowDroidInfo (int droidtype, int page , char ShowArrows );
 void PaintConsoleMenu (int menu_pos);
 EXTERN void write_full_item_name_into_string ( item* ShowItem , char* full_item_name ) ;
@@ -714,7 +787,7 @@ EXTERN int DisplayText ( const char *text, int startx, int starty, const SDL_Rec
 EXTERN void display_current_chat_protocol ( int background_picture_code , enemy* ChatDroid , int with_update );
 
 EXTERN void DisplayChar (unsigned char c);
-EXTERN int ScrollText (char *text, int startx, int starty, int EndLine , int background_code );
+EXTERN int ScrollText (char *text, int startx, int starty, int background_code );
 
 EXTERN int ImprovedCheckLineBreak(unsigned char *text, const SDL_Rect *clip , float text_stretch );
 EXTERN char *PreviousLine (char *textstart, char *text);
@@ -831,7 +904,6 @@ EXTERN void AnimateCurrents (void);
 EXTERN void ClearPlayground (void);
 EXTERN int IsActive (int color, int row);
 
-
 // BFont.c
 #undef EXTERN
 #ifdef _bfont_c
