@@ -292,7 +292,7 @@ SaveGame( void )
     //
     if ( Me[0].energy <= 0 )
     {
-	DoMenuSelection( "\n\n    Surely you do not really want do save a game \n\n    where your tux is dead, do you?" , 
+	DoMenuSelection( _("\n\n    Surely you do not really want do save a game \n\n    where your tux is dead, do you?"), 
 			 MenuTexts , 1 , -1 , NULL );
 	return ( OK );
     }
@@ -321,7 +321,7 @@ SaveGame( void )
 	      (int) MAX_ENEMYS_ON_SHIP );
     
     //--------------------
-    sprintf( filename , "%s/%s%s", our_config_dir, Me[0].character_name, SHIP_EXT );
+    sprintf( filename , "%s/%s%s", our_config_dir, Me[0].character_name, ".shp" );
 
     if ( SaveShip( filename ) != OK )
     {
@@ -456,7 +456,7 @@ freedroid-discussion@lists.sourceforge.net\n\
     
     ShowSaveLoadGameProgressMeter( 100 , TRUE ) ;
     
-    append_new_game_message ( "Game saved." );
+    append_new_game_message ( _("Game saved.") );
 
     DebugPrintf ( SAVE_LOAD_GAME_DEBUG , "\nint SaveGame( void ): end of function reached.");
     
@@ -479,7 +479,7 @@ DeleteGame( void )
     //--------------------
     // First we save the full ship information, same as with the level editor
     //
-    sprintf( filename , "%s/%s%s", our_config_dir , Me[0].character_name, SHIP_EXT);
+    sprintf( filename , "%s/%s%s", our_config_dir , Me[0].character_name, ".shp");
     
     remove ( filename ) ;
     
@@ -505,7 +505,7 @@ int
 LoadGame( void )
 {
     char version_check_string[1000];
-    unsigned char *LoadGameData;
+    char *LoadGameData;
     char filename[1000];
     unsigned char* InfluencerRawDataPointer;
     unsigned char* EnemyRawDataPointer;
@@ -535,7 +535,7 @@ LoadGame( void )
     //--------------------
     // First we load the full ship information, same as with the level editor
     
-    sprintf( filename , "%s/%s%s", our_config_dir, Me [ 0 ] . character_name, SHIP_EXT);
+    sprintf( filename , "%s/%s%s", our_config_dir, Me [ 0 ] . character_name, ".shp");
     
     //--------------------
     // Maybe there isn't any saved game by that name.  This case must be checked for
@@ -544,7 +544,7 @@ LoadGame( void )
     if ((DataFile = fopen ( filename , "rb")) == NULL )
     {
 	GiveMouseAlertWindow ( "\nW A R N I N G !\n\nFreedroidRPG was unable to locate the saved game file you requested to load.\nThis might mean that it really isn't there cause you tried to load a game without ever having saved the game before.  \nThe other explanation of this error might be a severe error in FreedroidRPG.\nNothing will be done about it." );
-	append_new_game_message ( "Failed to load old game." );
+	append_new_game_message ( _("Failed to load old game.") );
 	return ( ERR ) ;
     }
     else
@@ -650,11 +650,11 @@ LoadGame( void )
     
     if ( strcmp ( Me [ 0 ] . freedroid_version_string , version_check_string ) != 0 )
     {
-	show_button_tooltip ( "Error: Version or structsize mismatch! The saved game in question appears to be from a (slightly?) different version of FreedroidRPG.\nSorry, but I refuse to load it for safety/stability reasons...\nFor Recovery, a blank game will be loaded...(please disregard)\n" );
+	show_button_tooltip ( _("Error: Version or structsize mismatch! The saved game in question appears to be from a (slightly?) different version of FreedroidRPG.\nSorry, but I refuse to load it for safety/stability reasons...\nFor Recovery, a blank game will be loaded...(please disregard)\n") );
 	our_SDL_flip_wrapper( Screen );
-	while ( SpacePressed() ) SDL_Delay ( 3 );
-	while ( !SpacePressed() ) SDL_Delay ( 3 );
-	while ( SpacePressed() ) SDL_Delay ( 3 );
+	while ( SpacePressed() || MouseLeftPressed() ) SDL_Delay ( 3 );
+	while ( !SpacePressed() && ! MouseLeftPressed() ) SDL_Delay ( 3 );
+	while ( SpacePressed() || MouseLeftPressed()) SDL_Delay ( 3 );
 
 	//--------------------
 	// Now at this point the current Tux data has been junked
@@ -671,7 +671,9 @@ LoadGame( void )
 	{
 	    clear_player_inventory_and_stats ( ) ;
 	    UpdateAllCharacterStats ( 0 ) ;
-	    LoadShip ( find_file ( "Asteroid.maps" , MAP_DIR, FALSE) ) ;
+	    char fp[2048];
+	    find_file ( "Asteroid.maps", MAP_DIR, fp, 0 );
+	    LoadShip ( fp ) ;
 	    PrepareStartOfNewCharacter (  ) ;
 	}
 	return ( ERR ) ;
@@ -708,7 +710,7 @@ LoadGame( void )
     // take a little time.  Therefore we print some message so the user will not
     // panic and push the reset button :)
     //
-    PutStringFont ( Screen , FPS_Display_BFont , 75 , 150 , "Updating Tux images (this may take a little while...)" );
+    PutStringFont ( Screen , FPS_Display_BFont , 75 , 150 , _("Updating Tux images (this may take a little while...)") );
     our_SDL_flip_wrapper ( Screen );
     
     //--------------------
@@ -720,7 +722,7 @@ LoadGame( void )
 
     load_game_command_came_from_inside_running_game = TRUE ;
 
-    append_new_game_message ( "Game loaded." );
+    append_new_game_message ( _("Game loaded.") );
 
     return OK;
 }; // int LoadGame ( void ) 
