@@ -198,35 +198,32 @@ AssembleItemListForTradeCharacter ( item* ListToBeFilled , int ShopCharacterCode
     ListPointer = ListToBeFilled;
     if ( ShopCharacterCode == PERSON_STONE )
     {
-	ListPointer->type = ITEM_SMALL_HEALTH_POTION; ListPointer++;
-	ListPointer->type = ITEM_MEDIUM_HEALTH_POTION; ListPointer++;
-	ListPointer->type = ITEM_FULL_HEALTH_POTION; ListPointer++;
-	ListPointer->type = ITEM_BUCKLER; ListPointer++;
-	ListPointer->type = ITEM_ARMOR_SIMPLE_JACKET; ListPointer++;
 	ListPointer->type = ITEM_DAGGER; ListPointer++;
-	ListPointer->type = ITEM_CLUB; ListPointer++;
 	ListPointer->type = ITEM_SHORT_SWORD; ListPointer++;
 	ListPointer->type = ITEM_SCIMITAR; ListPointer++;
-	ListPointer->type = ITEM_STAFF; ListPointer++;
+	ListPointer->type = ITEM_CLUB; ListPointer++;
 	ListPointer->type = ITEM_MACE; ListPointer++;
+	ListPointer->type = ITEM_STAFF; ListPointer++;
 	ListPointer->type = ITEM_CAP; ListPointer++;
+	ListPointer->type = ITEM_BUCKLER; ListPointer++;
+	ListPointer->type = ITEM_ARMOR_SIMPLE_JACKET; ListPointer++;
+	
     }
     else if ( ShopCharacterCode == PERSON_DOC_MOORE )
     {
 	ListPointer->type = ITEM_SMALL_HEALTH_POTION; ListPointer++;
-	ListPointer->type = ITEM_SMALL_MANA_POTION; ListPointer++;
 	ListPointer->type = ITEM_MEDIUM_HEALTH_POTION; ListPointer++;
-	ListPointer->type = ITEM_MEDIUM_MANA_POTION; ListPointer++;
+	ListPointer->type = ITEM_FULL_HEALTH_POTION; ListPointer++;
+
     }
     else if ( ShopCharacterCode == PERSON_LUKAS )
     {
-	ListPointer->type = ITEM_RED_GUARD_LIGHT_ARMOUR; ListPointer++;
-	ListPointer->type = ITEM_RED_GUARD_HEAVY_ARMOUR; ListPointer++;
 	ListPointer->type = ITEM_LASER_PISTOL; ListPointer++;
 	ListPointer->type = ITEM_PLASMA_PISTOL; ListPointer++;
 	ListPointer->type = ITEM_LASER_AMMUNITION; ListPointer++;
 	ListPointer->type = ITEM_PLASMA_AMMUNITION; ListPointer++;
-
+	ListPointer->type = ITEM_RED_GUARD_LIGHT_ARMOUR; ListPointer++;
+	ListPointer->type = ITEM_RED_GUARD_HEAVY_ARMOUR; ListPointer++;
     }
     else if ( ShopCharacterCode == PERSON_SKIPPY )
     {
@@ -240,15 +237,11 @@ AssembleItemListForTradeCharacter ( item* ListToBeFilled , int ShopCharacterCode
     }
     else if ( ShopCharacterCode == PERSON_EWALD )
     {
-	ListPointer->type = ITEM_BLUE_ENERGY_DRINK; ListPointer++;
-	ListPointer->type = ITEM_SMALL_HEALTH_POTION; ListPointer++;
 	ListPointer->type = ITEM_SMALL_MANA_POTION; ListPointer++;
-	ListPointer->type = ITEM_MEDIUM_HEALTH_POTION; ListPointer++;
 	ListPointer->type = ITEM_MEDIUM_MANA_POTION; ListPointer++;
-	ListPointer->type = ITEM_FULL_HEALTH_POTION; ListPointer++;
 	ListPointer->type = ITEM_FULL_MANA_POTION; ListPointer++;
+	ListPointer->type = ITEM_BLUE_ENERGY_DRINK; ListPointer++;
 	ListPointer->type = ITEM_RUNNING_POWER_POTION; ListPointer++;
-
 	ListPointer->type = ITEM_TEMP_STRENGTH_POTION; ListPointer++;
 	ListPointer->type = ITEM_TEMP_DEXTERITY_POTION; ListPointer++;
 
@@ -260,23 +253,26 @@ AssembleItemListForTradeCharacter ( item* ListToBeFilled , int ShopCharacterCode
     }
     else if ( ShopCharacterCode == PERSON_SORENSON )
     {
-	ListPointer->type = ITEM_SCRIPT_OF_IDENTIFY; ListPointer++;
-	ListPointer->type = ITEM_SCRIPT_OF_TELEPORT_HOME; ListPointer++;
-
-	ListPointer->type = ITEM_SPELLBOOK_OF_HEALING; ListPointer++;
-	ListPointer->type = ITEM_SPELLBOOK_OF_EXPLOSION_CIRCLE; ListPointer++;
-	ListPointer->type = ITEM_SPELLBOOK_OF_EXPLOSION_RAY; ListPointer++;
-	ListPointer->type = ITEM_SPELLBOOK_OF_TELEPORT_HOME; ListPointer++;
-	
-	ListPointer->type = ITEM_SPELLBOOK_OF_PLASMA_BOLT; ListPointer++;
-	ListPointer->type = ITEM_SPELLBOOK_OF_ICE_BOLT; ListPointer++;
-	ListPointer->type = ITEM_SPELLBOOK_OF_POISON_BOLT; ListPointer++;
-	ListPointer->type = ITEM_SPELLBOOK_OF_PETRIFICATION; ListPointer++;
-	
-	ListPointer->type = ITEM_SPELLBOOK_OF_RADIAL_EMP_WAVE; ListPointer++;
-	ListPointer->type = ITEM_SPELLBOOK_OF_RADIAL_VMX_WAVE; ListPointer++;
-	ListPointer->type = ITEM_SPELLBOOK_OF_RADIAL_PLASMA_WAVE; ListPointer++;
-	ListPointer->type = ITEM_SPELLBOOK_OF_DETECT_ITEMS; ListPointer++;
+	ListPointer->type = ITEM_SPELLBOOK_OF_CHECK_SYSTEM_INTEGRITY; ListPointer++; 
+	ListPointer->type = ITEM_SPELLBOOK_OF_CALCULATE_PI; ListPointer++; 
+	ListPointer->type = ITEM_SPELLBOOK_OF_BLUE_SCREEN; ListPointer++; 
+	ListPointer->type = ITEM_SPELLBOOK_OF_TELEPORT_HOME; ListPointer++; 
+	ListPointer->type = ITEM_SPELLBOOK_OF_MALFORMED_PACKET; ListPointer++; 
+	ListPointer->type = ITEM_SPELLBOOK_OF_ANALYZE_ITEM; ListPointer++; 
+	ListPointer->type = ITEM_SPELLBOOK_OF_NETHACK; ListPointer++; 
+	ListPointer->type = ITEM_SPELLBOOK_OF_DISPELL_SMOKE; ListPointer++; 
+	ListPointer->type = ITEM_SPELLBOOK_OF_KILLER_POKE; ListPointer++; 
+	ListPointer->type = ITEM_SPELLBOOK_OF_BROADCAST_KILLER_POKE; ListPointer++; 
+	ListPointer->type = ITEM_SPELLBOOK_OF_RICER_CFLAGS; ListPointer++; 
+	ListPointer->type = ITEM_SPELLBOOK_OF_PLASMA_DISCHARGE; ListPointer++; 
+	ListPointer->type = ITEM_SPELLBOOK_OF_INVISIBILITY; ListPointer++; 
+	ListPointer->type = ITEM_SPELLBOOK_OF_SANCTUARY; ListPointer++; 
+	ListPointer->type = ITEM_SPELLBOOK_OF_VIRUS; ListPointer++; 
+	ListPointer->type = ITEM_SPELLBOOK_OF_BROADCAST_VIRUS; ListPointer++; 
+	ListPointer->type = ITEM_SPELLBOOK_OF_REVERSE_ENGINEER; ListPointer++; 
+	ListPointer->type = ITEM_SPELLBOOK_OF_EMERGENCY_SHUTDOWN; ListPointer++; 
+	ListPointer->type = ITEM_SPELLBOOK_OF_LIGHT; ListPointer++; 
+	ListPointer->type = ITEM_SPELLBOOK_OF_SATELLITE_IMAGE; ListPointer++; 
     }
     else
     {
@@ -294,7 +290,7 @@ currently and therefore initiates immediate termination now...",
     for ( i = 0 ; i < MAX_ITEMS_IN_INVENTORY ; i ++ )
     {
 	if ( ListPointer->type == (-1) ) break;
-	FillInItemProperties( ListPointer , TRUE , 0 );
+	FillInItemProperties( ListPointer , TRUE , 0 , 1);
 	ListPointer -> is_identified = TRUE;
 	ListPointer++;
     }
@@ -497,11 +493,12 @@ ShowRescaledItem ( int position , int TuxItemRow , item* ShowItem )
     SDL_Rect TargetRectangle = { 0, 0, INITIAL_BLOCK_WIDTH * GameConfig . screen_width / 640,  INITIAL_BLOCK_HEIGHT * GameConfig . screen_height / 480};
     static iso_image equipped_icon ;
     static int first_call = TRUE ;
-    char* fpath;
 
     if ( first_call )
     {
-            fpath = find_file ( "mouse_cursor_0003.png" , GRAPHICS_DIR, FALSE );
+	    char fpath[2048];
+
+            find_file ( "mouse_cursor_0003.png" , GRAPHICS_DIR, fpath, 0 );
             get_iso_image_from_file_and_path ( fpath , & ( equipped_icon ) , FALSE ) ;
             if ( equipped_icon . surface == NULL )
             {
@@ -552,11 +549,11 @@ Error loading flag image.",
 	{
 	if ( use_open_gl )
 	    {
-            blit_open_gl_texture_to_screen_position ( equipped_icon , TargetRectangle . x + TargetRectangle . w - 24, TargetRectangle . y , TRUE );
+            blit_open_gl_texture_to_screen_position ( &equipped_icon , TargetRectangle . x + TargetRectangle . w - 24, TargetRectangle . y , TRUE );
     	    }
         else
             {
-            blit_iso_image_to_screen_position ( equipped_icon , TargetRectangle . x + TargetRectangle . w -  24, TargetRectangle . y );
+            blit_iso_image_to_screen_position ( &equipped_icon , TargetRectangle . x + TargetRectangle . w -  24, TargetRectangle . y );
             }
 	}
 }; // void ShowRescaledItem ( int position , item* ShowItem )
@@ -692,8 +689,9 @@ GreatShopInterface ( int NumberOfItems , item* ShowPointerList[ MAX_ITEMS_IN_INV
 	}
 	else if ( TuxItemIndex >= 0 )
 	{
+	    SellButtonActive = FALSE;
 	    if ( ShowChestButtons ) ShowGenericButtonFromList ( PUT_BUTTON );
-	    else if ( ItemMap [ TuxItemsList [ TuxItemIndex ] -> type ] . base_list_price )
+	    else if ( calculate_item_sell_price( TuxItemsList [ TuxItemIndex ] ))
 			{
 			ShowGenericButtonFromList ( SELL_BUTTON );
 		        SellButtonActive = TRUE; 
@@ -735,24 +733,24 @@ GreatShopInterface ( int NumberOfItems , item* ShowPointerList[ MAX_ITEMS_IN_INV
 	blit_our_own_mouse_cursor ( );
 	our_SDL_flip_wrapper( Screen );
 	
-	if ( SpacePressed() || EscapePressed() || axis_is_active )
+	if ( SpacePressed() || EscapePressed() || MouseLeftPressed() )
 	{
-	    if ( MouseCursorIsOnButton( DESCRIPTION_WINDOW_UP_BUTTON , GetMousePos_x() , GetMousePos_y() ) && axis_is_active && !WasPressed )
+	    if ( MouseCursorIsOnButton( DESCRIPTION_WINDOW_UP_BUTTON , GetMousePos_x() , GetMousePos_y() ) && MouseLeftPressed() && !WasPressed )
 	    {
 		MoveMenuPositionSound();
 		Displacement += FontHeight ( GetCurrentFont () );
 	    }
-	    else if ( MouseCursorIsOnButton( DESCRIPTION_WINDOW_DOWN_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && axis_is_active && !WasPressed )
+	    else if ( MouseCursorIsOnButton( DESCRIPTION_WINDOW_DOWN_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && MouseLeftPressed() && !WasPressed )
 	    {
 		MoveMenuPositionSound();
 		Displacement -= FontHeight ( GetCurrentFont () );
 	    }
-	    else if ( MouseCursorIsOnButton( ITEM_BROWSER_EXIT_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && axis_is_active && !WasPressed )
+	    else if ( MouseCursorIsOnButton( ITEM_BROWSER_EXIT_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && MouseLeftPressed() && !WasPressed )
 	    {
 		finished = TRUE;
-		while (SpacePressed() ||EscapePressed());
+		while (SpacePressed() || EscapePressed() || MouseLeftPressed());
 	    }
-	    else if ( MouseCursorIsOnButton( LEFT_TUX_SHOP_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && axis_is_active && !WasPressed )
+	    else if ( MouseCursorIsOnButton( LEFT_TUX_SHOP_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && MouseLeftPressed() && !WasPressed )
 	    {
 		if ( 0 < RowStart ) 
 		{
@@ -764,9 +762,9 @@ GreatShopInterface ( int NumberOfItems , item* ShowPointerList[ MAX_ITEMS_IN_INV
 		    }
 		}
 		MoveMenuPositionSound();
-		while (SpacePressed() ||EscapePressed());
+		while (SpacePressed() ||EscapePressed() || MouseLeftPressed());
 	    }
-	    else if ( MouseCursorIsOnButton( RIGHT_TUX_SHOP_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && axis_is_active && !WasPressed )
+	    else if ( MouseCursorIsOnButton( RIGHT_TUX_SHOP_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && MouseLeftPressed() && !WasPressed )
 	    {
 		if ( RowStart + RowLength < NumberOfItems ) 
 		{
@@ -778,9 +776,9 @@ GreatShopInterface ( int NumberOfItems , item* ShowPointerList[ MAX_ITEMS_IN_INV
 		    }
 		}
 		MoveMenuPositionSound();
-		while (SpacePressed() ||EscapePressed());
+		while (SpacePressed() ||EscapePressed() || MouseLeftPressed());
 	    }
-	    else if ( MouseCursorIsOnButton( LEFT_SHOP_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && axis_is_active && !WasPressed )
+	    else if ( MouseCursorIsOnButton( LEFT_SHOP_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && MouseLeftPressed() && !WasPressed )
 	    {
 		if ( 0 < TuxRowStart ) 
 		{
@@ -792,9 +790,9 @@ GreatShopInterface ( int NumberOfItems , item* ShowPointerList[ MAX_ITEMS_IN_INV
 		    }
 		}
 		MoveMenuPositionSound();
-		while (SpacePressed() ||EscapePressed());
+		while (SpacePressed() ||EscapePressed() || MouseLeftPressed());
 	    }
-	    else if ( MouseCursorIsOnButton( RIGHT_SHOP_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && axis_is_active && !WasPressed )
+	    else if ( MouseCursorIsOnButton( RIGHT_SHOP_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && MouseLeftPressed() && !WasPressed )
 	    {
 		if ( TuxRowStart + TuxRowLength < NumberOfItemsInTuxRow ) 
 		{
@@ -806,9 +804,9 @@ GreatShopInterface ( int NumberOfItems , item* ShowPointerList[ MAX_ITEMS_IN_INV
 		    }
 		}
 		MoveMenuPositionSound();
-		while (SpacePressed() ||EscapePressed());
+		while (SpacePressed() ||EscapePressed() || MouseLeftPressed());
 	    }
-	    else if ( ( ( ClickTarget = ClickWasOntoItemRowPosition ( GetMousePos_x()  , GetMousePos_y()  , FALSE ) ) >= 0 ) && axis_is_active && !WasPressed )
+	    else if ( ( ( ClickTarget = ClickWasOntoItemRowPosition ( GetMousePos_x()  , GetMousePos_y()  , FALSE ) ) >= 0 ) && MouseLeftPressed() && !WasPressed )
 	    {
 		if ( ClickTarget < NumberOfItems )
 		{
@@ -817,7 +815,7 @@ GreatShopInterface ( int NumberOfItems , item* ShowPointerList[ MAX_ITEMS_IN_INV
 		    Displacement = 0 ;
 		}
 	    }
-	    else if ( ( ( ClickTarget = ClickWasOntoItemRowPosition ( GetMousePos_x()  , GetMousePos_y()  , TRUE ) ) >= 0 ) && axis_is_active && !WasPressed )
+	    else if ( ( ( ClickTarget = ClickWasOntoItemRowPosition ( GetMousePos_x()  , GetMousePos_y()  , TRUE ) ) >= 0 ) && MouseLeftPressed() && !WasPressed )
 	    {
 		if ( ClickTarget < NumberOfItemsInTuxRow )
 		{
@@ -826,7 +824,7 @@ GreatShopInterface ( int NumberOfItems , item* ShowPointerList[ MAX_ITEMS_IN_INV
 		    Displacement = 0 ;
 		}
 	    }
-	    else if ( MouseCursorIsOnButton( BUY_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && axis_is_active && !WasPressed )
+	    else if ( MouseCursorIsOnButton( BUY_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && MouseLeftPressed() && !WasPressed )
 	    {
 		if ( BuyButtonActive )
 		{
@@ -854,11 +852,11 @@ GreatShopInterface ( int NumberOfItems , item* ShowPointerList[ MAX_ITEMS_IN_INV
 			else
 			    ShopOrder -> number_selected = 1;
 		    }
-		    
+		    while ( MouseLeftPressed() ) SDL_Delay(1);
 		    return ( 0 );
 		}
 	    }
-	    else if ( MouseCursorIsOnButton( SELL_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && axis_is_active && !WasPressed )
+	    else if ( MouseCursorIsOnButton( SELL_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && MouseLeftPressed() && !WasPressed )
 	    {
 		if ( SellButtonActive )
 		{
@@ -872,12 +870,12 @@ GreatShopInterface ( int NumberOfItems , item* ShowPointerList[ MAX_ITEMS_IN_INV
 		    }
 		    else
 			ShopOrder -> number_selected = 1;
-		    
+		    while ( MouseLeftPressed() ) SDL_Delay(1);
 		    return ( 0 );
 		}
 	    }
 	    else if ( MouseCursorIsOnButton( REPAIR_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && 
-		      axis_is_active && !WasPressed && ( !ShowChestButtons ) )
+		      MouseLeftPressed() && !WasPressed && ( !ShowChestButtons ) )
 	    {
 		//--------------------
 		// Reference to the Tux item list must only be made, when the 'highlight'
@@ -901,7 +899,7 @@ GreatShopInterface ( int NumberOfItems , item* ShowPointerList[ MAX_ITEMS_IN_INV
 		    }
 		}
 	    }
-	    else if ( MouseCursorIsOnButton( IDENTIFY_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && axis_is_active && !WasPressed && ( !ShowChestButtons ) )
+	    else if ( MouseCursorIsOnButton( IDENTIFY_BUTTON , GetMousePos_x()  , GetMousePos_y()  ) && MouseLeftPressed() && !WasPressed && ( !ShowChestButtons ) )
 	    {
 		//--------------------
 		// Reference to the Tux item list must only be made, when the 'highlight'
@@ -923,7 +921,7 @@ GreatShopInterface ( int NumberOfItems , item* ShowPointerList[ MAX_ITEMS_IN_INV
 	
 	
 	
-	WasPressed = axis_is_active;
+	WasPressed = MouseLeftPressed();
 	
 	if (UpPressed() || MouseWheelUpPressed())
 	{
@@ -1197,7 +1195,7 @@ DoEquippmentListSelection( char* Startstring , item* Item_Pointer_List[ MAX_ITEM
 	// DisplayText( "BACK" , 580 , 50 + (i+1) * ITEM_MENU_DISTANCE , NULL );
 	// CenteredPutStringFont( Screen , Message_BFont , 50 + (i+1) * ITEM_MENU_DISTANCE , " BACK " );
 	//
-	CenteredPutString( Screen , 50 + (i+1) * ITEM_MENU_DISTANCE , " BACK " );
+	CenteredPutString( Screen , 50 + (i+1) * ITEM_MENU_DISTANCE , _(" BACK "));
 	
 	//--------------------
 	// Now we draw the influencer as a cursor
@@ -1243,7 +1241,7 @@ DoEquippmentListSelection( char* Startstring , item* Item_Pointer_List[ MAX_ITEM
 	
     } // while not space pressed...
     
-    if ( SpacePressed() || axis_is_active ) 
+    if ( SpacePressed() || MouseLeftPressed() ) 
     {
 	return ( InMenuPosition + MenuInListPosition ) ;
     }
@@ -1260,32 +1258,25 @@ DoEquippmentListSelection( char* Startstring , item* Item_Pointer_List[ MAX_ITEM
 void 
 TryToRepairItem( item* RepairItem )
 {
-    int MenuPosition;
-    char linebuf[1000];
-    
-#define ANSWER_YES 1
-#define ANSWER_NO 2
-    
     char* MenuTexts[ 10 ];
-    MenuTexts[0]="Yes";
-    MenuTexts[1]="No";
+    MenuTexts[0]=_("Yes");
+    MenuTexts[1]=_("No");
     MenuTexts[2]="";
     
-    while ( SpacePressed() || EnterPressed() );
+    while ( SpacePressed() || EnterPressed() || MouseLeftPressed() ) SDL_Delay(1);
     
     if ( calculate_item_repair_price ( RepairItem ) > Me [ 0 ] . Gold )
     {
-	PlayOnceNeededSoundSample ( "STO_You_Cant_Repaired_0.wav" , FALSE , FALSE );
-	MenuTexts[0]=" BACK ";
+	MenuTexts[0]=_(" BACK ");
 	MenuTexts[1]="";
         SetCurrentFont ( Menu_BFont );
-	DoMenuSelection ( "\n\nYou can't afford to have this item repaired! " , MenuTexts , 1 , -1 , NULL );
+	DoMenuSelection ( _("\n\nYou can't afford to have this item repaired! ") , MenuTexts , 1 , -1 , NULL );
 	return;
     }
     
     Me [ 0 ] . Gold -= calculate_item_repair_price ( RepairItem ) ;
     RepairItem->current_duration = RepairItem->max_duration;
-    PlayOnceNeededSoundSample ( "effects/Shop_ItemRepairedSound_0.wav" , FALSE , FALSE );
+    PlayOnceNeededSoundSample ( "effects/Shop_ItemRepairedSound_0.ogg" , FALSE , FALSE );
 }; // void TryToRepairItem( item* RepairItem )
 
 /* ----------------------------------------------------------------------
@@ -1294,26 +1285,19 @@ TryToRepairItem( item* RepairItem )
 void 
 TryToIdentifyItem( item* IdentifyItem )
 {
-    int MenuPosition;
-    char linebuf[1000];
-    
-#define ANSWER_YES 1
-#define ANSWER_NO 2
-    
     char* MenuTexts[ 10 ];
-    MenuTexts[0]="Yes";
-    MenuTexts[1]="No";
+    MenuTexts[0]=_("Yes");
+    MenuTexts[1]=_("No");
     MenuTexts[2]="";
     
-    while ( SpacePressed() || EnterPressed() );
+    while ( SpacePressed() || EnterPressed() || MouseLeftPressed());
     
     if ( 100 > Me[0].Gold )
     {
-	PlayOnceNeededSoundSample ( "STO_You_Cant_Identified_0.wav" , FALSE , FALSE );
-	MenuTexts[0]=" BACK ";
+	MenuTexts[0]=_(" BACK ");
 	MenuTexts[1]="";
         SetCurrentFont ( Menu_BFont );
-	DoMenuSelection ( "You can't afford to have this item identified! " , MenuTexts , 1 , -1 , NULL );
+	DoMenuSelection ( _("You can't afford to have this item identified! ") , MenuTexts , 1 , -1 , NULL );
 	return;
     }
     
@@ -1321,7 +1305,7 @@ TryToIdentifyItem( item* IdentifyItem )
 	while (EnterPressed() || SpacePressed() );
 	Me[0].Gold -= 100 ;
 	IdentifyItem -> is_identified = TRUE ;
-	PlayOnceNeededSoundSample ( "effects/Shop_ItemIdentifiedSound_0.wav" , FALSE , FALSE );
+	PlayOnceNeededSoundSample ( "effects/Shop_ItemIdentifiedSound_0.ogg" , FALSE , FALSE );
 
     return;
 }; // void TryToIdentifyItem( item* IdentifyItem )
@@ -1339,8 +1323,8 @@ TryToSellItem( item* SellItem , int WithBacktalk , int AmountToSellAtMost )
 #define ANSWER_NO 2
     
     char* MenuTexts[ 10 ];
-    MenuTexts[0]="Yes";
-    MenuTexts[1]="No";
+    MenuTexts[0]=_("Yes");
+    MenuTexts[1]=_("No");
     MenuTexts[2]="";
     
     //--------------------
@@ -1382,7 +1366,7 @@ please inform the developers...",
 	while ( 1 )
 	{
 	    GiveItemDescription( linebuf , SellItem , TRUE );
-	    strcat ( linebuf , "\n\n    Are you sure you wish to sell this/(some of these) item(s)?" );
+	    strcat ( linebuf , _("\n\n    Are you sure you wish to sell this/(some of these) item(s)?") );
 	    MenuPosition = DoMenuSelection( linebuf , MenuTexts , 1 , -1 , NULL );
 	    switch (MenuPosition) 
 	    {
@@ -1394,7 +1378,7 @@ please inform the developers...",
 		    
 		    Me [ 0 ] . Gold += calculate_item_sell_price ( SellItem );
 		    DeleteItem( SellItem );
-		    PlayOnceNeededSoundSample ( "effects/Shop_ItemSoldSound_0.wav" , FALSE , TRUE );
+		    PlayOnceNeededSoundSample ( "effects/Shop_ItemSoldSound_0.ogg" , FALSE , TRUE );
 		    
 		    return;
 		    break;
@@ -1417,7 +1401,7 @@ please inform the developers...",
 	else 
 	    DeleteItem( SellItem );
 	
-	PlayOnceNeededSoundSample ( "effects/Shop_ItemSoldSound_0.wav" , FALSE , TRUE );
+	PlayOnceNeededSoundSample ( "effects/Shop_ItemSoldSound_0.ogg" , FALSE , TRUE );
     }
 }; // void TryToSellItem( item* SellItem )
 
@@ -1508,11 +1492,11 @@ TryToIntegrateItemIntoInventory ( item* BuyItem , int AmountToBuyAtMost )
     // for buying and could be bought, if only ONE HAD ENOUGH ROOM IN INVENTORY!!
     // Therefore a message must be displayed, saying what the problem is.
     //
-    PlayOnceNeededSoundSample ( "Tux_Hold_On_I_0.wav" , FALSE , FALSE );
-    MenuTexts[0]=" BACK ";
+    PlayOnceNeededSoundSample ( "Tux_Hold_On_I_0.ogg" , FALSE , FALSE );
+    MenuTexts[0]=_(" BACK ");
     MenuTexts[1]="";
     GiveItemDescription( linebuf , BuyItem , TRUE );
-    strcat ( linebuf , "\n\n   No room for this item in inventory!" );
+    strcat ( linebuf , _("\n\n   No room for this item in inventory!") );
     DoMenuSelection( linebuf , MenuTexts , 1 , -1 , NULL );
     return ( FALSE );
     
@@ -1536,7 +1520,7 @@ TryToTakeItem( item* BuyItem , int AmountToBuyAtMost )
     //
     if ( AmountToBuyAtMost <= 0 ) 
     {
-	DebugPrintf ( 0 , "\nTried to take 0 items of a kind from chest or cointainer... doing nothing... " );
+	DebugPrintf ( 0 , _("\nTried to take 0 items of a kind from chest or cointainer... doing nothing... ") );
 	return;
     }
     
@@ -1569,8 +1553,8 @@ TryToBuyItem( item* BuyItem , int WithBacktalk , int AmountToBuyAtMost )
 #define ANSWER_NO 2
     
     char* MenuTexts[ 10 ];
-    MenuTexts[0]="Yes";
-    MenuTexts[1]="No";
+    MenuTexts[0]=_("Yes");
+    MenuTexts[1]=_("No");
     MenuTexts[2]="";
     
     DebugPrintf ( 0 , "\nTryToBuyItem (...):  function called." );
@@ -1589,17 +1573,16 @@ TryToBuyItem( item* BuyItem , int WithBacktalk , int AmountToBuyAtMost )
     
     FreeIndex = GetFreeInventoryIndex(  );
     
-    while ( SpacePressed() || EnterPressed() || axis_is_active );
+    while ( SpacePressed() || EnterPressed() || MouseLeftPressed() );
     
     if ( calculate_item_buy_price ( BuyItem ) > Me [ 0 ] . Gold )
     {
-	PlayOnceNeededSoundSample ( "STO_You_Cant_Buy_0.wav" , FALSE , FALSE );
 	if ( WithBacktalk )
 	{
-	    MenuTexts[0]=" BACK ";
+	    MenuTexts[0]=_(" BACK ");
 	    MenuTexts[1]="";
 	    GiveItemDescription( linebuf , BuyItem , TRUE );
-	    strcat ( linebuf , "\n\n    You can't afford to purchase this item!" );
+	    strcat ( linebuf , _("\n\n    You can't afford to purchase this item!") );
             SetCurrentFont ( Menu_BFont );
 	    DoMenuSelection( linebuf , MenuTexts , 1 , -1 , NULL );
 	}
@@ -1617,7 +1600,7 @@ TryToBuyItem( item* BuyItem , int WithBacktalk , int AmountToBuyAtMost )
     if ( TryToIntegrateItemIntoInventory ( BuyItem , AmountToBuyAtMost ) )
     {
 	Me[0].Gold -= PotentialPrice ;
-	PlayOnceNeededSoundSample ( "effects/Shop_ItemBoughtSound_0.wav" , FALSE , FALSE );
+	PlayOnceNeededSoundSample ( "effects/Shop_ItemBoughtSound_0.ogg" , FALSE , FALSE );
     }
     else
     {
@@ -1759,8 +1742,8 @@ Repair_Items( void )
     int NumberOfItemsInTuxRow = 0 ;
     item* TuxItemsList[ MAX_ITEMS_IN_INVENTORY ];
     shop_decision ShopOrder;
-    MenuTexts[0]="Yes";
-    MenuTexts[1]="No";
+    MenuTexts[0]=_("Yes");
+    MenuTexts[1]=_("No");
     MenuTexts[2]="";
     
     
@@ -1825,10 +1808,9 @@ Repair_Items( void )
 	
 	if ( Pointer_Index == 0 )
 	{
-	    PlayOnceNeededSoundSample ( "STO_Sorry_But_Repair_0.wav" , FALSE , FALSE );
-	    MenuTexts[0]=" BACK ";
+	    MenuTexts[0]=_(" BACK ");
 	    MenuTexts[1]="";
-	    DoMenuSelection ( " YOU DONT HAVE ANYTHING THAT WOULD NEED REPAIR " , MenuTexts , 1 , -1 , NULL );
+	    DoMenuSelection ( _(" YOU DONT HAVE ANYTHING THAT WOULD NEED REPAIR ") , MenuTexts , 1 , -1 , NULL );
 	    return;
 	}
 	
@@ -1880,8 +1862,8 @@ Identify_Items ( void )
     char DescriptionText[5000];
     int ItemSelected;
     char* MenuTexts[ 10 ];
-    MenuTexts[0]="Yes";
-    MenuTexts[1]="No";
+    MenuTexts[0]=_("Yes");
+    MenuTexts[1]=_("No");
     MenuTexts[2]="";
     
     //--------------------
@@ -1931,10 +1913,9 @@ Identify_Items ( void )
     
     if ( Pointer_Index == 0 )
     {
-	PlayOnceNeededSoundSample ( "STO_You_Dont_Have_0.wav" , FALSE , FALSE );
-	MenuTexts[0]=" BACK ";
+	MenuTexts[0]=_(" BACK ");
 	MenuTexts[1]="";
-	DoMenuSelection ( " YOU DONT HAVE ANYTHING THAT WOULD NEED TO BE IDENTIFIED!" , MenuTexts , 1 , -1 , NULL );
+	DoMenuSelection ( _(" YOU DONT HAVE ANYTHING THAT WOULD NEED TO BE IDENTIFIED!") , MenuTexts , 1 , -1 , NULL );
 	return;
     }
     
@@ -1946,7 +1927,7 @@ Identify_Items ( void )
     
     while ( ItemSelected != (-1) )
     {
-	sprintf( DescriptionText , " I COULD IDENTIFY THESE ITEMS             YOUR GOLD:  %4ld" , Me[0].Gold );
+	sprintf( DescriptionText , _(" I COULD IDENTIFY THESE ITEMS             YOUR GOLD:  %4ld") , Me[0].Gold );
 	ItemSelected = DoEquippmentListSelection( DescriptionText , Identify_Pointer_List , PRICING_FOR_IDENTIFY );
 	if ( ItemSelected != (-1) ) TryToIdentifyItem( Identify_Pointer_List[ ItemSelected ] ) ;
     }
@@ -1973,8 +1954,8 @@ Sell_Items( int ForHealer )
     //  int MenuInListPosition = 0;
     char DescriptionText[5000];
     char* MenuTexts[ 10 ];
-    MenuTexts[0]="Yes";
-    MenuTexts[1]="No";
+    MenuTexts[0]=_("Yes");
+    MenuTexts[1]=_("No");
     MenuTexts[2]="";
     
     //--------------------
@@ -2007,10 +1988,9 @@ Sell_Items( int ForHealer )
     
     if ( Pointer_Index == 0 )
     {
-	PlayOnceNeededSoundSample ( "STO_Sorry_But_You_0.wav" , FALSE , FALSE );
-	MenuTexts[0]=" BACK ";
+	MenuTexts[0]=_(" BACK ");
 	MenuTexts[1]="";
-	DoMenuSelection ( " YOU DONT HAVE ANYTHING IN INVENTORY (I.E. NOT WORN), THAT COULD BE SOLD. " , 
+	DoMenuSelection ( _(" YOU DONT HAVE ANYTHING IN INVENTORY (I.E. NOT WORN), THAT COULD BE SOLD. "), 
 			  MenuTexts, 1 , -1 , NULL );
 	return;
     }
@@ -2023,7 +2003,7 @@ Sell_Items( int ForHealer )
     
     while ( ItemSelected != (-1) )
     {
-	sprintf( DescriptionText , " I WOULD BUY FROM YOU THESE ITEMS        YOUR GOLD:  %4ld" , Me[0].Gold );
+	sprintf( DescriptionText , _(" I WOULD BUY FROM YOU THESE ITEMS        YOUR GOLD:  %4ld"), Me[0].Gold );
 	ItemSelected = DoEquippmentListSelection( DescriptionText , Sell_Pointer_List , PRICING_FOR_SELL );
 	if ( ItemSelected != (-1) ) TryToSellItem( Sell_Pointer_List[ ItemSelected ] , TRUE , 1 ) ;
     }
@@ -2066,12 +2046,12 @@ BuySellMenu ( void )
     
     while (!Weiter)
     {
-	MenuTexts[0]="Buy Basic Items";
-	MenuTexts[1]="Buy Premium Items";
-	MenuTexts[2]="Sell Items";
-	MenuTexts[3]="Repair Items";
-	MenuTexts[5]="Leave the Sales Representative";
-	MenuTexts[4]="Identify Items";
+	MenuTexts[0]=_("Buy Basic Items");
+	MenuTexts[1]=_("Buy Premium Items");
+	MenuTexts[2]=_("Sell Items");
+	MenuTexts[3]=_("Repair Items");
+	MenuTexts[5]=_("Leave the Sales Representative");
+	MenuTexts[4]=_("Identify Items");
 	MenuTexts[8]="";
 	
 	// MenuPosition = DoMenuSelection( "" , MenuTexts , -1 , SHOP_BACKGROUND_IMAGE , NULL );
