@@ -143,7 +143,9 @@ InitAudio( void )
 								   \n\
 								   If you want this, use the appropriate command line option and Freedroid will \n\
 								   not complain any more.",
-								   NO_NEED_TO_INFORM, IS_FATAL );
+								   NO_NEED_TO_INFORM, IS_WARNING_ONLY );
+		sound_on = FALSE;
+		return;
 		}
 	else
 		{
@@ -170,7 +172,9 @@ InitAudio( void )
 								   \n\
 								   If you want this, use the appropriate command line option and Freedroid will \n\
 								   not complain any more.",
-								   NO_NEED_TO_INFORM, IS_FATAL );
+								   NO_NEED_TO_INFORM, IS_WARNING_ONLY );
+		sound_on = FALSE;
+		return;
 		}
 	else
 		{
@@ -184,7 +188,6 @@ InitAudio( void )
 	// really resolve the problem however is unsure.
 	//
 	DebugPrintf( 1 , "\nChannels allocated: %d. " , Mix_AllocateChannels( 200 ) );
-
 	}; // void InitAudio(void)
 
 
@@ -283,8 +286,8 @@ LoadAndFadeInBackgroundMusic ( void )
 #else
 
 	static int MOD_Music_Channel = -1;
-	char* fpath;
-	char filename_raw[ 5000 ];
+	char fpath[2048];
+	char filename_raw[ 2048 ];
 
 	if ( !sound_on )
 		return ;
@@ -318,7 +321,7 @@ LoadAndFadeInBackgroundMusic ( void )
 
 	strcpy ( filename_raw , "music/" );
 	strcat ( filename_raw , NewMusicTargetFileName );
-	fpath = find_file_for_callbacks ( filename_raw , SOUND_DIR, FALSE );
+	find_file ( filename_raw , SOUND_DIR, fpath, 0 );
 	Loaded_MOD_Files [ 0 ] = Mix_LoadMUS( fpath );
 	if ( Loaded_MOD_Files[ 0 ] == NULL )
 		{
@@ -428,7 +431,7 @@ void PlayOnceNeededSoundSample( char* SoundSampleFileName , int With_Waiting , i
 	int Newest_Sound_Channel = 0;
 	Mix_Chunk *One_Shot_WAV_File;
 	char Temp_Filename[ 5000 ];
-	char* fpath = "no_fpath_has_been_set";
+	char fpath[2048] = "no_fpath_has_been_set";
 
 	//--------------------
 	// In case the same sample is played again and again in a very
@@ -474,9 +477,6 @@ void PlayOnceNeededSoundSample( char* SoundSampleFileName , int With_Waiting , i
 	return ;
 #else
 */
-	//--------------------
-	// In case sound has been disabled, we don't do anything here...
-	//
 	if ( !sound_on )
 		{
 		//--------------------
@@ -492,15 +492,11 @@ void PlayOnceNeededSoundSample( char* SoundSampleFileName , int With_Waiting , i
 			simulated_playback_starting_time = SDL_GetTicks() ;
 
 			while ( ( SDL_GetTicks() - simulated_playback_starting_time < 7 * 1000 ) &&
-					!EscapePressed() && !SpacePressed() )
-				SDL_Delay( 100 );
+					!EscapePressed() && !SpacePressed() && !MouseLeftPressed())
+				SDL_Delay( 10 );
 
-			if ( EscapePressed() )
-				while ( EscapePressed() )
-					;
-			if ( SpacePressed() )
-				while ( SpacePressed() )
-					;
+			while ( EscapePressed() || SpacePressed() || MouseLeftPressed() )
+					SDL_Delay(1);
 			}
 
 		//--------------------
@@ -532,7 +528,7 @@ void PlayOnceNeededSoundSample( char* SoundSampleFileName , int With_Waiting , i
 		{
 		pathlen = strlen ( Temp_Filename );
 
-		if ( strcmp ( Temp_Filename + pathlen - 4 , ".wav" ) == 0 )
+		if ( strcmp ( Temp_Filename + pathlen - 4 , ".ogg" ) == 0 )
 			{
 			extension = Temp_Filename + pathlen - 4;
 			}
@@ -545,12 +541,11 @@ void PlayOnceNeededSoundSample( char* SoundSampleFileName , int With_Waiting , i
 		while ( extensions [ i ] != NULL )
 			{
 			strcpy ( extension, extensions [ i ] );
-			fpath = find_file_silent ( Temp_Filename , SOUND_DIR, FALSE );
 			//--------------------
 			// find_file_silent may return a NULL pointer, in case the file name
 			// composed hasn't been found.  We need to catch that case of course.
 			//
-			if ( fpath != NULL )
+                       if ( find_file ( Temp_Filename , SOUND_DIR, fpath, 1 ) == 0)
 				{
 				One_Shot_WAV_File = Mix_LoadWAV ( fpath ) ;
 				if ( One_Shot_WAV_File != NULL )
@@ -560,8 +555,8 @@ void PlayOnceNeededSoundSample( char* SoundSampleFileName , int With_Waiting , i
 				else
 					{
 					GiveStandardErrorMessage ( __FUNCTION__ , "\
-											   Corrupt sound file encountered!  The file is there, \n\
-											   but the SDL MIXER was unable to LOAD it.",
+Corrupt sound file encountered!  The file is there, \n\
+but the SDL MIXER was unable to LOAD it.",
 											   NO_NEED_TO_INFORM , IS_WARNING_ONLY );
 					}
 				}
@@ -584,8 +579,8 @@ void PlayOnceNeededSoundSample( char* SoundSampleFileName , int With_Waiting , i
 		if ( strcmp ( SoundSampleFileName , "Sorry_No_Voice_Sample_Yet_0.wav" ) )
 			{
 			fprintf( stderr, "\n\nSoundSampleFileName: '%s'" , SoundSampleFileName );
-			GiveStandardErrorMessage ( __FUNCTION__ , "\
-									   There seems to be a sound file missing.",
+                       GiveStandardErrorMessage ( __FUNCTION__ , "\
+There seems to be a sound file missing.",
 									   NO_NEED_TO_INFORM, GameConfig.terminate_on_missing_speech_sample );
 			}
 
@@ -604,11 +599,11 @@ void PlayOnceNeededSoundSample( char* SoundSampleFileName , int With_Waiting , i
 				simulated_playback_starting_time = SDL_GetTicks() ;
 
 				while ( ( SDL_GetTicks() - simulated_playback_starting_time < 7 * 1000 ) &&
-						!EscapePressed() && !SpacePressed() )
-					;
+						!EscapePressed() && !SpacePressed() && !MouseLeftPressed() )
+					SDL_Delay(10);
 
-				while ( EscapePressed() || SpacePressed() )
-					;
+				while ( EscapePressed() || SpacePressed() || MouseLeftPressed() )
+					SDL_Delay(10);
 				}
 
 			//--------------------
@@ -681,11 +676,11 @@ void PlayOnceNeededSoundSample( char* SoundSampleFileName , int With_Waiting , i
 		// In case escape was pressed, the currently playing voice sample must
 		// be terminated immediately.
 		//
-		if ( EscapePressed() || SpacePressed() )
+		if ( EscapePressed() || SpacePressed() || MouseLeftPressed() )
 			{
 			Mix_HaltChannel( Newest_Sound_Channel );
-			while ( EscapePressed() || SpacePressed() )
-				;
+			while ( EscapePressed() || SpacePressed() || MouseLeftPressed())
+				SDL_Delay(10);
 
 			//--------------------
 			// Now the channel has finished playing (or we have stopped it) and
@@ -740,7 +735,7 @@ play_sample_using_WAV_cache_v( char* SoundSampleFileName , int With_Waiting , in
 	{
 	int Newest_Sound_Channel = 0;
 	char Temp_Filename[ 5000 ];
-	char* fpath;
+	char fpath[2048];
 	int index_of_sample_to_be_played = 0 ;
 	int sound_must_be_loaded = TRUE ;
 	int i;
@@ -792,7 +787,7 @@ play_sample_using_WAV_cache_v( char* SoundSampleFileName , int With_Waiting , in
 		//
 		dynamic_WAV_cache[ next_free_position_in_cache ] = NULL ;
 		strcpy ( Temp_Filename , SoundSampleFileName );
-		fpath = find_file ( Temp_Filename , SOUND_DIR, FALSE );
+		find_file (Temp_Filename , SOUND_DIR, fpath, 0 );
 		dynamic_WAV_cache[ next_free_position_in_cache ] = Mix_LoadWAV( fpath );
 		if ( dynamic_WAV_cache [ next_free_position_in_cache ] == NULL )
 			{
