@@ -114,7 +114,6 @@ typedef struct
     int StandardEnemyMessages_On_Off;
     int StandardInfluencerMessages_On_Off;
     int Mouse_Input_Permitted;
-    char Theme_SubPath[2000];
 
     //--------------------
     // Now we add all the variables for the current screen/hud
@@ -144,13 +143,11 @@ typedef struct
     int enemy_energy_bars_visible;
     int hog_CPU;
     int highlighting_mode_full;
-    int menu_mode;
     int omit_tux_in_level_editor;
     int omit_obstacles_in_level_editor;
     int omit_enemies_in_level_editor;
     int level_editor_edit_mode;
     int zoom_is_on;
-    int use_bars_instead_of_energy_o_meter;
     int show_quick_inventory;
     int show_blood; // this can be used to make the game more friendly for children...
     int show_tooltips;
@@ -168,6 +165,9 @@ typedef struct
     float automap_display_scale ;
     int skip_shadow_blitting ;
     int language ; // index of language, see in defs.h
+    int do_fadings; // do the screen fadings
+    int auto_display_to_help; // display the takeover help
+    int fullscreen_on;
 }
 configuration_for_freedroid , *Configuration_for_freedroid;
 
@@ -264,6 +264,9 @@ typedef struct
     // Maybe the triggered action will change some obstacle on some level...
     char* modify_obstacle_with_label;
     int modify_obstacle_to_type;
+
+    char * modify_event_trigger_with_action_label;
+    int modify_event_trigger_value;
     
     // Maybe the triggered event teleports the influencer somewhere
     point TeleportTarget;
@@ -271,6 +274,8 @@ typedef struct
     
     // Maybe the triggered action consists of a mission assignment
     int AssignWhichMission;
+
+    char * also_execute_action_label; //execute another action (linked action)
     
 }
 triggered_action , *Triggered_action;
@@ -294,6 +299,8 @@ typedef struct
     // Thats propably the most important information at all!!!
     // int EventNumber;
     char* TargetActionLabel;
+
+    int enabled; //is the trigger enabled?
 }
 event_trigger , *Event_trigger;
 
@@ -378,7 +385,7 @@ typedef struct
     int modifier_to_bonus_to_force;
 
     float base_bonus_to_health_recovery;
-    float base_bonus_to_mana_recovery;
+    float base_bonus_to_cooling_rate;
     
 
 
@@ -395,6 +402,8 @@ typedef struct
     int modifier_to_bonus_to_resist_disruptor; // this is a percentage
     int light_bonus_value;
     float price_factor;
+
+    int level; //"level" of the prefix (is it good or not)
 } item_bonus , *Item_bonus;
 
 typedef struct
@@ -489,7 +498,7 @@ typedef struct
     int bonus_to_life;
     int bonus_to_force;
     float bonus_to_health_recovery;
-    float bonus_to_mana_recovery;
+    float bonus_to_cooling_rate;
     int bonus_to_tohit;
     int bonus_to_all_attributes;
     int bonus_to_ac_or_damage;       // this is a percentage
@@ -500,7 +509,6 @@ typedef struct
     int ac_bonus;                    // how much is ac increased by this item worn
     int damage;                      // how much damage does this item
     int damage_modifier;             // how much additional damage can add to the base damage
-    int gold_amount;                 // how much cyberbucks are there, IN CASE OF CYBERBUCKS
     int multiplicity;
     int ammo_clip; 		// how much bullets in the clip, IN CASE OF WEAPON
     point inventory_position;
@@ -509,13 +517,12 @@ typedef struct
 typedef struct
 {
     char *druidname;
-    char *portrait_filename_without_ext;
     char *droid_portrait_rotation_series_prefix;
     char *droid_death_sound_file_name;
     char *droid_attack_animation_sound_file_name;
     int class;
     double maxenergy;		// the maximum energy the batteries can carry 
-    double maxmana;		// the maximum force this droids mind can carry 
+    double max_temperature;		// the maximum force this droids mind can carry 
     double lose_health;		// the energy/time the duid loses under influence-control 
     
     double maxspeed;
@@ -557,9 +564,6 @@ typedef struct
     int to_hit;                           // chance that this droid hits an unarmoured target
     int getting_hit_modifier;             // modifier for this droid to receive a hit from the player
     float recover_time_after_getting_hit;
-    int advanced_behaviour;               // Does this droid behave better that in the original paradroid?
-    int call_for_help_after_getting_hit;  // Does this droid request help from the next console so soon as it is
-    // hit by a bullet of some type?
     char *notes;			        // notes on the druid of this type 
     int is_human;
     int individual_shape_nr;
@@ -595,15 +599,16 @@ typedef struct
     double health;		  // the max. possible energy in the moment 
     float maxenergy; // current top limit for the influencers energy
     double energy;		  // current energy level 
-    float maxmana;   // current top limit for the influencers magic power
-    double mana;                    // current mana level 
+    float max_temperature;   // current top limit for temperature (highest is better)
+    float temperature;                    // current temperature
+    float old_temperature;                    // current temperature
     float max_running_power;
     float running_power;
     int running_must_rest;
     int running_power_bonus;
 
     float health_recovery_rate; //points of health recovered each second
-    float mana_recovery_rate; //mana points recovered each second
+    float cooling_rate; //temperature points recovered each second
     
     Sint16 LastMouse_X;             // mostly for other players:  Where was the last mouseclick...
     Sint16 LastMouse_Y;             // mostly for other players:  Where was the last mouseclick...
@@ -661,8 +666,8 @@ typedef struct
     // currently readied and that...
     //
     int readied_skill; 
-    int SkillLevel[ NUMBER_OF_SKILLS ];
-    int base_skill_level [ NUMBER_OF_SKILLS ];
+    int SkillLevel[MAX_NUMBER_OF_PROGRAMS];
+    int base_skill_level[MAX_NUMBER_OF_PROGRAMS];
     int melee_weapon_skill;
     int ranged_weapon_skill;
     int spellcasting_skill;
@@ -695,8 +700,6 @@ typedef struct
     // of the Tux like town guard member or not and the like...
     //
     unsigned char Chat_Flags[ MAX_PERSONS ][ MAX_ANSWERS_PER_PERSON ];
-    int clearance_list[ MAX_CLEARANCES ];
-    char password_list[ MAX_PASSWORDS ] [ MAX_PASSWORD_LENGTH ] ;
     char cookie_list[ MAX_COOKIES ] [ MAX_COOKIE_LENGTH ] ;
     int is_town_guard_member;
     char chat_character_initialized [ MAX_PERSONS ]; 
@@ -708,13 +711,15 @@ typedef struct
     moderately_finepoint next_intermediate_point [ MAX_INTERMEDIATE_WAYPOINTS_FOR_TUX ] ;  // waypoints for the tux, when target not directly reachable
     Uint16 KillRecord[ 200 ];      // how many ( of the first 1000 monster types) have been killed yet?
     Uint8 Automap [ MAX_LEVELS ] [ 100 ][ 100 ]; // this is the data for the automatic map
-    moderately_finepoint DetectedItemList[ MAX_ITEMS_PER_LEVEL ];
     int current_zero_ring_index;
     gps Position_History_Ring_Buffer[ MAX_INFLU_POSITION_HISTORY ];
     
     int BigScreenMessageIndex;
     char BigScreenMessage [ MAX_BIG_SCREEN_MESSAGES ] [ 5000 ];
     float BigScreenMessageDuration [ MAX_BIG_SCREEN_MESSAGES ];
+
+    float slowdown_duration;
+    float paralyze_duration;
 }
 tux_t, *Tux_t;
 
@@ -729,7 +734,7 @@ typedef struct
     gps teleport_anchor;          
     double health;		
     double energy;		
-    double mana;                  
+    double temperature;
     double busy_time;		
     int busy_type;
     double phase;			
@@ -755,7 +760,7 @@ typedef struct
     int resist_fire;         
     int resist_electricity;  
     float maxenergy; 
-    float maxmana;   
+    float max_temperature;   
     int exp_level;   
     long ExpRequired;
     long Gold;
@@ -956,23 +961,37 @@ blast, *Blast;
 
 typedef struct
 {
-    int type; // what type of spell is active?
+    int img_type; // what type of spell is active?
+    int damage;
+    int poison_duration;
+    int poison_dmg;
+    int freeze_duration;
+    int paralyze_duration;
     moderately_finepoint spell_center;
     float spell_radius;
     float spell_age;
     int active_directions [ RADIAL_SPELL_DIRECTIONS ] ;
+    int mine;
 }
 spell_active, *Spell_Active;
 
 typedef struct
 {
-    int Circle;
-    char* spell_skill_name;
-    char* spell_skill_icon_name;
-    iso_image spell_skill_icon_surface;
-    int mana_cost_table[ NUMBER_OF_SKILL_LEVELS ];
-    int magic_requirement_table[ NUMBER_OF_SKILL_LEVELS ];
-    char* spell_skill_description;
+    char* name;
+    char* icon_name;
+    iso_image icon_surface;
+    int heat_cost;
+    int heat_cost_per_level;
+    int damage_base;
+    int damage_mod;
+    int damage_per_level;
+    int hurt_bots;
+    int hurt_humans;
+    char* description;
+    char* effect;
+    int form;
+    int present_at_startup;
+    int graphics_code;
 }
 spell_skill_spec, *Spell_Skill_Spec;
 
