@@ -69,8 +69,12 @@
 #include <signal.h>
 
 #ifdef HAVE_SYS_SOUNDCARD_H
+#ifdef __OpenBSD__
+#include <soundcard.h>
+#else
 #include <sys/soundcard.h>
 #endif
+#endif
 #ifdef HAVE_SYS_IOCTL_H
 #include <sys/ioctl.h>
 #endif
@@ -79,6 +83,10 @@
 #include <fcntl.h>
 #endif
 
+//#ifdef HAVE_LOCALE_H
+//#include <locale.h>
+//#endif
+
 #include <errno.h>
 #include <stdarg.h>
 #include <ctype.h>
@@ -102,6 +110,6 @@
 #include "SDL_opengl.h"
 #endif /* HAVE_LIBGL */
 
-
+#include "lang.h"
 
 #endif /* double-inclusion protection */
