@@ -32,7 +32,6 @@
 
 
 #include "colodefs.h"
-#include "ship.h"
 
 char* floor_tile_filenames [ ALL_ISOMETRIC_FLOOR_TILES ] =
   {
@@ -128,25 +127,26 @@ tux_t Me[ MAX_PLAYERS ] ;
 network_tux_t NetworkMe[ MAX_PLAYERS ];
 
 char *InfluenceModeNames[] = {
-  "Mobile",
-  "Transfer",
-  "Weapon",
-  "Captured",
-  "Complete",
-  "Rejected",
-  "Logged In",
-  "Debriefing",
-  "Terminated",
-  "Pause",
-  "Cheese",
-  "Elevator",
-  "Briefing",
-  "Menu",
-  "Fresh Net",
-  "Name Tran",
+  N_("Mobile"),
+  N_("Transfer"),
+  N_("Weapon"),
+  N_("Captured"),
+  N_("Complete"),
+  N_("Rejected"),
+  N_("Logged In"),
+  N_("Debriefing"),
+  N_("Terminated"),
+  N_("Pause"),
+  N_("Cheese"),
+  N_("Elevator"),
+  N_("Briefing"),
+  N_("Menu"),
+  N_("Fresh Net"),
+  N_("Name Tran"),
   NULL
 };
 
+// Debug string, no need for translation
 char *NetworkClientStatusNames[] = {
   "Network ERROR" ,
   "Unconnected" , 
@@ -158,90 +158,90 @@ char *NetworkClientStatusNames[] = {
 
 
 char *Classname[] = {
-  "Influence device",
-  "Disposal robot",
-  "Servant robot",
-  "Messenger robot",
-  "Maintenance robot",
-  "Crew droid",
-  "Sentinel droid",
-  "Battle droid",
-  "Security droid",
-  "Command Cyborg",
-  "Peaceful Human",
-  "Cold MS Force",
-  "Mrs. Stone, Shopowner",
-  "Resistance Founder",
-  "Town Healer",
-  "Sorenson, Master of Magic", // 15
-  "Pendragon, Rebel Fighter",
-  "Dixon, Teleporter Service Man",
-  "Chandra, Tourist Guide",
+  N_("Influence device"),
+  N_("Disposal robot"),
+  N_("Servant robot"),
+  N_("Messenger robot"),
+  N_("Maintenance robot"),
+  N_("Crew droid"),
+  N_("Sentinel droid"),
+  N_("Battle droid"),
+  N_("Security droid"),
+  N_("Command Cyborg"),
+  N_("Peaceful Human"),
+  N_("Cold MS Force"),
+  N_("Mrs. Stone, Shopowner"),
+  N_("Resistance Founder"),
+  N_("Town Healer"),
+  N_("Sorenson, Master of Magic"), // 15
+  N_("Pendragon, Rebel Fighter"),
+  N_("Dixon, Teleporter Service Man"),
+  N_("Chandra, Tourist Guide"),
   NULL
 };
 
 char *Classes[] = {
-  "influence",
-  "disposal",
-  "servant",
-  "messenger",
-  "maintenance",
-  "crew",
-  "sentinel",
-  "battle",
-  "security",
-  "command",
-  "error"
+  N_("influence"),
+  N_("disposal"),
+  N_("servant"),
+  N_("messenger"),
+  N_("maintenance"),
+  N_("crew"),
+  N_("sentinel"),
+  N_("battle"),
+  N_("security"),
+  N_("command"),
+  N_("error")
 };
 
 char *Drivenames[] = {
-  "none",
-  "tracks",
-  "anti-grav",
-  "tripedal",
-  "wheels",
-  "bipedal",
-  "error"
+  N_("none"),
+  N_("tracks"),
+  N_("anti-grav"),
+  N_("tripedal"),
+  N_("wheels"),
+  N_("bipedal"),
+  N_("error")
 };
 
 char *Sensornames[] = {
-  " - ",
-  "spectral",
-  "infra-red",
-  "subsonic",
-  "ultra-sonic",
-  "radar",
-  "error"
+  N_(" - "),
+  N_("spectral"),
+  N_("infra-red"),
+  N_("subsonic"),
+  N_("ultra-sonic"),
+  N_("radar"),
+  N_("error")
 };
 
 char *Brainnames[] = {
-  "none",
-  "neutronic",
-  "primode",
-  "error"
+  N_("none"),
+  N_("neutronic"),
+  N_("primode"),
+  N_("error")
 };
 
 char *Weaponnames[] = {
-  "none",
-  "lasers",
-  "laser rifle",
-  "disruptor",
-  "exterminator",
-  "error"
+  N_("none"),
+  N_("lasers"),
+  N_("laser rifle"),
+  N_("disruptor"),
+  N_("exterminator"),
+  N_("error")
 };
 
 char* AllSkillTexts [ NUMBER_OF_SKILL_LEVELS ] =
   {
-    "novice",
-    "average",
-    "experienced",
-    "skilled",
-    "adept",
-    "masterful",
-    "inhuman",
-    "god-like",
-    "super-god-like",
-    "wicked sick"
+    N_("novice"),
+    N_("average"),
+    N_("experienced"),
+    N_("skilled"),
+    N_("adept"),
+    N_("masterful"),
+    N_("inhuman"),
+    N_("god-like"),
+    N_("super-god-like"),
+    N_("wicked sick")
   };
 
 //--------------------
@@ -252,14 +252,14 @@ char* AllSkillTexts [ NUMBER_OF_SKILL_LEVELS ] =
 // These multipliers are given by the table below.
 //
 float MeleeDamageMultiplierTable [  ] =
-  {  1.0 , 1.5 , 2.0 , 2.5 , 3.0 , 3.5 , 4.0 , 4.5 , 5.0 } ;
+  {  1.0 , 1.2 , 1.3 , 1.5 , 1.5 , 1.6 , 2.0 , 2.5 , 3.0 } ;
 float MeleeRechargeMultiplierTable [  ] =
-  {  1.0 , 0.8 , 0.6 , 0.5 , 0.4 , 0.2 , 0.15 , 0.10 , 0.05 } ;
+  {  1.0 , 0.9 , 0.8 , 0.8 , 0.7 , 0.6 , 0.5 , 0.50 , 0.5 } ;
 
 float RangedDamageMultiplierTable [  ] =
-  {  1.0 , 1.5 , 2.0 , 2.5 , 3.0 , 3.5 , 4.0 , 4.5 , 5.0} ;
+  {  1.0 , 1.2 , 1.3 , 1.5 , 1.7 , 1.8 , 2.0  , 2.5 , 3.0} ;
 float RangedRechargeMultiplierTable [  ] =
-  {  1.0 , 0.8 , 0.6 , 0.5 , 0.4 , 0.2 , 0.15 , 0.10 , 0.05 } ;
+  {  1.0 , 0.9 , 0.8 , 0.8 , 0.7 , 0.6 , 0.5 , 0.5 , 0.5 } ;
 
 //--------------------
 // In the game, many spells are still internally similar
@@ -271,31 +271,9 @@ float RangedRechargeMultiplierTable [  ] =
 int SpellHitPercentageTable [  ] =
   {  50 , 70 , 90 , 110 , 130 , 150 , 190 , 230 , 270 } ;
 
-spell_skill_spec SpellSkillMap[ NUMBER_OF_SKILLS ] = {
-  { 0 , "Takeover/Talk/Loot"     , "TakeoverTalkSkill.png"     , UNLOADED_ISO_IMAGE , 
-    { 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 } ,
-    { 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 } ,
-  "This is the Takeover and Talk skill.  The Tux is gifted with an innert ability to hack any machine in no time.  To make use of this ability, select this skill.  When a machine is close enough and this skill is activated by holding down the right mouse button, the takeover process will be initiated." } , 
-
-  { 0 , "Loot Chest/Body"        , "ChestAndDeadBodyLoot.png"  , UNLOADED_ISO_IMAGE , 
-    { 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 } ,
-    { 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 } ,
-  "This is the skill you must ready in order to open chests or search dead bodies.  To do this, just ready the skill and stand in front of the chest or over the dead body and press the right mouse button to open the chest/corpse looting interface." } ,
-
-  { 0 , "Repair Skill"           , "RepairSkill.png"           , UNLOADED_ISO_IMAGE , 
-    { 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 } ,
-    { 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 } ,
-  "This skill allows to repair a given item from inventory.  To use this skill, select it and then open the inventory screen and then right click the mouse on the item you wish to repair.  While repair doesn't 'cost' anything, the item will still lose some of its maximum duration in the process, but the current duration will be restored to this new maximum value." } ,
-
-  { 0 , "Attack with weapon"     , "WeaponSkill.png"           , UNLOADED_ISO_IMAGE , 
-    { 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 } ,
-    { 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 } ,
-  "This is the main weapon skill.  Right clicking somewhere will now cause an attack.  You can still use left click to move around.  In general, peaceful humans will not appreciate people running around with weapons drawn." } ,
-
-  { 0 , "Identify Item"     , "IdentifySkill.png"           , UNLOADED_ISO_IMAGE , 
-    { 15 , 13 , 11 , 9 , 7 , 5 , 4 , 3 , 2 , 1 } ,
-    { 28 , 35 , 45 , 55 , 65 , 70 , 75 , 80 , 85 , 999 } ,
-  "This skill can be used to identify items.  To use this skill, select it and then open the inventory screen and then right click the mouse on the item you wish to identify." } ,
+spell_skill_spec *SpellSkillMap; 
+int number_of_skills;
+/*[ number_of_skills ] = {
 
   { 1 , "Force -> Energy "       , "FirstAidSpell.png"         , UNLOADED_ISO_IMAGE , 
     { 6 , 5 , 4 , 3 , 2 , 1 , 1 , 1 , 1 , 1 } ,
@@ -312,10 +290,10 @@ spell_skill_spec SpellSkillMap[ NUMBER_OF_SKILLS ] = {
     { 30 , 45 , 55 , 65 , 70 , 75 , 80 , 85 , 90 , 999 } ,
   "This is a very simple combat spell.  It fires a plasma bolt into the direction the caster is facing.  This spell does not have as much effect as some ranged weapons, but the good thing about it is that it doesn't require any ammo as well, except perhaps for some mana." } ,
 
-  { 1 , "Ice Bolt"               , "FrostBoltSpell.png"        , UNLOADED_ISO_IMAGE , 
+  { 1 , "Calculate PI"               , "Calculate_PI.png"        , UNLOADED_ISO_IMAGE , 
     { 6 , 5 , 4 , 3 , 2 , 1 , 1 , 1 , 1 , 1 } ,
     { 30 , 45 , 55 , 65 , 70 , 75 , 80 , 85 , 90 , 999 } ,
-  "This simple combat spell allows the caster to fire a frosty bolt into the direction the caster is facing.  This frosty bold can cause some machines to seriously slow down the speed of their motions cause due to dumb MS low-level programming they think they are fighting in a winter environment and have to take extra care not to slip out." } ,
+  "This program allows you to execute a calculate PI script on the target, causing them to to slow down/stop their motions for an amount of time. Dumb MS low-level programming, they think they can actually compute it." } ,
 
   { 1 , "Explosion Circle"       , "ExplosionCircleSpell.png"  , UNLOADED_ISO_IMAGE , 
     { 6 , 5 , 4 , 3 , 2 , 1 , 1 , 1 , 1 , 1 } ,
@@ -457,7 +435,7 @@ spell_skill_spec SpellSkillMap[ NUMBER_OF_SKILLS ] = {
   { 1 , "Unused spell Nr. 39"    , "NoSkillAvailable.png"      , UNLOADED_ISO_IMAGE , 
     { 6 , 5 , 4 , 3 , 2 , 1 , 1 , 1 , 1 , 1 } ,
     { 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , 0 } ,
-  "This is a skill" } };
+  "This is a skill" } };*/
 
 Druidspec Druidmap;
 
